################################################################################
# Authors: 
# Alfredo Sanchez-Tojar (with support from Endika Blanco-Urdillo) 

# Script first created in Nov 2018

################################################################################
# Description of script and Instructions
################################################################################

# This script is for a meta-analysis on the effect of urbanization
# on biodiversity.

################################################################################
# Packages needed
################################################################################

# Clear memory
rm(list = ls())

###install.packages("pacman","egg")
pacman::p_load(metafor,readxl,ggplot2)
library(egg)

################################################################################
# Functions needed
################################################################################

# function to convert chi-squared to Pearson's r (Nakagawa and Cuthill 2007, 
# Table 2)
chi.to.r <- function(chi, n){
  r <- sqrt(chi/n)}

# function to convert t-values from a continuous predictor variable to 
# Pearson's r (Nakagawa and Cuthill 2007, pg 598)
t.to.r <- function(t, N){
  df <- N - 2 #this assumes that there are no other fixed effects included in the models from which t was obtained
  r <- t/sqrt(((t^2) + df))}

# function to convert F-values to Pearson's r (Lajeunesse 2013)
F.to.r <- function(f, N){
  r <- sqrt(f/(f + N - 2))}

# function to convert R2 to Pearson's r (adjusted) (Nakagawa and Cuthill 2007)
R2.to.r <- function(R2, N, k){
  r <- sqrt(1 -(((N - 1)*(1 - R2))/(N - k - 1)))}

# function to convert Spearman's rho to Pearson's r (Lajeunesse 2013)
spearman_to_pearson <- function(rho){
  r <- 2*sin((pi*rho)/6)}

# function to convert Kendall's tau to Pearson's r (Lajeunesse 2013)
kendall_to_pearson <- function(tau){
  r <- sin((pi*tau)/2)}

# function to obtain variance of r (Viechtbauer 2018, Meta-analysis course, 
# Maastrich, Dec 2018)
Vr <- function(r, N){
  Vr <- ((1 - r^2)^2)/(N - 1)}


################################################################################
# Importing the data
################################################################################

meta <- as.data.frame(read_excel("data.xlsx"))
#View(meta)
#str(meta)

################################################################################
# exploring & re-coding variables
################################################################################

# data per study (frecuency)
#hist(table(meta$studyID))


# VALUE
table(meta$value)

# # some visual testing for variable Value: all good
# meta$Value.2 <- ifelse((meta$Richness_rural > meta$Richness_urban | 
#                           meta$Shannon_rural > meta$Shannon_urban | 
#                           meta$Simpson_rural > meta$Simpson_urban | 
#                           meta$Fun_rural > meta$Fun_urban | 
#                           meta$Phy_rural > meta$Phy_urban), 
#                        "Negative",
#                        "Positive")


# TYPE OF DATA
# es_type as factor
table(meta$es_type)
meta$es_type <- factor(meta$es_type)


# YEAR
table(meta$year)
summary(meta$year)


# METHOD
table(meta$method)


# CONTINENT
table(meta$continent)


# SCALE
# no changes needed
table(meta$scale)


# DIVERSITY
table(meta$diversity)


# CLASS
# we have recoded the factor taxa so that the sample sizes are decent
# and still biologically meaningful
table(meta$Class)

meta$Class <- ifelse(meta$Class=="Diplopoda","Myriapoda", as.character(meta$Class))
meta$Class <- ifelse(meta$Class=="Chilopoda","Myriapoda", as.character(meta$Class))

meta$Class <- ifelse(meta$Class=="Branchiopoda","Crustacea", as.character(meta$Class))
meta$Class <- ifelse(meta$Class=="Copepoda","Crustacea", as.character(meta$Class))
meta$Class <- ifelse(meta$Class=="Malacostraca","Crustacea", as.character(meta$Class))

table(meta$Class)
meta$Class <- factor(meta$Class)


# ORDER
table(meta$Order)


# FAMILY
table(meta$Family)


# # testing sample sizes: all good!
# meta$Nt.2 <- meta$Nr + meta$Nu
# table(meta$Nt.2==meta$Nt)


# # searching for potential shared control non-independence that we may have
# # overlooked: none found other than the one we knew of.
# length(meta[!(is.na(meta$Richness_rural)),"Richness_rural"])
# length(unique(meta[!(is.na(meta$Richness_rural)),"Richness_rural"]))
# sort(table(meta[!(is.na(meta$Richness_rural)),"Richness_rural"]))
# 
# length(meta[!(is.na(meta$Richness_urban)),"Richness_urban"])
# length(unique(meta[!(is.na(meta$Richness_urban)),"Richness_urban"]))
# sort(table(meta[!(is.na(meta$Richness_urban)),"Richness_urban"]))
# 
# length(meta[!(is.na(meta$Shannon_rural)),"Shannon_rural"])
# length(unique(meta[!(is.na(meta$Shannon_rural)),"Shannon_rural"]))
# sort(table(meta[!(is.na(meta$Shannon_rural)),"Shannon_rural"]))
# 
# length(meta[!(is.na(meta$Shannon_urban)),"Shannon_urban"])
# length(unique(meta[!(is.na(meta$Shannon_urban)),"Shannon_urban"]))
# sort(table(meta[!(is.na(meta$Shannon_urban)),"Shannon_urban"]))
# 
# length(meta[!(is.na(meta$Simpson_rural)),"Simpson_rural"])
# length(unique(meta[!(is.na(meta$Simpson_rural)),"Simpson_rural"]))
# sort(table(meta[!(is.na(meta$Simpson_rural)),"Simpson_rural"]))
# 
# length(meta[!(is.na(meta$Simpson_urban)),"Simpson_urban"])
# length(unique(meta[!(is.na(meta$Simpson_urban)),"Simpson_urban"]))
# sort(table(meta[!(is.na(meta$Simpson_urban)),"Simpson_urban"]))
# 
# length(meta[!(is.na(meta$Fun_rural)),"Fun_rural"])
# length(unique(meta[!(is.na(meta$Fun_rural)),"Fun_rural"]))
# sort(table(meta[!(is.na(meta$Fun_rural)),"Fun_rural"]))
# 
# length(meta[!(is.na(meta$Fun_urban)),"Fun_urban"])
# length(unique(meta[!(is.na(meta$Fun_urban)),"Fun_urban"]))
# sort(table(meta[!(is.na(meta$Fun_urban)),"Fun_urban"]))


################################################################################
# Calculating effect sizes 
################################################################################

# Strategy = we transform all group comparisons (means, SD, N) to biserial 
# correlations and all the rest to Pearson's correlation coefficient. This 
# allows us to compare data obtained from comparing urban vs. rural, to studies 
# where urbanization was measured as a continuous variable. Since we use 
# biserial correlations, we do not transform Pearson's r to Zr. Note that some 
# biserial correlations might be larger than 1 or smaller than -1.

# We apply a different procedure for each original estimate. We subset the 
# database according to the original estimate and then we put everything 
# together once the effect sizes are estimated.

# For those studies where more than one type of effect size was reported, we 
# chose only one based on the following order of priority:
# 1. Pearson's correlation coefficient (r) + N's
# 2. Group means + SD's + N's
# 3. R2 + N's + k (number of predictors included in the model)
# 4. Other estimates + N's. The estimates where t, F and chi-squared, and no 
#   order of preference was needed to chose among them

# If the number of species is lower in urban than in rural, the sign of the 
# effect size should be or would needed to be assigned as (-) negative. In other 
# words, urbanization has a negative effect on biodiversity

# For studies reporting a correlation coefficient, we assumed it to be Pearson's
# correlation coefficient r unless stated otherwise.


################################################################################
# Urban vs. Rural: mean differences via biserial correlations
################################################################################

twogroups_ri <- meta[meta$es_type=="tgri",]
twogroups_ri <- escalc(measure="RBIS", 
                       m1i=Richness_urban, 
                       m2i=Richness_rural,
                       sd1i=SD_richness_urban,
                       sd2i=SD_richness_rural,
                       n1i=Nu,
                       n2i=Nr,
                       data=twogroups_ri)

twogroups_sh <- meta[meta$es_type=="tgsh",]
twogroups_sh <- escalc(measure="RBIS", 
                       m1i=Shannon_urban, 
                       m2i=Shannon_rural,
                       sd1i=SD_shannon_urban,
                       sd2i=SD_shannon_rural,
                       n1i=Nu,
                       n2i=Nr,
                       data=twogroups_sh)

twogroups_si <- meta[meta$es_type=="tgsi",]
twogroups_si <- escalc(measure="RBIS", 
                       m1i=Simpson_urban, 
                       m2i=Simpson_rural,
                       sd1i=SD_simpson_urban,
                       sd2i=SD_simpson_rural,
                       n1i=Nu,
                       n2i=Nr,
                       data=twogroups_si)

twogroups_fu <- meta[meta$es_type=="tgfu",]
twogroups_fu <- escalc(measure="RBIS", 
                       m1i=Fun_urban, 
                       m2i=Fun_rural,
                       sd1i=Fun_urban_SD,
                       sd2i=Fun_rural_SD,
                       n1i=Nu,
                       n2i=Nr,
                       data=twogroups_fu)

twogroups_ab <- meta[meta$es_type=="tgab",]
twogroups_ab <- escalc(measure="RBIS", 
                       m1i=abund_urban, 
                       m2i=abund_rural,
                       sd1i=SD_abund_urban,
                       sd2i=SD_abund_rural,
                       n1i=Nu,
                       n2i=Nr,
                       data=twogroups_ab)


################################################################################
# Pearson's r
################################################################################

Pearsons <- meta[meta$es_type=="pearsons",]

Pearsons$yi <- Pearsons$r
Pearsons$vi <- Vr(Pearsons$r, Pearsons$Nt)


################################################################################
# Spearman's rho
################################################################################

Spearmans <- meta[meta$es_type=="spearmans",]

Spearmans$yi <- spearman_to_pearson(Spearmans$r)
Spearmans$vi <- Vr(Spearmans$r, Spearmans$Nt)


################################################################################
# R2
################################################################################

R2 <- meta[meta$es_type=="R2",]

R2$yi <- R2.to.r(R2$R2, R2$Nt, R2$k)
R2$vi <- Vr(R2$yi, R2$Nt)

# revising signs
R2$yi <- ifelse(R2$value=="Negative", R2$yi*-1, R2$yi)


################################################################################
# T-values
################################################################################

t_test <- meta[meta$es_type=="t-test",]

t_test$yi <- t.to.r(t_test$t, t_test$Nt)
t_test$vi <- Vr(t_test$yi, t_test$Nt)


################################################################################
# F-values
################################################################################

f_test <- meta[meta$es_type=="F-test",]

f_test$yi <- F.to.r(f_test$F, f_test$Nt)
f_test$vi <- Vr(f_test$yi, f_test$Nt)

#revising signs
f_test$yi <- ifelse(f_test$value=="Negative", f_test$yi*-1, f_test$yi)


################################################################################
# Chi-squared values
################################################################################

chi_squared <- meta[meta$es_type=="chi-squared",]

chi_squared$yi <- chi.to.r(chi_squared$chi, chi_squared$Nt)
chi_squared$vi <- Vr(chi_squared$yi, chi_squared$Nt)

#revising signs
chi_squared$yi <- ifelse(chi_squared$value=="Negative",
                         chi_squared$yi*-1, chi_squared$yi)


################################################################################
# FINAL DATABASE
################################################################################

# putting together all the databases created above
meta.final <- rbind(twogroups_ri, twogroups_sh,
                    twogroups_si, twogroups_fu, twogroups_ab,
                    Pearsons, Spearmans, t_test,
                    f_test, chi_squared, R2)

# # quick test
# nrow(meta.final)==sum(nrow(twogroups_ri) + nrow(twogroups_sh) + 
#                       nrow(twogroups_si) + nrow(twogroups_fu) + nrow(twogroups_ab) +
#                       nrow(Pearsons) + nrow(Spearmans) + nrow(R2) + 
#                       nrow(t_test) + nrow(f_test) + nrow(chi_squared))


# creating a unique identifier to model within/residual variance and sorting
# the database
meta.final <- meta.final[with(meta.final, 
                              order(studyID, ComparisonID, LocationID)),]

meta.final$obsID <- 1:nrow(meta.final)


# reducing the database to the final version for the analyses and renaming
# variables using lower case [in a not so fancy way]
meta.final$r <- meta.final$yi
meta.final$Vr <- meta.final$vi
meta.final$comparisonID <- meta.final$ComparisonID
meta.final$locationID <- meta.final$LocationID
meta.final$inferential_type <- meta.final$Inferential_type


# output dataset
write.csv(meta.final[,c("obsID", "studyID", "comparisonID", "locationID",
                        "authors", "title", "year", "notes",
                        "r", "Vr", "Nr", "Nu", "Nt", "es_type", 
                        "inferential_type", "method", "continent", "scale",
                        "diversity", "Class", "Order", "Family")],
          file= "meta_final_reduced.csv", row.names=FALSE)


################################################################################
# Urban vs. Rural: mean and variance differences: lnRR, SMDH, lnCVR, lnVR
################################################################################

# subsetting dataset only for those with mean values available
meta.final.SA <- as.data.frame(
  meta.final[meta.final$es_type %in% c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
             c("obsID", "studyID", "comparisonID", "locationID",
               "authors", "title", "year", "notes",
               "Nr", "Nu", "Nt",
               "Richness_rural", "SD_richness_rural",
               "Richness_urban", "SD_richness_urban",
               "Shannon_rural", "SD_shannon_rural",
               "Shannon_urban", "SD_shannon_urban",
               "Simpson_rural", "SD_simpson_rural",
               "Simpson_urban", "SD_simpson_urban",
               "Fun_rural", "Fun_rural_SD",
               "Fun_urban", "Fun_urban_SD",
               "abund_rural", "SD_abund_rural",
               "abund_urban", "SD_abund_urban",
               "es_type", "inferential_type",
               "method", "continent", "scale", "diversity",
               "Class", "Order", "Family")])

# We are then calculating lnRR, SMDH, lnCVR and lnVR for each obsID, and 
# creating a database that contains them all.


# calculating effect sizes (which could have been done more elegantly using
# a function, or even a for loop, but it any works well as it is)

# Richness
twogroups_ri_SA <- meta.final.SA[meta.final.SA$es_type=="tgri",]
lnRR.ri <- escalc(measure="ROM", 
                  m1i=Richness_urban, 
                  m2i=Richness_rural,
                  sd1i=SD_richness_urban,
                  sd2i=SD_richness_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_ri_SA,
                  var.names=c("lnRR", "lnRR.vi"))

SMDH.ri <- escalc(measure="SMDH", 
                  m1i=Richness_urban, 
                  m2i=Richness_rural,
                  sd1i=SD_richness_urban,
                  sd2i=SD_richness_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_ri_SA,
                  var.names=c("SMDH", "SMDH.vi"))

SMDH.ri <- SMDH.ri[,c("obsID", "SMDH", "SMDH.vi")]

lnCVR.ri <- escalc(measure="CVR", 
                   m1i=Richness_urban, 
                   m2i=Richness_rural,
                   sd1i=SD_richness_urban,
                   sd2i=SD_richness_rural,
                   n1i=Nu,
                   n2i=Nr,
                   data=twogroups_ri_SA,
                   var.names=c("lnCVR", "lnCVR.vi"))

lnCVR.ri <- lnCVR.ri[,c("obsID", "lnCVR", "lnCVR.vi")]

lnVR.ri <- escalc(measure="VR", 
                  m1i=Richness_urban, 
                  m2i=Richness_rural,
                  sd1i=SD_richness_urban,
                  sd2i=SD_richness_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_ri_SA,
                  var.names=c("lnVR", "lnVR.vi"))

lnVR.ri <- lnVR.ri[,c("obsID", "lnVR", "lnVR.vi")]


# Shannon
twogroups_sh_SA <- meta.final.SA[meta.final.SA$es_type=="tgsh",]
lnRR.sh <- escalc(measure="ROM",
                  m1i=Shannon_urban,
                  m2i=Shannon_rural,
                  sd1i=SD_shannon_urban,
                  sd2i=SD_shannon_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_sh_SA,
                  var.names=c("lnRR", "lnRR.vi"))

SMDH.sh <- escalc(measure="SMDH", 
                  m1i=Shannon_urban,
                  m2i=Shannon_rural,
                  sd1i=SD_shannon_urban,
                  sd2i=SD_shannon_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_sh_SA,
                  var.names=c("SMDH", "SMDH.vi"))

SMDH.sh <- SMDH.sh[,c("obsID", "SMDH", "SMDH.vi")]

lnCVR.sh <- escalc(measure="CVR", 
                   m1i=Shannon_urban,
                   m2i=Shannon_rural,
                   sd1i=SD_shannon_urban,
                   sd2i=SD_shannon_rural,
                   n1i=Nu,
                   n2i=Nr,
                   data=twogroups_sh_SA,
                   var.names=c("lnCVR", "lnCVR.vi"))

lnCVR.sh <- lnCVR.sh[,c("obsID", "lnCVR", "lnCVR.vi")]

lnVR.sh <- escalc(measure="VR", 
                  m1i=Shannon_urban,
                  m2i=Shannon_rural,
                  sd1i=SD_shannon_urban,
                  sd2i=SD_shannon_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_sh_SA,
                  var.names=c("lnVR", "lnVR.vi"))

lnVR.sh <- lnVR.sh[,c("obsID", "lnVR", "lnVR.vi")]


# Simpson
twogroups_si_SA <- meta.final.SA[meta.final.SA$es_type=="tgsi",]
lnRR.si <- escalc(measure="ROM",
                  m1i=Simpson_urban,
                  m2i=Simpson_rural,
                  sd1i=SD_simpson_urban,
                  sd2i=SD_simpson_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_si_SA,
                  var.names=c("lnRR", "lnRR.vi"))

SMDH.si <- escalc(measure="SMDH", 
                  m1i=Simpson_urban,
                  m2i=Simpson_rural,
                  sd1i=SD_simpson_urban,
                  sd2i=SD_simpson_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_si_SA,
                  var.names=c("SMDH", "SMDH.vi"))

SMDH.si <- SMDH.si[,c("obsID", "SMDH", "SMDH.vi")]

lnCVR.si <- escalc(measure="CVR", 
                   m1i=Simpson_urban,
                   m2i=Simpson_rural,
                   sd1i=SD_simpson_urban,
                   sd2i=SD_simpson_rural,
                   n1i=Nu,
                   n2i=Nr,
                   data=twogroups_si_SA,
                   var.names=c("lnCVR", "lnCVR.vi"))

lnCVR.si <- lnCVR.si[,c("obsID", "lnCVR", "lnCVR.vi")]

lnVR.si <- escalc(measure="VR", 
                  m1i=Simpson_urban,
                  m2i=Simpson_rural,
                  sd1i=SD_simpson_urban,
                  sd2i=SD_simpson_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_si_SA,
                  var.names=c("lnVR", "lnVR.vi"))

lnVR.si <- lnVR.si[,c("obsID", "lnVR", "lnVR.vi")]


# Functional diversity
twogroups_fu_SA <- meta.final.SA[meta.final.SA$es_type=="tgfu",]
lnRR.fu <- escalc(measure="ROM",
                  m1i=Fun_urban,
                  m2i=Fun_rural,
                  sd1i=Fun_urban_SD,
                  sd2i=Fun_rural_SD,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_fu_SA,
                  var.names=c("lnRR", "lnRR.vi"))

SMDH.fu <- escalc(measure="SMDH", 
                  m1i=Fun_urban,
                  m2i=Fun_rural,
                  sd1i=Fun_urban_SD,
                  sd2i=Fun_rural_SD,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_fu_SA,
                  var.names=c("SMDH", "SMDH.vi"))

SMDH.fu <- SMDH.fu[,c("obsID", "SMDH", "SMDH.vi")]

lnCVR.fu <- escalc(measure="CVR", 
                   m1i=Fun_urban,
                   m2i=Fun_rural,
                   sd1i=Fun_urban_SD,
                   sd2i=Fun_rural_SD,
                   n1i=Nu,
                   n2i=Nr,
                   data=twogroups_fu_SA,
                   var.names=c("lnCVR", "lnCVR.vi"))

lnCVR.fu <- lnCVR.fu[,c("obsID", "lnCVR", "lnCVR.vi")]

lnVR.fu <- escalc(measure="VR", 
                  m1i=Fun_urban,
                  m2i=Fun_rural,
                  sd1i=Fun_urban_SD,
                  sd2i=Fun_rural_SD,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_fu_SA,
                  var.names=c("lnVR", "lnVR.vi"))

lnVR.fu <- lnVR.fu[,c("obsID", "lnVR", "lnVR.vi")]


# Abundance
twogroups_ab_SA <- meta.final.SA[meta.final.SA$es_type=="tgab",]
lnRR.ab <- escalc(measure="ROM",
                  m1i=abund_urban, 
                  m2i=abund_rural,
                  sd1i=SD_abund_urban,
                  sd2i=SD_abund_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_ab_SA,
                  var.names=c("lnRR", "lnRR.vi"))

SMDH.ab <- escalc(measure="SMDH", 
                  m1i=abund_urban, 
                  m2i=abund_rural,
                  sd1i=SD_abund_urban,
                  sd2i=SD_abund_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_ab_SA,
                  var.names=c("SMDH", "SMDH.vi"))

SMDH.ab <- SMDH.ab[,c("obsID", "SMDH", "SMDH.vi")]

lnCVR.ab <- escalc(measure="CVR", 
                   m1i=abund_urban, 
                   m2i=abund_rural,
                   sd1i=SD_abund_urban,
                   sd2i=SD_abund_rural,
                   n1i=Nu,
                   n2i=Nr,
                   data=twogroups_ab_SA,
                   var.names=c("lnCVR", "lnCVR.vi"))

lnCVR.ab <- lnCVR.ab[,c("obsID", "lnCVR", "lnCVR.vi")]

lnVR.ab <- escalc(measure="VR", 
                  m1i=abund_urban, 
                  m2i=abund_rural,
                  sd1i=SD_abund_urban,
                  sd2i=SD_abund_rural,
                  n1i=Nu,
                  n2i=Nr,
                  data=twogroups_ab_SA,
                  var.names=c("lnVR", "lnVR.vi"))

lnVR.ab <- lnVR.ab[,c("obsID", "lnVR", "lnVR.vi")]


# putting together all the lnRR databases created above
meta.final.SA <- as.data.frame(rbind(lnRR.ri,
                                     lnRR.sh,
                                     lnRR.si,
                                     lnRR.fu,
                                     lnRR.ab))

# putting together all the SMDH databases created above
meta.final.SMDH.SA <- as.data.frame(rbind(SMDH.ri,
                                          SMDH.sh,
                                          SMDH.si,
                                          SMDH.fu,
                                          SMDH.ab))

# putting together all the lnCVR databases created above
meta.final.lnCVR.SA <- as.data.frame(rbind(lnCVR.ri,
                                           lnCVR.sh,
                                           lnCVR.si,
                                           lnCVR.fu,
                                           lnCVR.ab))

# putting together all the lnVR databases created above
meta.final.lnVR.SA <- as.data.frame(rbind(lnVR.ri,
                                          lnVR.sh,
                                          lnVR.si,
                                          lnVR.fu,
                                          lnVR.ab))

# merging them by obsID
meta.final.SA <- merge(meta.final.SA, meta.final.SMDH.SA, by="obsID", all.x=T)
meta.final.SA <- merge(meta.final.SA, meta.final.lnCVR.SA, by="obsID", all.x=T)
meta.final.SA <- merge(meta.final.SA, meta.final.lnVR.SA, by="obsID", all.x=T)

# There is one NA for lnRR because of one mean = 0, which makes sense for that 
# result. Otherwise, although richness and alike could be theoretically 0 (no 
# species found), it is generally not expected to be the case (i.e. we generally
# expect to find some animal species (on average). Indeed, only one mean = 0 and
# thus, we are going to treat the biodiversity indices as ratio scale data for 
# the purposes of the sensitivity analyses.

# There are three NA's for the lnCVR due to 3 SD's being 0, which as described
# above are true cases of SD = 0, and thus, we did not try to impute them.


# output dataset
write.csv(meta.final.SA[,c("obsID", "studyID", "comparisonID", "locationID",
                           "authors", "title", "year", "notes",
                           "lnRR", "lnRR.vi",
                           "SMDH", "SMDH.vi",
                           "lnCVR", "lnCVR.vi",
                           "lnVR", "lnVR.vi",
                           "Nr", "Nu", "Nt", "es_type", "inferential_type",
                           "method",  "continent", "scale", "diversity",
                           "Class", "Order", "Family")],
          file= "meta_final_reduced_sensitivity_analyses.csv", row.names=FALSE)


############################################################
# testing whether ln(mean) and ln(SD) are correlated across
############################################################

# preparing the data quickly. First for richness
twogroups_ri_SA.rural <- twogroups_ri_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "Richness_rural", 
                                            "SD_richness_rural")]

names(twogroups_ri_SA.rural) <- c("obsID", "studyID", "comparisonID",
                                  "locationID", "mean", "SD")

twogroups_ri_SA.rural$origin.1 <- "rural"
twogroups_ri_SA.rural$origin.2 <- "richness"

twogroups_ri_SA.urban <- twogroups_ri_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "Richness_urban", 
                                            "SD_richness_urban")]

names(twogroups_ri_SA.urban) <- c("obsID", "studyID", "comparisonID", 
                                  "locationID", "mean", "SD")

twogroups_ri_SA.urban$origin.1 <- "urban"
twogroups_ri_SA.urban$origin.2 <- "richness"


# Second for Shannon
twogroups_sh_SA.rural <- twogroups_sh_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "Shannon_rural", 
                                            "SD_shannon_rural")]

names(twogroups_sh_SA.rural) <- c("obsID", "studyID", "comparisonID",
                                  "locationID", "mean", "SD")

twogroups_sh_SA.rural$origin.1 <- "rural"
twogroups_sh_SA.rural$origin.2 <- "shannon"

twogroups_sh_SA.urban <- twogroups_sh_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "Shannon_urban",
                                            "SD_shannon_urban")]

names(twogroups_sh_SA.urban) <- c("obsID", "studyID", "comparisonID", 
                                  "locationID", "mean","SD")

twogroups_sh_SA.urban$origin.1 <- "urban"
twogroups_sh_SA.urban$origin.2 <- "shannon"


# Third for Simpson
twogroups_si_SA.rural <- twogroups_si_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "Simpson_rural",
                                            "SD_simpson_rural")]

names(twogroups_si_SA.rural) <- c("obsID", "studyID", "comparisonID",
                                  "locationID", "mean", "SD")

twogroups_si_SA.rural$origin.1 <- "rural"
twogroups_si_SA.rural$origin.2 <- "simpson"

twogroups_si_SA.urban <- twogroups_si_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "Simpson_urban",
                                            "SD_simpson_urban")]

names(twogroups_si_SA.urban) <- c("obsID", "studyID", "comparisonID",
                                  "locationID", "mean", "SD")

twogroups_si_SA.urban$origin.1 <- "urban"
twogroups_si_SA.urban$origin.2 <- "simpson"


# Fourth for Functional
twogroups_fu_SA.rural <- twogroups_fu_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "Fun_rural",
                                            "Fun_rural_SD")]

names(twogroups_fu_SA.rural) <- c("obsID", "studyID", "comparisonID", 
                                  "locationID", "mean", "SD")

twogroups_fu_SA.rural$origin.1 <- "rural"
twogroups_fu_SA.rural$origin.2 <- "functional"

twogroups_fu_SA.urban <- twogroups_fu_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "Fun_urban",
                                            "Fun_urban_SD")]

names(twogroups_fu_SA.urban) <- c("obsID", "studyID", "comparisonID",
                                  "locationID", "mean", "SD")

twogroups_fu_SA.urban$origin.1 <- "urban"
twogroups_fu_SA.urban$origin.2 <- "functional"


# Fifth for Abundance
twogroups_ab_SA.rural <- twogroups_ab_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "abund_rural",
                                            "SD_abund_rural")]

names(twogroups_ab_SA.rural) <- c("obsID", "studyID", "comparisonID", 
                                  "locationID", "mean", "SD")

twogroups_ab_SA.rural$origin.1 <- "rural"
twogroups_ab_SA.rural$origin.2 <- "functional"

twogroups_ab_SA.urban <- twogroups_ab_SA[,c("obsID", "studyID", "comparisonID",
                                            "locationID", "abund_urban",
                                            "SD_abund_urban")]

names(twogroups_ab_SA.urban) <- c("obsID", "studyID", "comparisonID",
                                  "locationID", "mean", "SD")

twogroups_ab_SA.urban$origin.1 <- "urban"
twogroups_ab_SA.urban$origin.2 <- "functional"


#Unite
lnSD.lnmean.cor <- rbind(twogroups_ri_SA.rural, twogroups_ri_SA.urban,
                         twogroups_sh_SA.rural, twogroups_sh_SA.urban,
                         twogroups_si_SA.rural, twogroups_si_SA.urban,
                         twogroups_fu_SA.rural, twogroups_fu_SA.urban,
                         twogroups_ab_SA.rural, twogroups_ab_SA.urban)


# calculating the log of the variables
lnSD.lnmean.cor$lnmean <- log(lnSD.lnmean.cor$mean)
lnSD.lnmean.cor$lnSD <- log(lnSD.lnmean.cor$SD)


# reducing dataset to those values that are not -Inf (1 for lnmean, 3 for lnSD)
lnSD.lnmean.cor.no.Inf <- lnSD.lnmean.cor[lnSD.lnmean.cor$lnmean!=-Inf & 
                                            lnSD.lnmean.cor$lnSD!=-Inf,] 


# testing the correlation between those two, if strong, there is good evidence
# for Taylor's law, and thus, using lnCVR is supported
cor.test(lnSD.lnmean.cor.no.Inf$lnmean, lnSD.lnmean.cor.no.Inf$lnSD)


#Ploting ln(mean) vs ln(SD)
############################

# theme for the plots
tm <- theme(panel.background = element_blank(),
            axis.line = element_line(size = 0.75),
            axis.text = element_text(size = 10, colour = "black"),
            axis.title = element_text(size = 12),
            plot.title = element_text(size = 16, hjust = 0.5))

#lnmean and lnsd subset for urban and rural
lnSD.lnmean.cor.no.Inf.rural <- lnSD.lnmean.cor.no.Inf[which(lnSD.lnmean.cor.no.Inf$origin.1=="rural"),]
cor.test(lnSD.lnmean.cor.no.Inf.rural$lnmean, lnSD.lnmean.cor.no.Inf.rural$lnSD)
lnSD.lnmean.cor.no.Inf.urban <- lnSD.lnmean.cor.no.Inf[which(lnSD.lnmean.cor.no.Inf$origin.1=="urban"),]
cor.test(lnSD.lnmean.cor.no.Inf.urban$lnmean, lnSD.lnmean.cor.no.Inf.urban$lnSD)


rural.plot <- ggplot(lnSD.lnmean.cor.no.Inf.rural, aes(x = lnmean, y = lnSD,)) +
  geom_point(alpha = 0.25) + tm + labs(x = "ln(mean)", y = "ln(SD)") +
  xlim(-10, 10) +
  ylim(-10, 10) +
  geom_smooth(method = lm, se=FALSE) + 
  annotate(geom = "text", x = -4.5, y = 8.0, label = "A: Rural",size=5)+
  annotate(geom = "text", x = -4.5, y = 6.5, label = "pearson: 0.88",size=5)+
  theme(legend.position = c(0.85, 0.25),
        legend.title = element_text(size = 12),
        legend.text = element_text(size = 12),
        legend.key = element_rect(fill = alpha("white", 0.0)))

urban.plot <- ggplot(lnSD.lnmean.cor.no.Inf.urban, aes(x = lnmean, y = lnSD,)) +
  geom_point(alpha = 0.25) + tm + labs(x = "ln(mean)", y = "ln(SD)") +
  xlim(-10, 10) +
  ylim(-10, 10) +
  geom_smooth(method = lm, se=FALSE) + 
  annotate(geom = "text", x = -4.5, y = 8.0, label = "B: Urban", size = 5)+
  annotate(geom = "text", x = -4.5, y = 6.5, label = "pearson: 0.87", size = 5)+
  theme(legend.position = c(0.85, 0.25),
        legend.title = element_text(size = 12),
        legend.text = element_text(size = 12),
        legend.key = element_rect(fill = alpha("white", 0.0)))


# multipannel plot
tiff("figures/mean_vs_sd.tiff",
     height=10.5, width=20.5,
     units='cm', compression="lzw", res=800)

ggarrange(rural.plot, urban.plot,
          ncol = 2, nrow = 1)

dev.off()
