################################################################################
# Authors: 
# Alfredo Sanchez-Tojar (with support from Endika Blanco)

# Script first created in Nov 2018

################################################################################
# Description of script and Instructions
################################################################################

# This script is for a meta-analysis on the effect of urbanization on 
# biodiversity.

################################################################################
# Packages needed
################################################################################

# Clear memory
rm(list = ls())

###install.packages("pacman")
# devtools::install_github("itchyshin/orchard_plot", subdir = "orchaRd", 
#                          force = TRUE, build_vignettes = TRUE)
# devtools::install_github("daniel1noble/orchaRd", force = TRUE)
pacman::p_load(devtools, tidyverse, metafor, patchwork, R.rsp, orchaRd, emmeans,
               ape, phytools, report, car) #dplyr, ggplot2
pacman::p_load(knitr, DT, readxl, ggplot2, pander, formatR, rmdformats)

################################################################################
# Importing the data (from script 'data_preparation_arth.R')
################################################################################

meta.final <- read.table("meta_final_reduced.csv", header=T, sep=",")

# Modifying variables type
meta.final$studyID <- as.factor(meta.final$studyID)
meta.final$es_type <- as.factor(meta.final$es_type)


# Creating a new variable to categorize effects as biserial correlations, 
# Pearson's correlation coefficients or effects from inferential statistics
meta.final$es_type_2 <- as.factor(ifelse(meta.final$es_type %in% 
                                           c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                         "biserial_correlation",
                                         ifelse(meta.final$es_type %in% 
                                                  c("pearsons", "spearmans"),
                                                "correlation_coefficient",
                                                "inferential_statistic")))

# METHOD
# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final <- as.data.frame(meta.final %>% 
                              mutate(method= 
                                       factor(method, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# Generating a new method that accounts for the fact that for some of the data
# originally reported as gradients we later on had to extract only the extremes
# (i.e. most urbanized vs least urbanized), normally from figures, to be able to
# calculate biserial correlations. In these cases, these estimates are going to
# now be categorized as "Urban-Rural" as the original continuous nature of the
# measurement was then changed
meta.final$method.recat <- ifelse(as.character(meta.final$method) %in% 
                                    c("Urban Gradient") &
                                    as.character(meta.final$es_type) %in% 
                                    c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                  "Urban-Rural", 
                                  as.character(meta.final$method))

# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final <- as.data.frame(meta.final %>% 
                              mutate(method.recat= 
                                       factor(method.recat, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# CONTINENT
# We reorder the levels so that the reference level (intercept) is Europe
meta.final <- as.data.frame(meta.final %>%
                              mutate(continent=
                                       factor(continent, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Oceania",
                                                       "Africa"))))


# since sample sizes were to small for the original idea, we have recoded the 
# factor so that the sample sizes are decent and still biologically meaningful
meta.final$continent.2 <- as.factor(ifelse(meta.final$continent=="Africa" | 
                                             meta.final$continent=="Oceania", 
                                           "Others", as.character(meta.final$continent)))

table(meta.final$continent.2)

# We reorder the levels so that the reference level (intercept) is Europe
meta.final <- as.data.frame(meta.final %>%
                              mutate(continent.2=
                                       factor(continent.2, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Others"))))


# SCALE
# We reorder the levels so that the reference level (intercept) is City. The 
# order of goes from smaller to larger scale
meta.final <- as.data.frame(meta.final %>% 
                              mutate(scale= 
                                       factor(scale, 
                                              levels=c("City",
                                                       "Local",
                                                       "Regional"))))


# DIVERSITY
# We reorder the levels so that the reference level (intercept) is Richness, but
# first we recode the level names to make them more informative and standardized
meta.final$diversity <- dplyr::recode(meta.final$diversity, 
                                      "Other taxonomic diversity measure"= 
                                        "Taxonomic diversity: others", #to keep consistency with the other analyses, also shorter names are better for the plots and tables
                                      "Richness"="Taxonomic diversity: richness")

meta.final <- as.data.frame(meta.final %>% 
                              mutate(diversity= 
                                       factor(diversity, 
                                              levels=c("Taxonomic diversity: richness",
                                                       "Taxonomic diversity: others",
                                                       "Functional diversity",
                                                       "Abundance"))))


# CLASS
# Customizing the order of the factor levels. We reorder the levels so that the 
# reference level (intercept) is Insecta
meta.final <- as.data.frame(meta.final %>% 
                              mutate(Class = factor(Class, 
                                                    levels=c("Insecta",
                                                             "Arachnida",
                                                             "Crustacea",
                                                             "Myriapoda",
                                                             "Entognatha"))))


# ORDER
table(meta.final$Order)

#Subset for Insect Orders (Orders of the rest of Classes too small)
meta.final$Order.2 <- ifelse(as.character(meta.final$Order) %in% 
                               c("Araneae", "Decapoda", "Diplostraca",
                                 "Harpacticoida", "Isopoda", "Ixodida",
                                 "Opiliones", "Spirostreptida",
                                 "Diplostraca", "Trombidiformes"),
                             "Non-Insect Orders", 
                             as.character(meta.final$Order))

meta.final$Order.2 <- factor(meta.final$Order.2)
table(meta.final$Order.2)


#Subset for Insect Orders, after unifying EPT orders into EPT.
meta.final$Order.3 <- ifelse(as.character(meta.final$Order.2) %in% 
                               c("Ephemeroptera","Plecoptera","Trichoptera"),
                             "EPT", 
                             as.character(meta.final$Order.2))

# We reorder the levels
meta.final <- as.data.frame(meta.final %>%
                              mutate(Order.3=
                                       factor(Order.3, 
                                              levels=c("Coleoptera",
                                                       "Diptera",
                                                       "EPT",
                                                       "Hemiptera",
                                                       "Hymenoptera",
                                                       "Lepidoptera",
                                                       "Odonata",
                                                       "Orthoptera",
                                                       "Non-Insect Orders"))))

meta.final$Order.3 <- factor(meta.final$Order.3)
table(meta.final$Order.3)


# FAMILY
table(meta.final$Family)

#Joining "Apidae" to "Antophila" clade
meta.final$Family.2 <- factor(meta.final$Family)
meta.final$Family.2 <- ifelse(as.character(meta.final$Family.2) %in% 
                                c("Apidae"), "Apoidea", 
                              as.character(meta.final$Family.2))

#Subset for Insect Families with enough data (10<)
meta.final$Family.2 <- ifelse(as.character(meta.final$Family.2) %in% 
                                c("Anisoptera", "bat-flies", "Chironomidae",
                                  "Chloropidae", "Coccinellidae", "Cynipidae",
                                  "Geometridae", "Hydrachnidia", "Psychodidae",
                                  "Sarcophagidae", "Scarabaeidae", "Silphidae",
                                  "Sphecidae", "Staphylinidae", "Syrphidae",
                                  "Tachinidae", "Tenebrionidae", "Thomisidae",
                                  "Vespidae", "Zygoptera"),
                              "Other Families", 
                              as.character(meta.final$Family.2))

meta.final$Family.2 <- factor(meta.final$Family.2)
table(meta.final$Family.2)


#subset for abundance data
meta.final.abundance <- meta.final[meta.final$diversity=="Abundance",]


################################################################################
# Sampling variance-covariance matrix
################################################################################

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.ab <- matrix(0, nrow = nrow(meta.final.abundance), 
                              ncol = nrow(meta.final.abundance))

# names rows and columns for each obsID
rownames(VCV_ESVar.ab) <- meta.final.abundance[, "obsID"]
colnames(VCV_ESVar.ab) <- meta.final.abundance[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.ab <- which(meta.final.abundance[, "studyID"] %in% 
                                  meta.final.abundance[duplicated(meta.final.abundance[,"studyID"]), 
                                                       "studyID"] == TRUE)

combinations.ab <- do.call("rbind", tapply(shared_coord.ab, 
                                                  meta.final.abundance[shared_coord.ab,"studyID"], 
                                                  function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.ab)[1]) {
  p1 <- combinations.ab[i, 1]
  p2 <- combinations.ab[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.abundance[p1, "Vr"]) * 
    sqrt(meta.final.abundance[p2, "Vr"])
  VCV_ESVar.ab[p1, p2] <- p1_p2_cov
  VCV_ESVar.ab[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.ab) <- meta.final.abundance[, "Vr"]


################################################################################
# META-ANALYSIS
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.abundance$r, meta.final.abundance$Vr, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.abundance$r, meta.final.abundance$Vr, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.ab <- rma.mv(r, VCV_ESVar.ab, 
                     mods = ~ 1,
                     random = list(~ 1 | studyID,
                                   ~ 1 | comparisonID,
                                   ~ 1 | locationID,
                                   ~ 1 | obsID), 
                     method = "REML", 
                     test = "t", 
                     data = meta.final.abundance)

# Printing the summary results of the model
print(meta.model.ab, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.ab, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.ab)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.ab,col=meta.final.abundance$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.ab)
plot(1:nrow(meta.final.abundance), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.ab)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS
################################################################################

#############################
# Class using abundance only
#############################

# To test if the Class influences the effect size
metareg.Class.ab <- rma.mv(r, VCV_ESVar.ab, 
                        mods = ~ Class, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final.abundance)

print(metareg.Class.ab, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class <- r2_ml(metareg.Class.ab)
round(R2.Class*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.ab.no.int <- rma.mv(r, VCV_ESVar.ab, 
                               mods = ~ Class - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final.abundance)

print(metareg.Class.ab.no.int, digits=3)


tiff("figures/05_Class_abundance.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.ab.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.abundance,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-1.85, 1.5), breaks = c(seq(-1.5, 1.5, 0.5))) +
  annotate(geom = "text", x = 5.40, y = -1.54, 
           label = paste0("italic(R)^{2} == ", round(R2.Class[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -1.20, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
# Insecta and Arachnida are the only groups with more than 10 data points.
car::linearHypothesis(metareg.Class.ab, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.ab, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.ab, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.ab, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.ab, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.ab, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


#############################
# Order using abundance only
#############################

# To test if the Order influences the effect size
metareg.Order.ab <- rma.mv(r, VCV_ESVar.ab, 
                        mods = ~ Order.2, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final.abundance)

print(metareg.Order.ab, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order <- r2_ml(metareg.Order.ab)
round(R2.Order*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.ab.no.int <- rma.mv(r, VCV_ESVar.ab, 
                               mods = ~ Order.2 - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final.abundance)

print(metareg.Order.ab.no.int, digits=3)


tiff("figures/06_Order_Insecta_abundance.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.ab.no.int, mod = "Order.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.abundance,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 12.7, y = -1.70, 
           label = paste0("italic(R)^{2} == ", round(R2.Order[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 12.62, y = -1.22, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.ab, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.ab, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.ab, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.ab, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.ab, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.ab, rbind(c(0, 0, 0, 1, -1))) #  vs. 


###################################
# Order (EPT) using abundance only
###################################

# To test if the Order influences the effect size
metareg.Order.EPT.ab <- rma.mv(r, VCV_ESVar.ab, 
                            mods = ~ Order.3, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final.abundance)

print(metareg.Order.EPT.ab, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.EPT <- r2_ml(metareg.Order.EPT.ab)
round(R2.Order.EPT*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.EPT.ab.no.int <- rma.mv(r, VCV_ESVar.ab, 
                                   mods = ~ Order.3 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final.abundance)

print(metareg.Order.EPT.ab.no.int, digits=3)


tiff("figures/06_Order_EPT_abundance.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.EPT.ab.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.abundance,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 9.60, y = -1.70, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.EPT[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 9.52, y = -1.22, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
# Hemiptera, Odonata and Orthoptera not considered as n<10
car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 1, -1, 0, 0, 0, 0, 0, 0))) # Diptera vs. EPT
car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 1, 0, 0, -1, 0, 0, 0, 0))) # Diptera vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 1, 0, 0, 0, -1, 0, 0, 0))) # Diptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 1, 0, 0, 0, 0, 0, 0, -1))) # Diptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 0, 1, 0, -1, 0, 0, 0, 0))) # EPT vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 0, 1, 0, 0, -1, 0, 0, 0))) # EPT vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 0, 1, 0, 0, 0, 0, 0, -1))) # EPT vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 0, 0, 0, 1, -1, 0, 0, 0))) # Hymenoptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 0, 0, 0, 0, 0, 0, 0, -1))) # Hymenoptera vs. Non - Insect Orders
car::linearHypothesis(metareg.Order.EPT.ab, rbind(c(0, 0, 0, 0, 0, 1, 0, 0, -1))) # Lepidoptera vs. Non - Insect Orders


################################################################################
# Family using abundance only
################################################################################

# To test if the Family influences the effect size
metareg.Family.ab <- rma.mv(r, VCV_ESVar.ab, 
                            mods = ~ Family.2, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final.abundance)

print(metareg.Family.ab, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.ab <- r2_ml(metareg.Family.ab)
round(R2.Family.ab*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.ab.no.int <- rma.mv(r, VCV_ESVar.ab, 
                                   mods = ~ Family.2 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final.abundance)

print(metareg.Family.ab.no.int, digits=3)


tiff("figures/07_Family_abundance.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.ab.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.abundance,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -1.7, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.ab[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -1.25, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
# Calliphoridae, Culicidae and Drosophilidae not considered in comparations
# because of the low number of data (n<10).
car::linearHypothesis(metareg.Family.ab, rbind(c(0, 0, 1, 0, 0, -1, 0))) # Carabidae vs. Formicidae
car::linearHypothesis(metareg.Family.ab, rbind(c(0, 0, 1, 0, 0, 0, -1))) # Carabidae vs. Other Families
car::linearHypothesis(metareg.Family.ab, rbind(c(0, 0, 0, 0, 0, 1, -1))) # Formicidae vs. Other Families

