################################################################################
# Authors: 
# Alfredo Sanchez-Tojar (with support from Endika Blanco)

# Script first created in Nov 2018

################################################################################
# Description of script and Instructions
################################################################################

# This script is for a meta-analysis on the effect of urbanization on 
# biodiversity.

################################################################################
# Packages needed
################################################################################

# Clear memory
rm(list = ls())


#install.packages("pacman")
#pacman::p_load(devtools, tidyverse, metafor, patchwork, R.rsp, orchaRd, emmeans,
#               ape, phytools, report, car) #dplyr, ggplot2
#pacman::p_load(knitr, DT, readxl, ggplot2, pander, formatR, rmdformats)
#devtools::install_github("itchyshin/orchard_plot", subdir = "orchaRd", 
#                         force = TRUE, build_vignettes = TRUE)
#devtools::install_github("daniel1noble/orchaRd", force = TRUE)

pacman::p_load(ape,metafor,rotl,treebase,dplyr,stringr,ggplot2,tidyverse,
               devtools, patchwork, R.rsp, emmeans)# packages for rma.mv optimizers used below

devtools::install_github("daniel1noble/orchaRd", force = TRUE)

library(orchaRd)


################################################################################
# Importing the data (from script 'data_preparation_arth.R')
################################################################################

meta.final <- read.table("meta_final_reduced.csv", header=T, sep=",")

# Modifying variables type
meta.final$studyID <- as.factor(meta.final$studyID)
meta.final$es_type <- as.factor(meta.final$es_type)


# Creating a new variable to categorize effects as biserial correlations, 
# Pearson's correlation coefficients or effects from inferential statistics
meta.final$es_type_2 <- as.factor(ifelse(meta.final$es_type %in% 
                                         c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                         "biserial_correlation",
                                         ifelse(meta.final$es_type %in% 
                                                  c("pearsons", "spearmans"),
                                                "correlation_coefficient",
                                                "inferential_statistic")))

# METHOD
# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final <- as.data.frame(meta.final %>% 
                              mutate(method= 
                                       factor(method, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# Generating a new method that accounts for the fact that for some of the data
# originally reported as gradients we later on had to extract only the extremes
# (i.e. most urbanized vs least urbanized), normally from figures, to be able to
# calculate biserial correlations. In these cases, these estimates are going to
# now be categorized as "Urban-Rural" as the original continuous nature of the
# measurement was then changed
meta.final$method.recat <- ifelse(as.character(meta.final$method) %in% 
                                    c("Urban Gradient") &
                                    as.character(meta.final$es_type) %in% 
                                    c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                  "Urban-Rural", 
                                  as.character(meta.final$method))

# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final <- as.data.frame(meta.final %>% 
                              mutate(method.recat= 
                                       factor(method.recat, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# CONTINENT
# We reorder the levels so that the reference level (intercept) is Europe
meta.final <- as.data.frame(meta.final %>%
                              mutate(continent=
                                       factor(continent, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Oceania",
                                                       "Africa"))))


# since sample sizes were to small for the original idea, we have recoded the 
# factor so that the sample sizes are decent and still biologically meaningful
meta.final$continent.2 <- as.factor(ifelse(meta.final$continent=="Africa" | 
                                             meta.final$continent=="Oceania", 
                                           "Others", as.character(meta.final$continent)))

table(meta.final$continent.2)

# We reorder the levels so that the reference level (intercept) is Europe
meta.final <- as.data.frame(meta.final %>%
                              mutate(continent.2=
                                       factor(continent.2, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Others"))))


# SCALE
# We reorder the levels so that the reference level (intercept) is City. The 
# order of goes from smaller to larger scale
meta.final <- as.data.frame(meta.final %>% 
                              mutate(scale= 
                                       factor(scale, 
                                              levels=c("City",
                                                       "Local",
                                                       "Regional"))))


# DIVERSITY
# We reorder the levels so that the reference level (intercept) is Richness, but
# first we recode the level names to make them more informative and standardized
meta.final$diversity <- dplyr::recode(meta.final$diversity, 
                                      "Other taxonomic diversity measure"= 
                                        "Taxonomic diversity: others", #to keep consistency with the other analyses, also shorter names are better for the plots and tables
                                      "Richness"="Taxonomic diversity: richness")

meta.final <- as.data.frame(meta.final %>% 
                              mutate(diversity= 
                                       factor(diversity, 
                                              levels=c("Taxonomic diversity: richness",
                                                       "Taxonomic diversity: others",
                                                       "Functional diversity",
                                                       "Abundance"))))


# CLASS
# Customizing the order of the factor levels. We reorder the levels so that the 
# reference level (intercept) is Insecta
meta.final <- as.data.frame(meta.final %>% 
                              mutate(Class = factor(Class, 
                                                   levels=c("Insecta",
                                                            "Arachnida",
                                                            "Crustacea",
                                                            "Myriapoda",
                                                            "Entognatha"))))


# ORDER
table(meta.final$Order)

#Subset for Insect Orders (Orders of the rest of Classes too small)
meta.final$Order.2 <- ifelse(as.character(meta.final$Order) %in% 
                       c("Araneae", "Decapoda", "Diplostraca",
                         "Harpacticoida", "Isopoda", "Ixodida",
                         "Opiliones", "Spirostreptida",
                         "Diplostraca", "Trombidiformes"),
                     "Non-Insect Orders", 
                     as.character(meta.final$Order))

meta.final$Order.2 <- factor(meta.final$Order.2)
table(meta.final$Order.2)


#Subset for Insect Orders, after unifying EPT orders into EPT.
meta.final$Order.3 <- ifelse(as.character(meta.final$Order.2) %in% 
                                    c("Ephemeroptera","Plecoptera","Trichoptera"),
                                  "EPT", 
                                  as.character(meta.final$Order.2))

# We reorder the levels
meta.final <- as.data.frame(meta.final %>%
                                 mutate(Order.3=
                                          factor(Order.3, 
                                                 levels=c("Coleoptera",
                                                          "Diptera",
                                                          "EPT",
                                                          "Hemiptera",
                                                          "Hymenoptera",
                                                          "Lepidoptera",
                                                          "Odonata",
                                                          "Orthoptera",
                                                          "Non-Insect Orders"))))

meta.final$Order.3 <- factor(meta.final$Order.3)
table(meta.final$Order.3)


# FAMILY
table(meta.final$Family)

#Joining "Apidae" to "Apoidea" superfamily
meta.final$Family.2 <- factor(meta.final$Family)
meta.final$Family.2 <- ifelse(as.character(meta.final$Family.2) %in% 
                               c("Apidae"), "Apoidea", 
                             as.character(meta.final$Family.2))

#Subset for Insect Families with enough data (10<)
meta.final$Family.2 <- ifelse(as.character(meta.final$Family.2) %in% 
                               c("Anisoptera", "bat-flies", "Chironomidae",
                                 "Chloropidae", "Coccinellidae", "Cynipidae",
                                 "Geometridae", "Hydrachnidia", "Psychodidae",
                                 "Sarcophagidae", "Scarabaeidae", "Silphidae",
                                 "Sphecidae", "Staphylinidae", "Syrphidae",
                                 "Tachinidae", "Tenebrionidae", "Thomisidae",
                                 "Vespidae", "Zygoptera"),
                             "Other Families", 
                             as.character(meta.final$Family.2))

meta.final$Family.2 <- factor(meta.final$Family.2)
table(meta.final$Family.2)


################################################################################
# Sampling variance-covariance matrix
################################################################################

# We specified sampling variance as a variance-covariance matrix, with the 
# sampling variance for each effect size on the diagonal, and the covariance 
# between these measures as off-diagonal elements. The model assumed a 0.5 
# correlation between the effect size sample variances with the same studyID. 
# For a similar approach, see O'Dea et al., 2019
# (https://doi.org/10.1111/faf.12394)or Kim et al. 2022 
# (https://doi.org/10.1111/1365-2656.13554), from which this code was taken from.

### Creating a var-covar matrix assuming a 0.5 correlation between effect sizes 
# from the same studyID covariance = (0.5 * sqrt(vi.1) * sqrt(vi.2))

# Creates a matrix (called 'VCV_ESVar') with the dimensions =  
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar <- matrix(0, nrow=nrow(meta.final), ncol=nrow(meta.final))

# Names rows and columns for each obsID
rownames(VCV_ESVar) <- meta.final[,"obsID"]
colnames(VCV_ESVar) <- meta.final[,"obsID"]

# Finds effect sizes that come from the same study
shared_coord <- which(meta.final[,"studyID"] %in% 
                        meta.final[duplicated(meta.final[,"studyID"]), 
                                   "studyID"]==TRUE)

combinations <- do.call("rbind", tapply(shared_coord, 
                                        meta.final[shared_coord, "studyID"], 
                                        function(x) t(utils::combn(x, 2))))

# Calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations)[1]) {
  p1 <- combinations[i, 1]
  p2 <- combinations[i, 2]
  p1_p2_cov <- 0.5*sqrt(meta.final[p1, "Vr"])*sqrt(meta.final[p2, "Vr"])
  VCV_ESVar[p1, p2] <- p1_p2_cov
  VCV_ESVar[p2, p1] <- p1_p2_cov
} 

# Enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar) <- meta.final[,"Vr"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar, 'VCV_ESVar.csv')


################################################################################
# META-ANALYSIS
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final$r, meta.final$Vr, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final$r, meta.final$Vr, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model <- rma.mv(r, VCV_ESVar, 
                     mods = ~ 1,
                     random = list(~ 1 | studyID,
                                   ~ 1 | comparisonID,
                                   ~ 1 | locationID,
                                   ~ 1 | obsID), 
                     method = "REML", 
                     test = "t", 
                     data = meta.final)

# Printing the summary results of the model
print(meta.model, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model,col=meta.final$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model)
plot(1:nrow(meta.final), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS
################################################################################

####################
# Method (original)
####################

# To test if the method influences the effect size
metareg.method <- rma.mv(r, VCV_ESVar, 
                         mods = ~ method, 
                         random = list(~ 1 | studyID,
                                       ~ 1 | comparisonID,
                                       ~ 1 | locationID,
                                       ~ 1 | obsID),
                         method = "REML", 
                         test = "t", 
                         data = meta.final)

print(metareg.method, digits=2)

# Calculate marginal R2 with r2_ml
R2.method <- r2_ml(metareg.method)
round(R2.method*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.method.no.int <- rma.mv(r, VCV_ESVar, 
                                mods = ~ method - 1, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final)

print(metareg.method.no.int, digits=3)


tiff("figures/01_Methods.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.method.no.int, mod = "method", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.39, 0.085),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction ="horizontal",
        legend.title = element_text(size = 10),
        legend.text = element_text(size = 10)) +
  theme(axis.title = element_text(size = 12)) +
  theme(axis.text = element_text(size = 12)) +
  theme(axis.text.y = element_text(size = 12)) +
  scale_y_continuous(limits = c(-1.9, 1.5), breaks = c(seq(-1.5, 1.5, 0.5))) +
  annotate(geom = "text", x = 4.44, y = -1.43, 
           label = paste0("italic(R)^{2} == ", round(R2.method[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 4.42, y = -1.19, label = "%", color = "black", 
           parse = FALSE, size = 5)

dev.off()

# Compare the remaining factor levels
car::linearHypothesis(metareg.method, rbind(c(0, 1, -1, 0))) # City Comparison vs. Urban-Rural
car::linearHypothesis(metareg.method, rbind(c(0, 1, 0, -1))) # City Comparison vs. Temporal Urban Gradient
car::linearHypothesis(metareg.method, rbind(c(0, 0, 1, -1))) # Urban-Rural vs. Temporal Urban Gradient


########################
# Method (recategorized)
########################

# To test if the method influences the effect size
metareg.method.recat <- rma.mv(r, VCV_ESVar, 
                               mods = ~ method.recat, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final)

print(metareg.method.recat, digits=2)

# Calculate marginal R2 with r2_ml
R2.method.recat <- r2_ml(metareg.method.recat)
round(R2.method.recat*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.method.recat.no.int <- rma.mv(r, VCV_ESVar, 
                                      mods = ~ method.recat - 1, 
                                      random = list(~ 1 | studyID,
                                                    ~ 1 | comparisonID,
                                                    ~ 1 | locationID,
                                                    ~ 1 | obsID),
                                      method = "REML", 
                                      test = "t", 
                                      data = meta.final)

print(metareg.method.recat.no.int, digits=3)


tiff("figures/01_Methods_recategorized3.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.method.recat.no.int, mod = "method.recat", 
             group = "studyID",
             xlab = "Effect size (r)", 
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.5, 0.11),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 8),
        legend.text = element_text(size = 8)) +
  theme(axis.title = element_text(size = 12)) +
  theme(axis.text = element_text(size = 12)) +
  theme(axis.text.y = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2.5, 2.5), breaks = c(seq(-2.5, 2.5, 0.5))) +
  annotate(geom = "text", x = 4.4, y = -2.1, 
           label = paste0("italic(R)^{2} == ", round(R2.method.recat[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 4.36, y = -1.55, label = "%", color = "black", 
           parse = FALSE, size = 5)

dev.off()

# Compare the remaining factor levels
car::linearHypothesis(metareg.method.recat, rbind(c(0, 1, -1, 0))) # City Comparison vs. Urban-Rural
car::linearHypothesis(metareg.method.recat, rbind(c(0, 1, 0, -1))) # City Comparison vs. Temporal Urban Gradient
car::linearHypothesis(metareg.method.recat, rbind(c(0, 0, 1, -1))) # Urban-Rural vs. Temporal Urban Gradient


#################
# Continent
#################

# To test if the continent influences the effect size
metareg.continent <- rma.mv(r, VCV_ESVar, 
                            mods = ~ continent, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final)

print(metareg.continent, digits=2)

# Calculate marginal R2 with r2_ml
R2.continent <- r2_ml(metareg.continent)
round(R2.continent*100, 1)


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.no.int <- rma.mv(r, VCV_ESVar, 
                                   mods = ~ continent - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final)

print(metareg.continent.no.int, digits=3)


tiff("figures/02_Continent.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.no.int, mod = "continent", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.46, 0.077),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-1.9, 1.5), breaks = c(seq(-1.5, 1.5, 0.5))) +
  annotate(geom = "text", x = 6.43, y = -1.6, 
           label = paste0("italic(R)^{2} == ", round(R2.continent[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 6.40, y = -1.25, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.continent, rbind(c(0, 1, -1, 0, 0, 0))) # North America vs. South America
car::linearHypothesis(metareg.continent, rbind(c(0, 1, 0, -1, 0, 0))) # North America vs. Asia
car::linearHypothesis(metareg.continent, rbind(c(0, 1, 0, 0, -1, 0))) # North America vs. Oceania
car::linearHypothesis(metareg.continent, rbind(c(0, 1, 0, 0, 0, -1))) # North America vs. Africa
car::linearHypothesis(metareg.continent, rbind(c(0, 0, 1, -1, 0, 0))) # South America vs. Asia
car::linearHypothesis(metareg.continent, rbind(c(0, 0, 1, 0, -1, 0))) # South America vs. Oceania
car::linearHypothesis(metareg.continent, rbind(c(0, 0, 1, 0, 0, -1))) # South America vs. Africa
car::linearHypothesis(metareg.continent, rbind(c(0, 0, 0, 1, -1, 0))) # Asia vs. Oceania
car::linearHypothesis(metareg.continent, rbind(c(0, 0, 0, 1, 0, -1))) # Asia vs. Africa
car::linearHypothesis(metareg.continent, rbind(c(0, 0, 0, 0, 1, -1))) # Oceania vs. Africa


############################
# Continent (recategorized)
############################

# To test if the continent influences the effect size
metareg.continent.2 <- rma.mv(r, VCV_ESVar, 
                            mods = ~ continent.2, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final)

print(metareg.continent.2, digits=2)

# Calculate marginal R2 with r2_ml
R2.continent.2 <- r2_ml(metareg.continent.2)
round(R2.continent.2*100, 1)


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.2.no.int <- rma.mv(r, VCV_ESVar, 
                                   mods = ~ continent.2 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final)

print(metareg.continent.2.no.int, digits=3)


tiff("figures/02_Continent_Recategorized2.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.2.no.int, mod = "continent.2", 
             xlab = "Effect size (r)",
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.46, 0.077),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 8),
        legend.text = element_text(size = 8)) +
  theme(axis.title = element_text(size = 12)) +
  theme(axis.text = element_text(size = 12)) +
  theme(axis.text.y = element_text(size = 12)) +
  scale_y_continuous(limits = c(-1.9, 1.5), breaks = c(seq(-1.5, 1.5, 0.5))) +
  annotate(geom = "text", x = 5.43, y = -1.55, 
           label = paste0("italic(R)^{2} == ", round(R2.continent.2[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.40, y = -1.21, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.continent.2, rbind(c(0, 1, -1, 0, 0))) # North America vs. South America
car::linearHypothesis(metareg.continent.2, rbind(c(0, 1, 0, -1, 0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.2, rbind(c(0, 1, 0, 0, -1))) # North America vs. Others
car::linearHypothesis(metareg.continent.2, rbind(c(0, 0, 1, -1, 0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.2, rbind(c(0, 0, 1, 0, -1))) # South America vs. Others
car::linearHypothesis(metareg.continent.2, rbind(c(0, 0, 0, 1, -1))) # Asia vs. Others



#################
# Scale
#################

# To test if the scale influences the effect size
metareg.scale <- rma.mv(r, VCV_ESVar, 
                        mods = ~ scale, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final)

print(metareg.scale, digits=2)

# Calculate marginal R2 with r2_ml
R2.scale <- r2_ml(metareg.scale)
round(R2.scale*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.scale.no.int <- rma.mv(r, VCV_ESVar, 
                               mods = ~ scale - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final)

print(metareg.scale.no.int, digits=3)


tiff("figures/03_Scale.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.scale.no.int, mod = "scale", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.084),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-1.9, 1.5), breaks = c(seq(-1.5, 1.5, 0.5))) +
  annotate(geom = "text", x = 3.43, y = -1.54, 
           label = paste0("italic(R)^{2} == ", round(R2.scale[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 3.41, y = -1.20, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.scale, rbind(c(0, 1, -1))) # Local vs. Regional


#################
# Diversity index
#################

# To test if the diversity index influences the effect size
metareg.diversity <- rma.mv(r, VCV_ESVar, 
                            mods = ~ diversity, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method="REML", 
                            test="t", 
                            data=meta.final)

print(metareg.diversity, digits=2)

# Calculate marginal R2 with r2_ml
R2.diversity <- r2_ml(metareg.diversity)
round(R2.diversity*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.diversity.no.int <- rma.mv(r, VCV_ESVar, 
                                   mods = ~ diversity - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final)

print(metareg.diversity.no.int, digits=3)


tiff("figures/04_Diversity.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.diversity.no.int, mod = "diversity", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.36, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-1.9, 1.5), breaks = c(seq(-1.5, 1.5, 0.5))) +
  annotate(geom = "text", x = 4.43, y = -1.65, 
           label = paste0("italic(R)^{2} == ", round(R2.diversity[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 4.40, y = -1.25, label = "%", color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.diversity, rbind(c(0, 1, -1, 0))) # Taxonomic diversity: others vs. Functional diversity
car::linearHypothesis(metareg.diversity, rbind(c(0, 1, 0, -1))) # Taxonomic diversity: others vs. Abundance
car::linearHypothesis(metareg.diversity, rbind(c(0, 0, 1, -1))) # Functional diversity vs. Abundance


#################
# Class
#################

# To test if the Class influences the effect size
metareg.Class <- rma.mv(r, VCV_ESVar, 
                        mods = ~ Class, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final)

print(metareg.Class, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class <- r2_ml(metareg.Class)
round(R2.Class*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.no.int <- rma.mv(r, VCV_ESVar, 
                               mods = ~ Class - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final)

print(metareg.Class.no.int, digits=3)


tiff("figures/05_Class2.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.no.int, mod = "Class", 
             group = "studyID",
             xlab = "Effect size (r)", 
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.55, 0.12),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  annotate(geom = "text", x = 5.33, y = -1.8, 
           label = paste0("italic(R)^{2} == ", round(R2.Class[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.30, y = -1.4, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


#################
# Order
#################

# To test if the Order influences the effect size
metareg.Order <- rma.mv(r, VCV_ESVar, 
                        mods = ~ Order.2, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final)

print(metareg.Order, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order <- r2_ml(metareg.Order)
round(R2.Order*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.no.int <- rma.mv(r, VCV_ESVar, 
                               mods = ~ Order.2 - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final)

print(metareg.Order.no.int, digits=3)


tiff("figures/06_Order_Insecta.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.no.int, mod = "Order.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 12.7, y = -1.80, 
           label = paste0("italic(R)^{2} == ", round(R2.Order[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 12.62, y = -1.42, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order, rbind(c(0, 0, 0, 1, -1))) #  vs. 


#################
# Order (EPT)
#################

# To test if the Order influences the effect size
metareg.Order.EPT <- rma.mv(r, VCV_ESVar, 
                        mods = ~ Order.3, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final)

print(metareg.Order.EPT, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.EPT <- r2_ml(metareg.Order.EPT)
round(R2.Order.EPT*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.EPT.no.int <- rma.mv(r, VCV_ESVar, 
                               mods = ~ Order.3 - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final)

print(metareg.Order.EPT.no.int, digits=3)


tiff("figures/06_Order_EPT.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.EPT.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 9.60, y = -1.70, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.EPT[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 9.52, y = -1.25, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
# Hemiptera and Orthoptera not considered as n<10
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 1, -1, 0, 0, 0, 0, 0, 0))) # Diptera vs. EPT
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 1, 0, 0, -1, 0, 0, 0, 0))) # Diptera vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 1, 0, 0, 0, -1, 0, 0, 0))) # Diptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 1, 0, 0, 0, 0, -1, 0, 0))) # Diptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 1, 0, 0, 0, 0, 0, 0, -1))) # Diptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 1, 0, -1, 0, 0, 0, 0))) # EPT vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 1, 0, 0, -1, 0, 0, 0))) # EPT vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 1, 0, 0, 0, -1, 0, 0))) # EPT vs. Odonata
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 1, 0, 0, 0, 0, 0, -1))) # EPT vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 0, 0, 1, -1, 0, 0, 0))) # Hymenoptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 0, 0, 1, 0, -1, 0, 0))) # Hymenoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 0, 0, 0, 0, 0, 0, -1))) # Hymenoptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 0, 0, 0, 1, -1, 0, 0))) # Lepidoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 0, 0, 0, 1, 0, 0, -1))) # Lepidoptera vs. Non - Insect Orders
car::linearHypothesis(metareg.Order.EPT, rbind(c(0, 0, 0, 0, 0, 0, 1, 0, -1))) # Odonata vs. Non - Insect Orders


#################
# Family
#################

# To test if the Family influences the effect size
metareg.Family <- rma.mv(r, VCV_ESVar, 
                        mods = ~ Family.2, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final)

print(metareg.Family, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family <- r2_ml(metareg.Family)
round(R2.Family*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.no.int <- rma.mv(r, VCV_ESVar, 
                               mods = ~ Family.2 - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final)

print(metareg.Family.no.int, digits=3)


tiff("figures/07_Family.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -1.7, 
           label = paste0("italic(R)^{2} == ", round(R2.Family[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -1.3, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family, rbind(c(0, 1, -1, 0, 0, 0, 0))) # Calliphoridae vs. Carabidae
car::linearHypothesis(metareg.Family, rbind(c(0, 1, 0, -1, 0, 0, 0))) # Calliphoridae vs. Culicidae
car::linearHypothesis(metareg.Family, rbind(c(0, 1, 0, 0, -1, 0, 0))) # Calliphoridae vs. Drosophilidae
car::linearHypothesis(metareg.Family, rbind(c(0, 1, 0, 0, 0, -1, 0))) # Calliphoridae vs. Formicidae
car::linearHypothesis(metareg.Family, rbind(c(0, 1, 0, 0, 0, 0, -1))) # Calliphoridae vs. Other Families

car::linearHypothesis(metareg.Family, rbind(c(0, 0, 1, -1, 0, 0, 0))) # Carabidae vs. Culicidae
car::linearHypothesis(metareg.Family, rbind(c(0, 0, 1, 0, -1, 0, 0))) # Carabidae vs. Drosophilidae
car::linearHypothesis(metareg.Family, rbind(c(0, 0, 1, 0, 0, -1, 0))) # Carabidae vs. Formicidae
car::linearHypothesis(metareg.Family, rbind(c(0, 0, 1, 0, 0, 0, -1))) # Carabidae vs. Other Families

car::linearHypothesis(metareg.Family, rbind(c(0, 0, 0, 1, -1, 0, 0))) # Culicidae vs. Drosophilidae
car::linearHypothesis(metareg.Family, rbind(c(0, 0, 0, 1, 0, -1, 0))) # Culicidae vs. Formicidae
car::linearHypothesis(metareg.Family, rbind(c(0, 0, 0, 1, 0, 0, -1))) # Culicidae vs. Other Families

car::linearHypothesis(metareg.Family, rbind(c(0, 0, 0, 0, 1, -1, 0))) # Drosophilidae vs. Formicidae
car::linearHypothesis(metareg.Family, rbind(c(0, 0, 0, 0, 1, 0, -1))) # Drosophilidae vs. Other Families
car::linearHypothesis(metareg.Family, rbind(c(0, 0, 0, 0, 0, 1, -1))) # Formicidae vs. Other Families

