################################################################################
# Authors: 
# Alfredo Sanchez-Tojar (with support from Endika Blanco)

# Script first created in Nov 2018

################################################################################
# Description of script and Instructions
################################################################################

# This script is for a meta-analysis on the effect of urbanization on 
# biodiversity.

################################################################################
# Packages needed
################################################################################

# Clear memory
rm(list = ls())

###install.packages("pacman")
# devtools::install_github("itchyshin/orchard_plot", subdir = "orchaRd", 
#                          force = TRUE, build_vignettes = TRUE)
# devtools::install_github("daniel1noble/orchaRd", force = TRUE)
pacman::p_load(devtools, tidyverse, metafor, patchwork, R.rsp, orchaRd, emmeans,
               ape, phytools, report, car) #dplyr, ggplot2
pacman::p_load(knitr, DT, readxl, ggplot2, pander, formatR, rmdformats)

################################################################################
# Importing the data (from script 'data_preparation_arth.R')
################################################################################

meta.final.SA <- read.table("meta_final_reduced_sensitivity_analyses.csv",
                            header=T, sep=",")

# Modifying variables type
meta.final.SA$studyID <- as.factor(meta.final.SA$studyID)
meta.final.SA$es_type <- as.factor(meta.final.SA$es_type)


# Creating a new variable to categorize effects as biserial correlations, 
# Pearson's correlation coefficients or effects from inferential statistics
meta.final.SA$es_type_2 <- as.factor(ifelse(meta.final.SA$es_type %in% 
                                           c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                         "biserial_correlation",
                                         ifelse(meta.final.SA$es_type %in% 
                                                  c("pearsons", "spearmans"),
                                                "correlation_coefficient",
                                                "inferential_statistic")))

# METHOD
# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(method= 
                                       factor(method, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# Generating a new method that accounts for the fact that for some of the data
# originally reported as gradients we later on had to extract only the extremes
# (i.e. most urbanized vs least urbanized), normally from figures, to be able to
# calculate biserial correlations. In these cases, these estimates are going to
# now be categorized as "Urban-Rural" as the original continuous nature of the
# measurement was then changed
meta.final.SA$method.recat <- ifelse(as.character(meta.final.SA$method) %in% 
                                    c("Urban Gradient") &
                                    as.character(meta.final.SA$es_type) %in% 
                                    c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                  "Urban-Rural", 
                                  as.character(meta.final.SA$method))

# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(method.recat= 
                                       factor(method.recat, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# CONTINENT
# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                              mutate(continent=
                                       factor(continent, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Oceania",
                                                       "Africa"))))


# since sample sizes were to small for the original idea, we have recoded the 
# factor so that the sample sizes are decent and still biologically meaningful
meta.final.SA$continent.2 <- as.factor(ifelse(meta.final.SA$continent=="Africa" | 
                                             meta.final.SA$continent=="Oceania", 
                                           "Others", as.character(meta.final.SA$continent)))

table(meta.final.SA$continent.2)

# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                              mutate(continent.2=
                                       factor(continent.2, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Others"))))


# SCALE
# We reorder the levels so that the reference level (intercept) is City. The 
# order of goes from smaller to larger scale
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(scale= 
                                       factor(scale, 
                                              levels=c("City",
                                                       "Local",
                                                       "Regional"))))


# DIVERSITY
# We reorder the levels so that the reference level (intercept) is Richness, but
# first we recode the level names to make them more informative and standardized
meta.final.SA$diversity <- dplyr::recode(meta.final.SA$diversity, 
                                      "Other taxonomic diversity measure"= 
                                        "Taxonomic diversity: others", #to keep consistency with the other analyses, also shorter names are better for the plots and tables
                                      "Richness"="Taxonomic diversity: richness")

meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(diversity= 
                                       factor(diversity, 
                                              levels=c("Taxonomic diversity: richness",
                                                       "Taxonomic diversity: others",
                                                       "Functional diversity",
                                                       "Abundance"))))


# CLASS
# Customizing the order of the factor levels. We reorder the levels so that the 
# reference level (intercept) is Insecta
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(Class = factor(Class, 
                                                    levels=c("Insecta",
                                                             "Arachnida",
                                                             "Crustacea",
                                                             "Myriapoda",
                                                             "Entognatha"))))


# ORDER
table(meta.final.SA$Order)

#Subset for Insect Orders (Orders of the rest of Classes too small)
meta.final.SA$Order.2 <- ifelse(as.character(meta.final.SA$Order) %in% 
                               c("Araneae", "Decapoda", "Diplostraca",
                                 "Harpacticoida", "Isopoda", "Ixodida",
                                 "Opiliones", "Spirostreptida",
                                 "Diplostraca", "Trombidiformes"),
                             "Non-Insect Orders", 
                             as.character(meta.final.SA$Order))

meta.final.SA$Order.2 <- factor(meta.final.SA$Order.2)
table(meta.final.SA$Order.2)


#Subset for Insect Orders, after unifying EPT orders into EPT.
meta.final.SA$Order.3 <- ifelse(as.character(meta.final.SA$Order.2) %in% 
                               c("Ephemeroptera","Plecoptera","Trichoptera"),
                             "EPT", 
                             as.character(meta.final.SA$Order.2))


# We reorder the levels
meta.final.SA <- as.data.frame(meta.final.SA %>%
                                 mutate(Order.3=
                                          factor(Order.3, 
                                                 levels=c("Coleoptera",
                                                          "Diptera",
                                                          "EPT",
                                                          "Hemiptera",
                                                          "Hymenoptera",
                                                          "Lepidoptera",
                                                          "Odonata",
                                                          "Orthoptera",
                                                          "Non-Insect Orders"))))

meta.final.SA$Order.3 <- factor(meta.final.SA$Order.3)
table(meta.final.SA$Order.3)


# FAMILY
table(meta.final.SA$Family)

#Joining "Apidae" to "Apoidea" superfamily
meta.final.SA$Family.2 <- factor(meta.final.SA$Family)
meta.final.SA$Family.2 <- ifelse(as.character(meta.final.SA$Family.2) %in% 
                                c("Apidae"), "Apoidea", 
                              as.character(meta.final.SA$Family.2))

#Subset for Insect Families with enough data (10<)
meta.final.SA$Family.2 <- ifelse(as.character(meta.final.SA$Family.2) %in% 
                                c("Anisoptera", "bat-flies", "Chironomidae",
                                  "Chloropidae", "Coccinellidae", "Cynipidae",
                                  "Geometridae", "Hydrachnidia", "Psychodidae",
                                  "Sarcophagidae", "Scarabaeidae", "Silphidae",
                                  "Sphecidae", "Staphylinidae", "Syrphidae",
                                  "Tachinidae", "Tenebrionidae", "Thomisidae",
                                  "Vespidae", "Zygoptera"),
                              "Other Families", 
                              as.character(meta.final.SA$Family.2))

meta.final.SA$Family.2 <- factor(meta.final.SA$Family.2)
table(meta.final.SA$Family.2)


#subset for Shannon/Simpson data
meta.final.SA.others <- meta.final.SA[meta.final.SA$diversity=="Taxonomic diversity: others",]


################################################################################
# Sampling variance-covariance matrix lnRR
################################################################################

# subset
meta.final.lnRR.others <- meta.final.SA.others

# there are a clear outliers that we are going to exclude from the analyses.
meta.final.lnRR.others <- meta.final.lnRR.others[meta.final.lnRR.others$lnRR>(-2.5) 
                                                       & !(is.na(meta.final.lnRR.others$lnRR)),]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnRR.ot <- matrix(0, nrow = nrow(meta.final.lnRR.others), 
                         ncol = nrow(meta.final.lnRR.others))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnRR.ot) <- meta.final.lnRR.others[, "obsID"]
colnames(VCV_ESVar.lnRR.ot) <- meta.final.lnRR.others[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.lnRR.ot <- which(meta.final.lnRR.others[, "studyID"] %in% 
                        meta.final.lnRR.others[duplicated(meta.final.lnRR.others[,"studyID"]), 
                                        "studyID"] == TRUE)

combinations.lnRR.ot <- do.call("rbind", tapply(shared_coord.lnRR.ot, 
                                        meta.final.lnRR.others[shared_coord.lnRR.ot,"studyID"], 
                                        function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.lnRR.ot)[1]) {
  p1 <- combinations.lnRR.ot[i, 1]
  p2 <- combinations.lnRR.ot[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnRR.others[p1, "lnRR.vi"]) * sqrt(meta.final.lnRR.others[p2, "lnRR.vi"])
  VCV_ESVar.lnRR.ot[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnRR.ot[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnRR.ot) <- meta.final.lnRR.others[, "lnRR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnRR.ot, 'VCV_ESVar.lnRR.ot.csv')


################################################################################
# lnRR
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.lnRR.others$lnRR, meta.final.lnRR.others$lnRR.vi, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.lnRR.others$lnRR, meta.final.lnRR.others$lnRR.vi, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.lnRR.ot <- rma.mv(lnRR, VCV_ESVar.lnRR.ot, 
                     mods = ~ 1,
                     random = list(~ 1 | studyID,
                                   ~ 1 | comparisonID,
                                   ~ 1 | locationID,
                                   ~ 1 | obsID), 
                     method = "REML", 
                     test = "t", 
                     data = meta.final.lnRR.others)

# Printing the summary results of the model
print(meta.model.lnRR.ot, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.lnRR.ot, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.lnRR.ot)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.lnRR.ot,col=meta.final.lnRR.others$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.lnRR.ot)
plot(1:nrow(meta.final.lnRR.others), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.lnRR.ot)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS lnRR
################################################################################

##################################
# Class using others only lnRR
##################################

# To test if the Class influences the effect size
metareg.Class.lnRR.ot <- rma.mv(lnRR, VCV_ESVar.lnRR.ot, 
                        mods = ~ Class, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final.lnRR.others)

print(metareg.Class.lnRR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class.lnRR.ot <- r2_ml(metareg.Class.lnRR.ot)
round(R2.Class.lnRR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnRR.ot.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR.ot, 
                               mods = ~ Class - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final.lnRR.others)

print(metareg.Class.lnRR.ot.no.int, digits=3)


tiff("figures/supplements/S05_Class_others_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnRR.ot.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  annotate(geom = "text", x = 5.4, y = -1.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Class.lnRR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -1.1, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnRR.ot, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnRR.ot, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnRR.ot, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnRR.ot, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnRR.ot, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnRR.ot, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


########################################
# Order (EPT) using others only lnRR
########################################

# To test if the Order influences the effect size
metareg.Order.lnRR.ot <- rma.mv(lnRR, VCV_ESVar.lnRR.ot, 
                            mods = ~ Order.3, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final.lnRR.others)

print(metareg.Order.lnRR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnRR.ot <- r2_ml(metareg.Order.lnRR.ot)
round(R2.Order.lnRR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnRR.ot.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR.ot, 
                                   mods = ~ Order.3 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final.lnRR.others)

print(metareg.Order.lnRR.ot.no.int, digits=3)


tiff("figures/supplements/S06_Order_others_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnRR.ot.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 6.4, y = -1.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnRR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 6.35, y = -1.0, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnRR.ot, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR.ot, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR.ot, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR.ot, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR.ot, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnRR.ot, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################
# Family using others only lnRR
################################################################################

# To test if the Family influences the effect size
metareg.Family.lnRR.ot <- rma.mv(lnRR, VCV_ESVar.lnRR.ot, 
                            mods = ~ Family.2, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final.lnRR.others)

print(metareg.Family.lnRR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnRR.ot <- r2_ml(metareg.Family.lnRR.ot)
round(R2.Family.lnRR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnRR.ot.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR.ot, 
                                   mods = ~ Family.2 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final.lnRR.others)

print(metareg.Family.lnRR.ot.no.int, digits=3)


tiff("figures/supplements/S07_Family_others_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnRR.ot.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2, 2), breaks = c(seq(-2, 2, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -1.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnRR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.34, y = -1.05, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnRR.ot, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnRR.ot, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnRR.ot, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Family.lnRR.ot, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnRR.ot, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Family.lnRR.ot, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################




################################################################################
# Sampling variance-covariance matrix SMDH
################################################################################

# subset
meta.final.SMDH.others <- meta.final.SA.others

# there are clear outliers that we are going to exclude from the analyses.
meta.final.SMDH.others <- meta.final.SMDH.others[meta.final.SMDH.others$SMDH.vi<5 
                                   & !(is.na(meta.final.SMDH.others$SMDH.vi)),]
meta.final.SMDH.others <- meta.final.SMDH.others[meta.final.SMDH.others$SMDH>(-4) 
                                   & !(is.na(meta.final.SMDH.others$SMDH)),]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.SMDH.ot <- matrix(0, nrow = nrow(meta.final.SMDH.others), 
                            ncol = nrow(meta.final.SMDH.others))

# names rows and columns for each obsID
rownames(VCV_ESVar.SMDH.ot) <- meta.final.SMDH.others[, "obsID"]
colnames(VCV_ESVar.SMDH.ot) <- meta.final.SMDH.others[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.SMDH.ot <- which(meta.final.SMDH.others[, "studyID"] %in% 
                                meta.final.SMDH.others[duplicated(meta.final.SMDH.others[,"studyID"]), 
                                                          "studyID"] == TRUE)

combinations.SMDH.ot <- do.call("rbind", tapply(shared_coord.SMDH.ot, 
                                                meta.final.SMDH.others[shared_coord.SMDH.ot,"studyID"], 
                                                function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.SMDH.ot)[1]) {
  p1 <- combinations.SMDH.ot[i, 1]
  p2 <- combinations.SMDH.ot[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.SMDH.others[p1, "SMDH.vi"]) * sqrt(meta.final.SMDH.others[p2, "SMDH.vi"])
  VCV_ESVar.SMDH.ot[p1, p2] <- p1_p2_cov
  VCV_ESVar.SMDH.ot[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.SMDH.ot) <- meta.final.SMDH.others[, "SMDH.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.SMDH.ot, 'VCV_ESVar.SMDH.ot.csv')


################################################################################
# SMDH
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.SMDH.others$SMDH, meta.final.SMDH.others$SMDH.vi, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.SMDH.others$SMDH, meta.final.SMDH.others$SMDH.vi, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.SMDH.ot <- rma.mv(SMDH, VCV_ESVar.SMDH.ot, 
                        mods = ~ 1,
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID), 
                        method = "REML", 
                        test = "t", 
                        data = meta.final.SMDH.others)

# Printing the summary results of the model
print(meta.model.SMDH.ot, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.SMDH.ot, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.SMDH.ot)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.SMDH.ot,col=meta.final.SMDH.others$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.SMDH.ot)
plot(1:nrow(meta.final.SMDH.others), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.SMDH.ot)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS SMDH
################################################################################

##################################
# Class using others only SMDH
##################################

# To test if the Class influences the effect size
metareg.Class.SMDH.ot <- rma.mv(SMDH, VCV_ESVar.SMDH.ot, 
                                mods = ~ Class, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.SMDH.others)

print(metareg.Class.SMDH.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class.SMDH.ot <- r2_ml(metareg.Class.SMDH.ot)
round(R2.Class.SMDH.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.SMDH.ot.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH.ot, 
                                       mods = ~ Class - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.SMDH.others)

print(metareg.Class.SMDH.ot.no.int, digits=3)


tiff("figures/supplements/S05_Class_others_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.SMDH.ot.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-4, 4), breaks = c(seq(-4, 4, 1))) +
  annotate(geom = "text", x = 5.4, y = -3, 
           label = paste0("italic(R)^{2} == ", round(R2.Class.SMDH.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -2.2, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class.SMDH.ot, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.SMDH.ot, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.SMDH.ot, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.SMDH.ot, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.SMDH.ot, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.SMDH.ot, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


########################################
# Order (EPT) using others only SMDH
########################################

# To test if the Order influences the effect size
metareg.Order.SMDH.ot <- rma.mv(SMDH, VCV_ESVar.SMDH.ot, 
                                mods = ~ Order.3, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.SMDH.others)

print(metareg.Order.SMDH.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.SMDH.ot <- r2_ml(metareg.Order.SMDH.ot)
round(R2.Order.SMDH.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.SMDH.ot.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH.ot, 
                                       mods = ~ Order.3 - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.SMDH.others)

print(metareg.Order.SMDH.ot.no.int, digits=3)


tiff("figures/supplements/S06_Order_others_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.SMDH.ot.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-4, 4), breaks = c(seq(-4, 4, 1))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 6.40, y = -3, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.SMDH.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 6.35, y = -2.0, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.SMDH.ot, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH.ot, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH.ot, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH.ot, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH.ot, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.SMDH.ot, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################
# Family using others only SMDH
################################################################################

# To test if the Family influences the effect size
metareg.Family.SMDH.ot <- rma.mv(SMDH, VCV_ESVar.SMDH.ot, 
                                 mods = ~ Family.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.SMDH.others)

print(metareg.Family.SMDH.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.SMDH.ot <- r2_ml(metareg.Family.SMDH.ot)
round(R2.Family.SMDH.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.SMDH.ot.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH.ot, 
                                        mods = ~ Family.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.SMDH.others)

print(metareg.Family.SMDH.ot.no.int, digits=3)


tiff("figures/supplements/S07_Family_others_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.SMDH.ot.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-4, 4), breaks = c(seq(-4, 4, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -3, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.SMDH.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.34, y = -2.15, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.SMDH.ot, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Family.SMDH.ot, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.SMDH.ot, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Family.SMDH.ot, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.SMDH.ot, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Family.SMDH.ot, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################




################################################################################
# Sampling variance-covariance matrix lnCVR
################################################################################

# subset
meta.final.lnCVR.others <- meta.final.SA.others

# there are clear outliers that we are going to exclude from the analyses.
meta.final.lnCVR.others <- meta.final.lnCVR.others[meta.final.lnCVR.others$lnCVR<3,]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnCVR.ot <- matrix(0, nrow = nrow(meta.final.lnCVR.others), 
                            ncol = nrow(meta.final.lnCVR.others))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnCVR.ot) <- meta.final.lnCVR.others[, "obsID"]
colnames(VCV_ESVar.lnCVR.ot) <- meta.final.lnCVR.others[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.lnCVR.ot <- which(meta.final.lnCVR.others[, "studyID"] %in% 
                                meta.final.lnCVR.others[duplicated(meta.final.lnCVR.others[,"studyID"]), 
                                                          "studyID"] == TRUE)

combinations.lnCVR.ot <- do.call("rbind", tapply(shared_coord.lnCVR.ot, 
                                                meta.final.lnCVR.others[shared_coord.lnCVR.ot,"studyID"], 
                                                function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.lnCVR.ot)[1]) {
  p1 <- combinations.lnCVR.ot[i, 1]
  p2 <- combinations.lnCVR.ot[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnCVR.others[p1, "lnCVR.vi"]) * sqrt(meta.final.lnCVR.others[p2, "lnCVR.vi"])
  VCV_ESVar.lnCVR.ot[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnCVR.ot[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnCVR.ot) <- meta.final.lnCVR.others[, "lnCVR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnCVR.ot, 'VCV_ESVar.lnCVR.ot.csv')


################################################################################
# lnCVR
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.lnCVR.others$lnCVR, meta.final.lnCVR.others$lnCVR.vi, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.lnCVR.others$lnCVR, meta.final.lnCVR.others$lnCVR.vi, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.lnCVR.ot <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ot, 
                             mods = ~ 1,
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID), 
                             method = "REML", 
                             test = "t", 
                             data = meta.final.lnCVR.others)

# Printing the summary results of the model
print(meta.model.lnCVR.ot, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.lnCVR.ot, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.lnCVR.ot)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.lnCVR.ot,col=meta.final.lnCVR.others$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.lnCVR.ot)
plot(1:nrow(meta.final.lnCVR.others), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.lnCVR.ot)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS lnCVR
################################################################################

##################################
# Class using others only lnCVR
##################################

# To test if the Class influences the effect size
metareg.Class.lnCVR.ot <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ot, 
                                mods = ~ Class, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnCVR.others)

print(metareg.Class.lnCVR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class.lnCVR.ot <- r2_ml(metareg.Class.lnCVR.ot)
round(R2.Class.lnCVR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnCVR.ot.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ot, 
                                       mods = ~ Class - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.lnCVR.others)

print(metareg.Class.lnCVR.ot.no.int, digits=3)


tiff("figures/supplements/S05_Class_others_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnCVR.ot.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  annotate(geom = "text", x = 5.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Class.lnCVR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -1.9, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnCVR.ot, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnCVR.ot, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnCVR.ot, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnCVR.ot, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnCVR.ot, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnCVR.ot, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


########################################
# Order (EPT) using others only lnCVR
########################################

# To test if the Order influences the effect size
metareg.Order.lnCVR.ot <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ot, 
                                mods = ~ Order.3, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnCVR.others)

print(metareg.Order.lnCVR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnCVR.ot <- r2_ml(metareg.Order.lnCVR.ot)
round(R2.Order.lnCVR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnCVR.ot.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ot, 
                                       mods = ~ Order.3 - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.lnCVR.others)

print(metareg.Order.lnCVR.ot.no.int, digits=3)


tiff("figures/supplements/S06_Order_others_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnCVR.ot.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 6.4, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnCVR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 6.35, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnCVR.ot, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR.ot, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR.ot, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR.ot, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR.ot, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnCVR.ot, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################
# Family using others only lnCVR
################################################################################

# To test if the Family influences the effect size
metareg.Family.lnCVR.ot <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ot, 
                                 mods = ~ Family.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.lnCVR.others)

print(metareg.Family.lnCVR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnCVR.ot <- r2_ml(metareg.Family.lnCVR.ot)
round(R2.Family.lnCVR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnCVR.ot.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ot, 
                                        mods = ~ Family.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.lnCVR.others)

print(metareg.Family.lnCVR.ot.no.int, digits=3)


tiff("figures/supplements/S07_Family_others_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnCVR.ot.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnCVR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.34, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnCVR.ot, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnCVR.ot, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnCVR.ot, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Family.lnCVR.ot, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnCVR.ot, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Family.lnCVR.ot, rbind(c(0, 0, 0, 1, -1))) #  vs. 


###############################################################################




################################################################################
# Sampling variance-covariance matrix lnVR
################################################################################

# subset
meta.final.lnVR.others <- meta.final.SA.others

# there are clear outliers that we are going to exclude from the analyses.
meta.final.lnVR.others <- meta.final.lnVR.others[meta.final.lnVR.others$lnVR<3 
                                                       & meta.final.lnVR.others$lnVR<4,]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnVR.ot <- matrix(0, nrow = nrow(meta.final.lnVR.others), 
                            ncol = nrow(meta.final.lnVR.others))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnVR.ot) <- meta.final.lnVR.others[, "obsID"]
colnames(VCV_ESVar.lnVR.ot) <- meta.final.lnVR.others[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.lnVR.ot <- which(meta.final.lnVR.others[, "studyID"] %in% 
                                meta.final.lnVR.others[duplicated(meta.final.lnVR.others[,"studyID"]), 
                                                          "studyID"] == TRUE)

combinations.lnVR.ot <- do.call("rbind", tapply(shared_coord.lnVR.ot, 
                                                meta.final.lnVR.others[shared_coord.lnVR.ot,"studyID"], 
                                                function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.lnVR.ot)[1]) {
  p1 <- combinations.lnVR.ot[i, 1]
  p2 <- combinations.lnVR.ot[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnVR.others[p1, "lnVR.vi"]) * sqrt(meta.final.lnVR.others[p2, "lnVR.vi"])
  VCV_ESVar.lnVR.ot[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnVR.ot[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnVR.ot) <- meta.final.lnVR.others[, "lnVR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnVR.ot, 'VCV_ESVar.lnVR.ot.csv')


################################################################################
# lnVR
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.lnVR.others$lnVR, meta.final.lnVR.others$lnVR.vi, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.lnVR.others$lnVR, meta.final.lnVR.others$lnVR.vi, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.lnVR.ot <- rma.mv(lnVR, VCV_ESVar.lnVR.ot, 
                             mods = ~ 1,
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID), 
                             method = "REML", 
                             test = "t", 
                             data = meta.final.lnVR.others)

# Printing the summary results of the model
print(meta.model.lnVR.ot, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.lnVR.ot, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.lnVR.ot)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.lnVR.ot,col=meta.final.lnVR.others$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.lnVR.ot)
plot(1:nrow(meta.final.lnVR.others), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.lnVR.ot)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS lnVR
################################################################################

##################################
# Class using others only lnVR
##################################

# To test if the Class influences the effect size
metareg.Class.lnVR.ot <- rma.mv(lnVR, VCV_ESVar.lnVR.ot, 
                                mods = ~ Class, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnVR.others)

print(metareg.Class.lnVR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class.lnVR.ot <- r2_ml(metareg.Class.lnVR.ot)
round(R2.Class.lnVR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnVR.ot.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR.ot, 
                                       mods = ~ Class - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.lnVR.others)

print(metareg.Class.lnVR.ot.no.int, digits=3)


tiff("figures/supplements/S05_Class_others_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnVR.ot.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  annotate(geom = "text", x = 5.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Class.lnVR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnVR.ot, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnVR.ot, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnVR.ot, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnVR.ot, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnVR.ot, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnVR.ot, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


########################################
# Order (EPT) using others only lnVR
########################################

# To test if the Order influences the effect size
metareg.Order.lnVR.ot <- rma.mv(lnVR, VCV_ESVar.lnVR.ot, 
                                mods = ~ Order.3, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnVR.others)

print(metareg.Order.lnVR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnVR.ot <- r2_ml(metareg.Order.lnVR.ot)
round(R2.Order.lnVR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnVR.ot.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR.ot, 
                                       mods = ~ Order.3 - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.lnVR.others)

print(metareg.Order.lnVR.ot.no.int, digits=3)


tiff("figures/supplements/S06_Order_others_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnVR.ot.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 6.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnVR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 6.34, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnVR.ot, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR.ot, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR.ot, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR.ot, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR.ot, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnVR.ot, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################
# Family using others only lnVR
################################################################################

# To test if the Family influences the effect size
metareg.Family.lnVR.ot <- rma.mv(lnVR, VCV_ESVar.lnVR.ot, 
                                 mods = ~ Family.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.lnVR.others)

print(metareg.Family.lnVR.ot, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnVR.ot <- r2_ml(metareg.Family.lnVR.ot)
round(R2.Family.lnVR.ot*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnVR.ot.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR.ot, 
                                        mods = ~ Family.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.lnVR.others)

print(metareg.Family.lnVR.ot.no.int, digits=3)


tiff("figures/supplements/S07_Family_others_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnVR.ot.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR.others,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-2.5, 2.5), breaks = c(seq(-2.5, 2.5, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -2, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnVR.ot[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -1.4, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnVR.ot, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnVR.ot, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnVR.ot, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Family.lnVR.ot, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnVR.ot, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Family.lnVR.ot, rbind(c(0, 0, 0, 1, -1))) #  vs. 

