################################################################################
# Authors: 
# Alfredo Sanchez-Tojar (with support from Endika Blanco)

# Script first created in Nov 2018

################################################################################
# Description of script and Instructions
################################################################################

# This script is for a meta-analysis on the effect of urbanization on 
# biodiversity.

################################################################################
# Packages needed
################################################################################

# Clear memory
rm(list = ls())

###install.packages("pacman")
# devtools::install_github("itchyshin/orchard_plot", subdir = "orchaRd", 
#                          force = TRUE, build_vignettes = TRUE)
# devtools::install_github("daniel1noble/orchaRd", force = TRUE)
pacman::p_load(devtools, tidyverse, metafor, patchwork, R.rsp, orchaRd, emmeans,
               ape, phytools, report, car) #dplyr, ggplot2
pacman::p_load(knitr, DT, readxl, ggplot2, pander, formatR, rmdformats)

################################################################################
# Importing the data (from script 'data_preparation_arth.R')
################################################################################

meta.final.SA <- read.table("meta_final_reduced_sensitivity_analyses.csv",
                            header=T, sep=",")

# Modifying variables type
meta.final.SA$studyID <- as.factor(meta.final.SA$studyID)
meta.final.SA$es_type <- as.factor(meta.final.SA$es_type)


# Creating a new variable to categorize effects as biserial correlations, 
# Pearson's correlation coefficients or effects from inferential statistics
meta.final.SA$es_type_2 <- as.factor(ifelse(meta.final.SA$es_type %in% 
                                           c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                         "biserial_correlation",
                                         ifelse(meta.final.SA$es_type %in% 
                                                  c("pearsons", "spearmans"),
                                                "correlation_coefficient",
                                                "inferential_statistic")))

# METHOD
# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(method= 
                                       factor(method, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# Generating a new method that accounts for the fact that for some of the data
# originally reported as gradients we later on had to extract only the extremes
# (i.e. most urbanized vs least urbanized), normally from figures, to be able to
# calculate biserial correlations. In these cases, these estimates are going to
# now be categorized as "Urban-Rural" as the original continuous nature of the
# measurement was then changed
meta.final.SA$method.recat <- ifelse(as.character(meta.final.SA$method) %in% 
                                    c("Urban Gradient") &
                                    as.character(meta.final.SA$es_type) %in% 
                                    c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                  "Urban-Rural", 
                                  as.character(meta.final.SA$method))

# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(method.recat= 
                                       factor(method.recat, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# CONTINENT
# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                              mutate(continent=
                                       factor(continent, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Oceania",
                                                       "Africa"))))


# since sample sizes were to small for the original idea, we have recoded the 
# factor so that the sample sizes are decent and still biologically meaningful
meta.final.SA$continent.2 <- as.factor(ifelse(meta.final.SA$continent=="Africa" | 
                                             meta.final.SA$continent=="Oceania", 
                                           "Others", as.character(meta.final.SA$continent)))

table(meta.final.SA$continent.2)

# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                              mutate(continent.2=
                                       factor(continent.2, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Others"))))


# SCALE
# We reorder the levels so that the reference level (intercept) is City. The 
# order of goes from smaller to larger scale
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(scale= 
                                       factor(scale, 
                                              levels=c("City",
                                                       "Local",
                                                       "Regional"))))


# DIVERSITY
# We reorder the levels so that the reference level (intercept) is Richness, but
# first we recode the level names to make them more informative and standardized
meta.final.SA$diversity <- dplyr::recode(meta.final.SA$diversity, 
                                      "Other taxonomic diversity measure"= 
                                        "Taxonomic diversity: others", #to keep consistency with the other analyses, also shorter names are better for the plots and tables
                                      "Richness"="Taxonomic diversity: richness")

meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(diversity= 
                                       factor(diversity, 
                                              levels=c("Taxonomic diversity: richness",
                                                       "Taxonomic diversity: others",
                                                       "Functional diversity",
                                                       "Abundance"))))


# CLASS
# Customizing the order of the factor levels. We reorder the levels so that the 
# reference level (intercept) is Insecta
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(Class = factor(Class, 
                                                    levels=c("Insecta",
                                                             "Arachnida",
                                                             "Crustacea",
                                                             "Myriapoda",
                                                             "Entognatha"))))


# ORDER
table(meta.final.SA$Order)

#Subset for Insect Orders (Orders of the rest of Classes too small)
meta.final.SA$Order.2 <- ifelse(as.character(meta.final.SA$Order) %in% 
                               c("Araneae", "Decapoda", "Diplostraca",
                                 "Harpacticoida", "Isopoda", "Ixodida",
                                 "Opiliones", "Spirostreptida",
                                 "Diplostraca", "Trombidiformes"),
                             "Non-Insect Orders", 
                             as.character(meta.final.SA$Order))

meta.final.SA$Order.2 <- factor(meta.final.SA$Order.2)
table(meta.final.SA$Order.2)


#Subset for Insect Orders, after unifying EPT orders into EPT.
meta.final.SA$Order.3 <- ifelse(as.character(meta.final.SA$Order.2) %in% 
                               c("Ephemeroptera","Plecoptera","Trichoptera"),
                             "EPT", 
                             as.character(meta.final.SA$Order.2))


# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                                 mutate(Order.3=
                                          factor(Order.3, 
                                                 levels=c("Coleoptera",
                                                          "Diptera",
                                                          "EPT",
                                                          "Hemiptera",
                                                          "Hymenoptera",
                                                          "Lepidoptera",
                                                          "Odonata",
                                                          "Orthoptera",
                                                          "Non-Insect Orders"))))

meta.final.SA$Order.3 <- factor(meta.final.SA$Order.3)
table(meta.final.SA$Order.3)


# FAMILY
table(meta.final.SA$Family)

#Joining "Apidae" to "Apoidea" superfamily
meta.final.SA$Family.2 <- factor(meta.final.SA$Family)
meta.final.SA$Family.2 <- ifelse(as.character(meta.final.SA$Family.2) %in% 
                                c("Apidae"), "Apoidea", 
                              as.character(meta.final.SA$Family.2))

#Subset for Insect Families with enough data (10<)
meta.final.SA$Family.2 <- ifelse(as.character(meta.final.SA$Family.2) %in% 
                                c("Anisoptera", "bat-flies", "Chironomidae",
                                  "Chloropidae", "Coccinellidae", "Cynipidae",
                                  "Geometridae", "Hydrachnidia", "Psychodidae",
                                  "Sarcophagidae", "Scarabaeidae", "Silphidae",
                                  "Sphecidae", "Staphylinidae", "Syrphidae",
                                  "Tachinidae", "Tenebrionidae", "Thomisidae",
                                  "Vespidae", "Zygoptera"),
                              "Other Families", 
                              as.character(meta.final.SA$Family.2))

meta.final.SA$Family.2 <- factor(meta.final.SA$Family.2)
table(meta.final.SA$Family.2)


#subset for richness data
meta.final.SA.richness <- meta.final.SA[meta.final.SA$diversity=="Taxonomic diversity: richness",]


################################################################################
# Sampling variance-covariance matrix lnRR
################################################################################

# subset
meta.final.lnRR.richness <- meta.final.SA.richness

# there are a clear outliers that we are going to exclude from the analyses.
meta.final.lnRR.richness <- meta.final.lnRR.richness[meta.final.lnRR.richness$lnRR>(-5) 
                                                       & !(is.na(meta.final.lnRR.richness$lnRR)),]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnRR.ri <- matrix(0, nrow = nrow(meta.final.lnRR.richness), 
                         ncol = nrow(meta.final.lnRR.richness))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnRR.ri) <- meta.final.lnRR.richness[, "obsID"]
colnames(VCV_ESVar.lnRR.ri) <- meta.final.lnRR.richness[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.lnRR.ri <- which(meta.final.lnRR.richness[, "studyID"] %in% 
                        meta.final.lnRR.richness[duplicated(meta.final.lnRR.richness[,"studyID"]), 
                                        "studyID"] == TRUE)

combinations.lnRR.ri <- do.call("rbind", tapply(shared_coord.lnRR.ri, 
                                        meta.final.lnRR.richness[shared_coord.lnRR.ri,"studyID"], 
                                        function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.lnRR.ri)[1]) {
  p1 <- combinations.lnRR.ri[i, 1]
  p2 <- combinations.lnRR.ri[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnRR.richness[p1, "lnRR.vi"]) * sqrt(meta.final.lnRR.richness[p2, "lnRR.vi"])
  VCV_ESVar.lnRR.ri[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnRR.ri[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnRR.ri) <- meta.final.lnRR.richness[, "lnRR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnRR.ri, 'VCV_ESVar.lnRR.ri.csv')


################################################################################
# lnRR
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.lnRR.richness$lnRR, meta.final.lnRR.richness$lnRR.vi, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.lnRR.richness$lnRR, meta.final.lnRR.richness$lnRR.vi, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.lnRR.ri <- rma.mv(lnRR, VCV_ESVar.lnRR.ri, 
                     mods = ~ 1,
                     random = list(~ 1 | studyID,
                                   ~ 1 | comparisonID,
                                   ~ 1 | locationID,
                                   ~ 1 | obsID), 
                     method = "REML", 
                     test = "t", 
                     data = meta.final.lnRR.richness)

# Printing the summary results of the model
print(meta.model.lnRR.ri, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.lnRR.ri, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.lnRR.ri)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.lnRR.ri,col=meta.final.lnRR.richness$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.lnRR.ri)
plot(1:nrow(meta.final.lnRR.richness), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.lnRR.ri)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS lnRR
################################################################################

##################################
# Class using richness only lnRR
##################################

# To test if the Class influences the effect size
metareg.Class.lnRR.ri <- rma.mv(lnRR, VCV_ESVar.lnRR.ri, 
                        mods = ~ Class, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final.lnRR.richness)

print(metareg.Class.lnRR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class.lnRR.ri <- r2_ml(metareg.Class.lnRR.ri)
round(R2.Class.lnRR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnRR.ri.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR.ri, 
                               mods = ~ Class - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final.lnRR.richness)

print(metareg.Class.lnRR.ri.no.int, digits=3)


tiff("figures/supplements/S05_Class_richness_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnRR.ri.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-4.5, 4.5), breaks = c(seq(-4.5, 4.5, 1))) +
  annotate(geom = "text", x = 5.4, y = -3.2, 
           label = paste0("italic(R)^{2} == ", round(R2.Class.lnRR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -2.3, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnRR.ri, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnRR.ri, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnRR.ri, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnRR.ri, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnRR.ri, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnRR.ri, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


########################################
# Order (EPT) using richness only lnRR
########################################

# To test if the Order influences the effect size
metareg.Order.lnRR.ri <- rma.mv(lnRR, VCV_ESVar.lnRR.ri, 
                            mods = ~ Order.3, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final.lnRR.richness)

print(metareg.Order.lnRR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnRR.ri <- r2_ml(metareg.Order.lnRR.ri)
round(R2.Order.lnRR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnRR.ri.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR.ri, 
                                   mods = ~ Order.3 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final.lnRR.richness)

print(metareg.Order.lnRR.ri.no.int, digits=3)


tiff("figures/supplements/S06_Order_richness_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnRR.ri.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-4.5, 4.5), breaks = c(seq(-4.5, 4.5, 1))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 7.4, y = -3.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnRR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -2.45, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnRR.ri, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR.ri, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR.ri, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR.ri, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR.ri, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnRR.ri, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################
# Family using richness only lnRR
################################################################################

# To test if the Family influences the effect size
metareg.Family.lnRR.ri <- rma.mv(lnRR, VCV_ESVar.lnRR.ri, 
                            mods = ~ Family.2, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final.lnRR.richness)

print(metareg.Family.lnRR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnRR.ri <- r2_ml(metareg.Family.lnRR.ri)
round(R2.Family.lnRR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnRR.ri.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR.ri, 
                                   mods = ~ Family.2 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final.lnRR.richness)

print(metareg.Family.lnRR.ri.no.int, digits=3)


tiff("figures/supplements/S07_Family_richness_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnRR.ri.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnRR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.34, y = -1.85, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnRR.ri, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnRR.ri, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnRR.ri, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Family.lnRR.ri, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnRR.ri, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Family.lnRR.ri, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################




################################################################################
# Sampling variance-covariance matrix SMDH
################################################################################

# subset
meta.final.SMDH.richness <- meta.final.SA.richness

# there are clear outliers that we are going to exclude from the analyses.
meta.final.SMDH.richness <- meta.final.SMDH.richness[meta.final.SMDH.richness$SMDH.vi<6 
                                   & !(is.na(meta.final.SMDH.richness$SMDH.vi)),]
meta.final.SMDH.richness <- meta.final.SMDH.richness[meta.final.SMDH.richness$SMDH<7 
                                   & !(is.na(meta.final.SMDH.richness$SMDH)),]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.SMDH.ri <- matrix(0, nrow = nrow(meta.final.SMDH.richness), 
                            ncol = nrow(meta.final.SMDH.richness))

# names rows and columns for each obsID
rownames(VCV_ESVar.SMDH.ri) <- meta.final.SMDH.richness[, "obsID"]
colnames(VCV_ESVar.SMDH.ri) <- meta.final.SMDH.richness[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.SMDH.ri <- which(meta.final.SMDH.richness[, "studyID"] %in% 
                                meta.final.SMDH.richness[duplicated(meta.final.SMDH.richness[,"studyID"]), 
                                                          "studyID"] == TRUE)

combinations.SMDH.ri <- do.call("rbind", tapply(shared_coord.SMDH.ri, 
                                                meta.final.SMDH.richness[shared_coord.SMDH.ri,"studyID"], 
                                                function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.SMDH.ri)[1]) {
  p1 <- combinations.SMDH.ri[i, 1]
  p2 <- combinations.SMDH.ri[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.SMDH.richness[p1, "SMDH.vi"]) * sqrt(meta.final.SMDH.richness[p2, "SMDH.vi"])
  VCV_ESVar.SMDH.ri[p1, p2] <- p1_p2_cov
  VCV_ESVar.SMDH.ri[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.SMDH.ri) <- meta.final.SMDH.richness[, "SMDH.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.SMDH.ri, 'VCV_ESVar.SMDH.ri.csv')


################################################################################
# SMDH
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.SMDH.richness$SMDH, meta.final.SMDH.richness$SMDH.vi, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.SMDH.richness$SMDH, meta.final.SMDH.richness$SMDH.vi, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.SMDH.ri <- rma.mv(SMDH, VCV_ESVar.SMDH.ri, 
                        mods = ~ 1,
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID), 
                        method = "REML", 
                        test = "t", 
                        data = meta.final.SMDH.richness)

# Printing the summary results of the model
print(meta.model.SMDH.ri, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.SMDH.ri, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.SMDH.ri)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.SMDH.ri,col=meta.final.SMDH.richness$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.SMDH.ri)
plot(1:nrow(meta.final.SMDH.richness), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.SMDH.ri)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS SMDH
################################################################################

##################################
# Class using richness only SMDH
##################################

# To test if the Class influences the effect size
metareg.Class.SMDH.ri <- rma.mv(SMDH, VCV_ESVar.SMDH.ri, 
                                mods = ~ Class, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.SMDH.richness)

print(metareg.Class.SMDH.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class.SMDH.ri <- r2_ml(metareg.Class.SMDH.ri)
round(R2.Class.SMDH.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.SMDH.ri.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH.ri, 
                                       mods = ~ Class - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.SMDH.richness)

print(metareg.Class.SMDH.ri.no.int, digits=3)


tiff("figures/supplements/S05_Class_richness_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.SMDH.ri.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6, 6), breaks = c(seq(-6, 6, 1))) +
  annotate(geom = "text", x = 5.4, y = -4.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Class.SMDH.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -3.3, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class.SMDH.ri, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.SMDH.ri, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.SMDH.ri, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.SMDH.ri, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.SMDH.ri, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.SMDH.ri, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


########################################
# Order (EPT) using richness only SMDH
########################################

# To test if the Order influences the effect size
metareg.Order.SMDH.ri <- rma.mv(SMDH, VCV_ESVar.SMDH.ri, 
                                mods = ~ Order.3, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.SMDH.richness)

print(metareg.Order.SMDH.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.SMDH.ri <- r2_ml(metareg.Order.SMDH.ri)
round(R2.Order.SMDH.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.SMDH.ri.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH.ri, 
                                       mods = ~ Order.3 - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.SMDH.richness)

print(metareg.Order.SMDH.ri.no.int, digits=3)


tiff("figures/supplements/S06_Order_richness_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.SMDH.ri.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6, 6), breaks = c(seq(-6, 6, 1))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 7.50, y = -4.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.SMDH.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.45, y = -3.1, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.SMDH.ri, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH.ri, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH.ri, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH.ri, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH.ri, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.SMDH.ri, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################
# Family using richness only SMDH
################################################################################

# To test if the Family influences the effect size
metareg.Family.SMDH.ri <- rma.mv(SMDH, VCV_ESVar.SMDH.ri, 
                                 mods = ~ Family.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.SMDH.richness)

print(metareg.Family.SMDH.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.SMDH.ri <- r2_ml(metareg.Family.SMDH.ri)
round(R2.Family.SMDH.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.SMDH.ri.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH.ri, 
                                        mods = ~ Family.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.SMDH.richness)

print(metareg.Family.SMDH.ri.no.int, digits=3)


tiff("figures/supplements/S07_Family_richness_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.SMDH.ri.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6, 6), breaks = c(seq(-6, 6, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -4.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.SMDH.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -3.3, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.SMDH.ri, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Family.SMDH.ri, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.SMDH.ri, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Family.SMDH.ri, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.SMDH.ri, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Family.SMDH.ri, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################




################################################################################
# Sampling variance-covariance matrix lnCVR
################################################################################

# subset
meta.final.lnCVR.richness <- meta.final.SA.richness

# there are clear outliers that we are going to exclude from the analyses.
meta.final.lnCVR.richness <- meta.final.lnCVR.richness[meta.final.lnCVR.richness$lnCVR>(-5) 
                                                     & meta.final.lnCVR.richness$lnCVR<5,]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnCVR.ri <- matrix(0, nrow = nrow(meta.final.lnCVR.richness), 
                            ncol = nrow(meta.final.lnCVR.richness))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnCVR.ri) <- meta.final.lnCVR.richness[, "obsID"]
colnames(VCV_ESVar.lnCVR.ri) <- meta.final.lnCVR.richness[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.lnCVR.ri <- which(meta.final.lnCVR.richness[, "studyID"] %in% 
                                meta.final.lnCVR.richness[duplicated(meta.final.lnCVR.richness[,"studyID"]), 
                                                          "studyID"] == TRUE)

combinations.lnCVR.ri <- do.call("rbind", tapply(shared_coord.lnCVR.ri, 
                                                meta.final.lnCVR.richness[shared_coord.lnCVR.ri,"studyID"], 
                                                function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.lnCVR.ri)[1]) {
  p1 <- combinations.lnCVR.ri[i, 1]
  p2 <- combinations.lnCVR.ri[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnCVR.richness[p1, "lnCVR.vi"]) * sqrt(meta.final.lnCVR.richness[p2, "lnCVR.vi"])
  VCV_ESVar.lnCVR.ri[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnCVR.ri[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnCVR.ri) <- meta.final.lnCVR.richness[, "lnCVR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnCVR.ri, 'VCV_ESVar.lnCVR.ri.csv')


################################################################################
# lnCVR
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.lnCVR.richness$lnCVR, meta.final.lnCVR.richness$lnCVR.vi, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.lnCVR.richness$lnCVR, meta.final.lnCVR.richness$lnCVR.vi, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.lnCVR.ri <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ri, 
                             mods = ~ 1,
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID), 
                             method = "REML", 
                             test = "t", 
                             data = meta.final.lnCVR.richness)

# Printing the summary results of the model
print(meta.model.lnCVR.ri, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.lnCVR.ri, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.lnCVR.ri)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.lnCVR.ri,col=meta.final.lnCVR.richness$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.lnCVR.ri)
plot(1:nrow(meta.final.lnCVR.richness), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.lnCVR.ri)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS lnCVR
################################################################################

##################################
# Class using richness only lnCVR
##################################

# To test if the Class influences the effect size
metareg.Class.lnCVR.ri <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ri, 
                                mods = ~ Class, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnCVR.richness)

print(metareg.Class.lnCVR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class.lnCVR.ri <- r2_ml(metareg.Class.lnCVR.ri)
round(R2.Class.lnCVR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnCVR.ri.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ri, 
                                       mods = ~ Class - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.lnCVR.richness)

print(metareg.Class.lnCVR.ri.no.int, digits=3)


tiff("figures/supplements/S05_Class_richness_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnCVR.ri.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5, 3.5), breaks = c(seq(-3.5, 3.5, 0.5))) +
  annotate(geom = "text", x = 5.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Class.lnCVR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnCVR.ri, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnCVR.ri, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnCVR.ri, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnCVR.ri, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnCVR.ri, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnCVR.ri, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


########################################
# Order (EPT) using richness only lnCVR
########################################

# To test if the Order influences the effect size
metareg.Order.lnCVR.ri <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ri, 
                                mods = ~ Order.3, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnCVR.richness)

print(metareg.Order.lnCVR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnCVR.ri <- r2_ml(metareg.Order.lnCVR.ri)
round(R2.Order.lnCVR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnCVR.ri.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ri, 
                                       mods = ~ Order.3 - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.lnCVR.richness)

print(metareg.Order.lnCVR.ri.no.int, digits=3)


tiff("figures/supplements/S06_Order_richness_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnCVR.ri.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 7.4, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnCVR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnCVR.ri, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR.ri, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR.ri, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR.ri, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR.ri, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnCVR.ri, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################
# Family using richness only lnCVR
################################################################################

# To test if the Family influences the effect size
metareg.Family.lnCVR.ri <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ri, 
                                 mods = ~ Family.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.lnCVR.richness)

print(metareg.Family.lnCVR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnCVR.ri <- r2_ml(metareg.Family.lnCVR.ri)
round(R2.Family.lnCVR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnCVR.ri.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR.ri, 
                                        mods = ~ Family.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.lnCVR.richness)

print(metareg.Family.lnCVR.ri.no.int, digits=3)


tiff("figures/supplements/S07_Family_richness_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnCVR.ri.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnCVR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.34, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnCVR.ri, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnCVR.ri, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnCVR.ri, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Family.lnCVR.ri, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnCVR.ri, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Family.lnCVR.ri, rbind(c(0, 0, 0, 1, -1))) #  vs. 


###############################################################################




################################################################################
# Sampling variance-covariance matrix lnVR
################################################################################

# subset
meta.final.lnVR.richness <- meta.final.SA.richness

# there are clear outliers that we are going to exclude from the analyses.
meta.final.lnVR.richness <- meta.final.lnVR.richness[meta.final.lnVR.richness$lnVR>(-4) 
                                                       & meta.final.lnVR.richness$lnVR<4,]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnVR.ri <- matrix(0, nrow = nrow(meta.final.lnVR.richness), 
                            ncol = nrow(meta.final.lnVR.richness))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnVR.ri) <- meta.final.lnVR.richness[, "obsID"]
colnames(VCV_ESVar.lnVR.ri) <- meta.final.lnVR.richness[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.lnVR.ri <- which(meta.final.lnVR.richness[, "studyID"] %in% 
                                meta.final.lnVR.richness[duplicated(meta.final.lnVR.richness[,"studyID"]), 
                                                          "studyID"] == TRUE)

combinations.lnVR.ri <- do.call("rbind", tapply(shared_coord.lnVR.ri, 
                                                meta.final.lnVR.richness[shared_coord.lnVR.ri,"studyID"], 
                                                function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.lnVR.ri)[1]) {
  p1 <- combinations.lnVR.ri[i, 1]
  p2 <- combinations.lnVR.ri[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnVR.richness[p1, "lnVR.vi"]) * sqrt(meta.final.lnVR.richness[p2, "lnVR.vi"])
  VCV_ESVar.lnVR.ri[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnVR.ri[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnVR.ri) <- meta.final.lnVR.richness[, "lnVR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnVR.ri, 'VCV_ESVar.lnVR.ri.csv')


################################################################################
# lnVR
################################################################################

# Raw data funnel plot
par(mfrow=c(1, 2))
funnel(meta.final.lnVR.richness$lnVR, meta.final.lnVR.richness$lnVR.vi, yaxis="sei",
       xlab="Effect size (r)", digits=2, las=1) 
funnel(meta.final.lnVR.richness$lnVR, meta.final.lnVR.richness$lnVR.vi, yaxis="seinv",
       xlab="Effect size (r)",  digits=2, las=1) 


# MAIN MODEL = multilevel meta-analysis
meta.model.lnVR.ri <- rma.mv(lnVR, VCV_ESVar.lnVR.ri, 
                             mods = ~ 1,
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID), 
                             method = "REML", 
                             test = "t", 
                             data = meta.final.lnVR.richness)

# Printing the summary results of the model
print(meta.model.lnVR.ri, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(meta.model.lnVR.ri, digits=2)

# Model funnel plots
par(mfrow = c(1, 1))
funnel(meta.model.lnVR.ri)

# Now exploring distribution of the three main types of effect sizes included: 
# biserial correlations, correlation coefficients and inferential statistics
funnel(meta.model.lnVR.ri,col=meta.final.lnVR.richness$es_type_2)

# We can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be potential outliers
resid<-rstandard(meta.model.lnVR.ri)
plot(1:nrow(meta.final.lnVR.richness), resid$z, type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model <- i2_ml(meta.model.lnVR.ri)
round(I2.model, 1)


################################################################################
# META-REGRESSIONS lnVR
################################################################################

##################################
# Class using richness only lnVR
##################################

# To test if the Class influences the effect size
metareg.Class.lnVR.ri <- rma.mv(lnVR, VCV_ESVar.lnVR.ri, 
                                mods = ~ Class, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnVR.richness)

print(metareg.Class.lnVR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Class.lnVR.ri <- r2_ml(metareg.Class.lnVR.ri)
round(R2.Class.lnVR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnVR.ri.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR.ri, 
                                       mods = ~ Class - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.lnVR.richness)

print(metareg.Class.lnVR.ri.no.int, digits=3)


tiff("figures/supplements/S05_Class_richness_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnVR.ri.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  annotate(geom = "text", x = 5.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Class.lnVR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 5.36, y = -1.9, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnVR.ri, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnVR.ri, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnVR.ri, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnVR.ri, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnVR.ri, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnVR.ri, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


########################################
# Order (EPT) using richness only lnVR
########################################

# To test if the Order influences the effect size
metareg.Order.lnVR.ri <- rma.mv(lnVR, VCV_ESVar.lnVR.ri, 
                                mods = ~ Order.3, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnVR.richness)

print(metareg.Order.lnVR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnVR.ri <- r2_ml(metareg.Order.lnVR.ri)
round(R2.Order.lnVR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnVR.ri.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR.ri, 
                                       mods = ~ Order.3 - 1, 
                                       random = list(~ 1 | studyID,
                                                     ~ 1 | comparisonID,
                                                     ~ 1 | locationID,
                                                     ~ 1 | obsID),
                                       method = "REML", 
                                       test = "t", 
                                       data = meta.final.lnVR.richness)

print(metareg.Order.lnVR.ri.no.int, digits=3)


tiff("figures/supplements/S06_Order_richness_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnVR.ri.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 7.50, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnVR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.44, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnVR.ri, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR.ri, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR.ri, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR.ri, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR.ri, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnVR.ri, rbind(c(0, 0, 0, 1, -1))) #  vs. 


################################################################################
# Family using richness only lnVR
################################################################################

# To test if the Family influences the effect size
metareg.Family.lnVR.ri <- rma.mv(lnVR, VCV_ESVar.lnVR.ri, 
                                 mods = ~ Family.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.lnVR.richness)

print(metareg.Family.lnVR.ri, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnVR.ri <- r2_ml(metareg.Family.lnVR.ri)
round(R2.Family.lnVR.ri*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnVR.ri.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR.ri, 
                                        mods = ~ Family.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.lnVR.richness)

print(metareg.Family.lnVR.ri.no.int, digits=3)


tiff("figures/supplements/S07_Family_richness_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnVR.ri.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR.richness,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3, 3), breaks = c(seq(-3, 3, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnVR.ri[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnVR.ri, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnVR.ri, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnVR.ri, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Family.lnVR.ri, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Family.lnVR.ri, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Family.lnVR.ri, rbind(c(0, 0, 0, 1, -1))) #  vs. 

