################################################################################
# Authors: 
# Alfredo Sanchez-Tojar (with support from Endika Blanco)

# Script first created in Nov 2018

################################################################################
# Description of script and Instructions
################################################################################

# This script is for a meta-analysis on the effect of urbanization on 
# biodiversity.

################################################################################
# Packages needed
################################################################################

# Clear memory
rm(list=ls())

###install.packages("pacman")
# devtools::install_github("itchyshin/orchard_plot", subdir = "orchaRd", 
#                          force = TRUE, build_vignettes = TRUE)
# devtools::install_github("daniel1noble/orchaRd", force = TRUE)
pacman::p_load(devtools, tidyverse, metafor, patchwork, R.rsp, orchaRd, emmeans,
               ape, phytools, report, car) #dplyr, ggplot2


################################################################################
# Using other effect sizes: lnRR and SMDH for extra sensitivity analyses
################################################################################

# importing the dataset for these tests and later on adjusting all variables
# as done for the main dataset above
meta.final.SA <- read.table("meta_final_reduced_sensitivity_analyses.csv",
                            header=T, sep=",")


# Modifying variables type
meta.final.SA$studyID <- as.factor(meta.final.SA$studyID)
meta.final.SA$es_type <- as.factor(meta.final.SA$es_type)


# Creating a new variable to categorize effects as biserial correlations, 
# Pearson's correlation coefficients or effects from inferential statistics
meta.final.SA$es_type_2 <- as.factor(ifelse(meta.final.SA$es_type %in% 
                                           c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                         "biserial_correlation",
                                         ifelse(meta.final.SA$es_type %in% 
                                                  c("pearsons", "spearmans"),
                                                "correlation_coefficient",
                                                "inferential_statistic")))

# METHOD
# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(method= 
                                       factor(method, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# Generating a new method that accounts for the fact that for some of the data
# originally reported as gradients we later on had to extract only the extremes
# (i.e. most urbanized vs least urbanized), normally from figures, to be able to
# calculate biserial correlations. In these cases, these estimates are going to
# now be categorized as "Urban-Rural" as the original continuous nature of the
# measurement was then changed
meta.final.SA$method.recat <- ifelse(as.character(meta.final.SA$method) %in% 
                                    c("Urban Gradient") &
                                    as.character(meta.final.SA$es_type) %in% 
                                    c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                  "Urban-Rural", 
                                  as.character(meta.final.SA$method))

# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(method.recat= 
                                       factor(method.recat, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# CONTINENT
# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                              mutate(continent=
                                       factor(continent, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Oceania",
                                                       "Africa"))))


# since sample sizes were to small for the original idea, we have recoded the 
# factor so that the sample sizes are decent and still biologically meaningful
meta.final.SA$continent.2 <- as.factor(ifelse(meta.final.SA$continent=="Africa" | 
                                             meta.final.SA$continent=="Oceania", 
                                           "Others", as.character(meta.final.SA$continent)))

table(meta.final.SA$continent.2)

# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                              mutate(continent.2=
                                       factor(continent.2, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Others"))))


# SCALE
# We reorder the levels so that the reference level (intercept) is City. The 
# order of goes from smaller to larger scale
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(scale= 
                                       factor(scale, 
                                              levels=c("City",
                                                       "Local",
                                                       "Regional"))))


# DIVERSITY
# We reorder the levels so that the reference level (intercept) is Richness, but
# first we recode the level names to make them more informative and standardized
meta.final.SA$diversity <- dplyr::recode(meta.final.SA$diversity, 
                                      "Other taxonomic diversity measure"= 
                                        "Taxonomic diversity: others", #to keep consistency with the other analyses, also shorter names are better for the plots and tables
                                      "Richness"="Taxonomic diversity: richness")

meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(diversity= 
                                       factor(diversity, 
                                              levels=c("Taxonomic diversity: richness",
                                                       "Taxonomic diversity: others",
                                                       "Functional diversity",
                                                       "Abundance"))))


# CLASS
# Customizing the order of the factor levels. We reorder the levels so that the 
# reference level (intercept) is Insecta
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                              mutate(Class = factor(Class, 
                                                    levels=c("Insecta",
                                                             "Arachnida",
                                                             "Crustacea",
                                                             "Myriapoda",
                                                             "Entognatha"))))


# ORDER
table(meta.final.SA$Order)

#Subset for Insect Orders (Orders of the rest of Classes too small)
meta.final.SA$Order.2 <- ifelse(as.character(meta.final.SA$Order) %in% 
                               c("Araneae", "Decapoda", "Diplostraca",
                                 "Harpacticoida", "Isopoda", "Ixodida",
                                 "Opiliones", "Spirostreptida",
                                 "Diplostraca", "Trombidiformes"),
                             "Non-Insect Orders", 
                             as.character(meta.final.SA$Order))

meta.final.SA$Order.2 <- factor(meta.final.SA$Order.2)
table(meta.final.SA$Order.2)


#Subset for Insect Orders, after unifying EPT orders into EPT.
meta.final.SA$Order.3 <- ifelse(as.character(meta.final.SA$Order.2) %in% 
                               c("Ephemeroptera","Plecoptera","Trichoptera"),
                             "EPT", 
                             as.character(meta.final.SA$Order.2))

# We reorder the levels
meta.final.SA <- as.data.frame(meta.final.SA %>%
                              mutate(Order.3=
                                       factor(Order.3, 
                                              levels=c("Coleoptera",
                                                       "Diptera",
                                                       "EPT",
                                                       "Hemiptera",
                                                       "Hymenoptera",
                                                       "Lepidoptera",
                                                       "Odonata",
                                                       "Orthoptera",
                                                       "Non-Insect Orders"))))

meta.final.SA$Order.3 <- factor(meta.final.SA$Order.3)
table(meta.final.SA$Order.3)


# FAMILY
table(meta.final.SA$Family)

#Joining "Apidae" to "Apoidea" superfamily
meta.final.SA$Family.2 <- factor(meta.final.SA$Family)
meta.final.SA$Family.2 <- ifelse(as.character(meta.final.SA$Family.2) %in% 
                                c("Apidae"), "Apoidea", 
                              as.character(meta.final.SA$Family.2))

#Subset for Insect Families with enough data (10<)
meta.final.SA$Family.2 <- ifelse(as.character(meta.final.SA$Family.2) %in% 
                                c("Anisoptera", "bat-flies", "Chironomidae",
                                  "Chloropidae", "Coccinellidae", "Cynipidae",
                                  "Geometridae", "Hydrachnidia", "Psychodidae",
                                  "Sarcophagidae", "Scarabaeidae", "Silphidae",
                                  "Sphecidae", "Staphylinidae", "Syrphidae",
                                  "Tachinidae", "Tenebrionidae", "Thomisidae",
                                  "Vespidae", "Zygoptera"),
                              "Other Families", 
                              as.character(meta.final.SA$Family.2))

meta.final.SA$Family.2 <- factor(meta.final.SA$Family.2)
table(meta.final.SA$Family.2)


################################################################################
# Sampling variance-covariance matrix lnRR
################################################################################

# subset
meta.final.lnRR <- meta.final.SA

# there is a clear outliers that we are going to exclude from the analyses.
meta.final.lnRR <- meta.final.lnRR[meta.final.lnRR$lnRR>-6 
                               & !(is.na(meta.final.lnRR$lnRR.vi)),]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnRR <- matrix(0, nrow = nrow(meta.final.lnRR), 
                         ncol = nrow(meta.final.lnRR))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnRR) <- meta.final.lnRR[, "obsID"]
colnames(VCV_ESVar.lnRR) <- meta.final.lnRR[, "obsID"]

# finds effect sizes that come from the same study
shared_coord <- which(meta.final.lnRR[, "studyID"] %in% 
                        meta.final.lnRR[duplicated(meta.final.lnRR[,"studyID"]), 
                                      "studyID"] == TRUE)

combinations <- do.call("rbind", tapply(shared_coord, 
                                        meta.final.lnRR[shared_coord,"studyID"], 
                                        function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations)[1]) {
  p1 <- combinations[i, 1]
  p2 <- combinations[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnRR[p1, "lnRR.vi"]) * sqrt(meta.final.lnRR[p2, "lnRR.vi"])
  VCV_ESVar.lnRR[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnRR[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnRR) <- meta.final.lnRR[, "lnRR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnRR, 'VCV_ESVar.lnRR.csv')


################################################################################
# lnRR
################################################################################

#Data funnel plot
par(mfrow = c(1, 2))
funnel(meta.final.lnRR$lnRR, meta.final.lnRR$lnRR.vi, yaxis="sei",
       xlab = "Effect size (lnRR)", digits = 2, las = 1)
funnel(meta.final.lnRR$lnRR, meta.final.lnRR$lnRR.vi, yaxis="seinv",
       xlab = "Effect size (lnRR)",  digits = 2, las = 1)


# MAIN MODEL = multilevel meta-analysis
model.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                     random = list(~ 1 | studyID,
                                   ~ 1 | comparisonID,
                                   ~ 1 | locationID,
                                   ~ 1 | obsID), 
                     method="REML", 
                     test="t", 
                     data=meta.final.lnRR)

# Printing the summary results of the model
print(model.lnRR, digits=2)

# Printing the results again, but adding the credibility/prediction interval, 
# which uses the heterogeneity to generate a 95% interval that should contain 
# 95% of the effect sizes of any future or unknown studies with similar features
# as those included in the current database
predict(model.lnRR, digits=2)

#model funnel plot
par(mfrow = c(1, 1))
funnel(model.lnRR)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model.lnRR <- i2_ml(model.lnRR)
round(I2.model.lnRR,1)


##############################
# method (recategorized) lnRR
##############################

#to test if the method influences the effect size
metareg.method.recat.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                    mods = ~ method.recat, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method="REML", 
                                    test="t", 
                                    data=meta.final.lnRR)

print(metareg.method.recat.lnRR, digits=2)

###calculate marginal R2 with r2_ml
R2.method <- r2_ml(metareg.method.recat.lnRR)
round(R2.method*100,1)

# Plotting the results
# removing the intercept for easy plotting
metareg.method.recat.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                           mods = ~ method.recat - 1, 
                                           random = list(~ 1 | studyID,
                                                         ~ 1 | comparisonID,
                                                         ~ 1 | locationID,
                                                         ~ 1 | obsID),
                                           method="REML", 
                                           test="t", 
                                           data=meta.final.lnRR)

print(metareg.method.recat.lnRR.no.int, digits=2)


tiff("figures/supplements/S01_Methods_lnRR.tiff", 
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.method.recat.lnRR.no.int, mod = "method.recat", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.39, 0.085),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6,6),breaks = c(seq(-6,6,1))) +
  annotate(geom="text", x=3.43, y=-5, label=paste0("italic(R)^{2} == ", round(R2.method[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.41, y=-3.6, label="%",color="black", parse = FALSE, size = 5)

dev.off()

###compare the remaining factor levels
car::linearHypothesis(metareg.method.recat.lnRR, rbind(c(0, 1, -1))) # City Comparison vs. Urban-Rural


##################
# continent lnRR
##################

#to test if the continent influences the effect size
metareg.continent.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                 mods = ~ continent, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.lnRR)

print(metareg.continent.lnRR, digits=2)

###calculate marginal R2 with r2_ml
R2.continent <- r2_ml(metareg.continent.lnRR)
round(R2.continent*100,1) # in %


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                        mods = ~ continent - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.lnRR)

print(metareg.continent.lnRR.no.int, digits=2)


tiff("figures/supplements/S02_Continent_lnRR.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.lnRR.no.int, mod = "continent", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.46, 0.077),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6,6),breaks = c(seq(-6,6,1))) +
  annotate(geom="text", x=6.34, y=-5, label=paste0("italic(R)^{2} == ", round(R2.continent[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=6.30, y=-3.7, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 1, -1, 0, 0, 0))) # North America vs. South America
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 1, 0, -1, 0, 0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 1, 0, 0, -1, 0))) # North America vs. Oceania
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 1, 0, 0, 0, -1))) # North America vs. Africa
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 0, 1, -1, 0, 0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 0, 1, 0, -1, 0))) # South America vs. Oceania
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 0, 1, 0, 0, -1))) # South America vs. Africa
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 0, 0, 1, -1, 0))) # Asia vs. Oceania
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 0, 0, 1, 0, -1))) # Asia vs. Africa
car::linearHypothesis(metareg.continent.lnRR, rbind(c(0, 0, 0, 0, 1, -1))) # Oceania vs. Africa


#################################
# continent lnRR (recategorized)
#################################

#to test if the continent influences the effect size
metareg.continent.2.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                 mods = ~ continent.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.lnRR)

print(metareg.continent.2.lnRR, digits=2)

###calculate marginal R2 with r2_ml
R2.continent.2 <- r2_ml(metareg.continent.2.lnRR)
round(R2.continent.2*100,1) # in %


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.2.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                        mods = ~ continent.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.lnRR)

print(metareg.continent.2.lnRR.no.int, digits=2)


tiff("figures/supplements/S02_Continent_lnRR_Recat.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.2.lnRR.no.int, mod = "continent.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.46, 0.077),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6,6),breaks = c(seq(-6,6,1))) +
  annotate(geom="text", x=5.34, y=-5, label=paste0("italic(R)^{2} == ", round(R2.continent.2[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=5.31, y=-3.7, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.continent.2.lnRR, rbind(c(0,1,-1,0,0))) # North America vs. South America
car::linearHypothesis(metareg.continent.2.lnRR, rbind(c(0,1,0,-1,0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.2.lnRR, rbind(c(0,1,0,0,-1))) # North America vs. Others
car::linearHypothesis(metareg.continent.2.lnRR, rbind(c(0,0,1,-1,0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.2.lnRR, rbind(c(0,0,1,0,-1))) # South America vs. Others
car::linearHypothesis(metareg.continent.2.lnRR, rbind(c(0,0,0,1,-1))) # Asia vs. Others


#################
# scale lnRR
#################

#to test if the scale influences the effect size
metareg.scale.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                             mods = ~ scale, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method="REML", 
                             test="t", 
                             data=meta.final.lnRR)

print(metareg.scale.lnRR, digits=2)

###calculate marginal R2 with r2_ml
R2.scale <- r2_ml(metareg.scale.lnRR)
round(R2.scale*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.scale.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                    mods = ~ scale - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method="REML", 
                                    test="t", 
                                    data=meta.final.lnRR)

print(metareg.scale.lnRR.no.int, digits=2)


tiff("figures/supplements/S03_Scale_lnRR.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.scale.lnRR.no.int, mod = "scale", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.43, 0.084),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6,6),breaks = c(seq(-6,6,1))) +
  annotate(geom="text", x=3.45, y=-5, label=paste0("italic(R)^{2} == ", round(R2.scale[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.43, y=-3.7, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.scale.lnRR, rbind(c(0,1,-1))) # Local vs. Regional


#################
# diversity lnRR
#################

#to test if the diversity index influences the effect size
metareg.diversity.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                 mods = ~ diversity, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.lnRR)

print(metareg.diversity.lnRR, digits=2)

###calculate marginal R2 with r2_ml
R2.diversity <- r2_ml(metareg.diversity.lnRR)
round(R2.diversity*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.diversity.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                        mods = ~ diversity - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.lnRR)

print(metareg.diversity.lnRR.no.int, digits=2)


tiff("figures/supplements/S04_Diversity_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.diversity.lnRR.no.int, mod = "diversity", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.36, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6,6),breaks = c(seq(-6,6,1))) +
  annotate(geom="text", x=4.44, y=-5, label=paste0("italic(R)^{2} == ", round(R2.diversity[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=4.41, y=-3.6, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.diversity.lnRR, rbind(c(0, 1, -1, 0))) # Taxonomic diversity: others vs. Functional diversity
car::linearHypothesis(metareg.diversity.lnRR, rbind(c(0, 1, 0, -1))) # Taxonomic diversity: others vs. Abundance
car::linearHypothesis(metareg.diversity.lnRR, rbind(c(0, 0, 1, -1))) # Functional diversity vs. Abundance


#################
# Class lnRR
#################

#to test if the Class influences the effect size
metareg.Class.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                             mods = ~ Class, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method="REML", 
                             test="t", 
                             data=meta.final.lnRR)

print(metareg.Class.lnRR, digits=2)

###calculate marginal R2 with r2_ml
R2.Class <- r2_ml(metareg.Class.lnRR)
round(R2.Class*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                    mods = ~ Class - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method="REML", 
                                    test="t", 
                                    data=meta.final.lnRR)

print(metareg.Class.lnRR.no.int, digits=2)


tiff("figures/supplements/S05_Class_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnRR.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.43, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6,6),breaks = c(seq(-6,6,1))) +
  annotate(geom="text", x=5.40, y=-5, label=paste0("italic(R)^{2} == ", round(R2.Class[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=5.35, y=-3.8, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnRR, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnRR, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnRR, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnRR, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnRR, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnRR, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


#################
# Order
#################

# To test if the Order influences the effect size
metareg.Order.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                        mods = ~ Order.2, 
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML", 
                        test = "t", 
                        data = meta.final.lnRR)

print(metareg.Order.lnRR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnRR <- r2_ml(metareg.Order.lnRR)
round(R2.Order.lnRR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                               mods = ~ Order.2 - 1, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method = "REML", 
                               test = "t", 
                               data = meta.final.lnRR)

print(metareg.Order.lnRR.no.int, digits=3)


tiff("figures/supplements/S06_Order_Insecta_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnRR.no.int, mod = "Order.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6, 6), breaks = c(seq(-6, 6, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 12.7, y = -5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnRR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 12.62, y = -3.6, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnRR, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnRR, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnRR, rbind(c(0, 0, 0, 1, -1))) #  vs. 


#################
# Order (EPT)
#################

# To test if the Order influences the effect size
metareg.Order.EPT.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                            mods = ~ Order.3, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method = "REML", 
                            test = "t", 
                            data = meta.final.lnRR)

print(metareg.Order.EPT.lnRR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.EPT.lnRR <- r2_ml(metareg.Order.EPT.lnRR)
round(R2.Order.EPT.lnRR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.EPT.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                   mods = ~ Order.3 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method = "REML", 
                                   test = "t", 
                                   data = meta.final.lnRR)

print(metareg.Order.EPT.lnRR.no.int, digits=3)


tiff("figures/supplements/S06_Order_Insecta_EPT_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.EPT.lnRR.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-6, 6), breaks = c(seq(-6, 6, 1))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 9.60, y = -5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.EPT.lnRR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 9.52, y = -3.6, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
# Hemiptera and Orthoptera not considered as n<10
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 1, -1, 0, 0, 0, 0, 0, 0))) # Diptera vs. EPT
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 1, 0, 0, -1, 0, 0, 0, 0))) # Diptera vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 1, 0, 0, 0, -1, 0, 0, 0))) # Diptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 1, 0, 0, 0, 0, -1, 0, 0))) # Diptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 1, 0, 0, 0, 0, 0, 0, -1))) # Diptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 1, 0, -1, 0, 0, 0, 0))) # EPT vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 1, 0, 0, -1, 0, 0, 0))) # EPT vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 1, 0, 0, 0, -1, 0, 0))) # EPT vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 1, 0, 0, 0, 0, 0, -1))) # EPT vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 0, 0, 1, -1, 0, 0, 0))) # Hymenoptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 0, 0, 1, 0, -1, 0, 0))) # Hymenoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 0, 0, 0, 0, 0, 0, -1))) # Hymenoptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 0, 0, 0, 1, -1, 0, 0))) # Lepidoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 0, 0, 0, 1, 0, 0, -1))) # Lepidoptera vs. Non - Insect Orders
car::linearHypothesis(metareg.Order.EPT.lnRR, rbind(c(0, 0, 0, 0, 0, 0, 1, 0, -1))) # Odonata vs. Non - Insect Orders


#################
# Family
#################

# To test if the Family influences the effect size
metareg.Family.lnRR <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                         mods = ~ Family.2, 
                         random = list(~ 1 | studyID,
                                       ~ 1 | comparisonID,
                                       ~ 1 | locationID,
                                       ~ 1 | obsID),
                         method = "REML", 
                         test = "t", 
                         data = meta.final.lnRR)

print(metareg.Family.lnRR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnRR <- r2_ml(metareg.Family.lnRR)
round(R2.Family.lnRR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnRR.no.int <- rma.mv(lnRR, VCV_ESVar.lnRR, 
                                mods = ~ Family.2 - 1, 
                                random = list(~ 1 | studyID,
                                              ~ 1 | comparisonID,
                                              ~ 1 | locationID,
                                              ~ 1 | obsID),
                                method = "REML", 
                                test = "t", 
                                data = meta.final.lnRR)

print(metareg.Family.lnRR.no.int, digits=3)


tiff("figures/supplements/S07_Family_lnRR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnRR.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnRR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5, 5), breaks = c(seq(-5, 5, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -4, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnRR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -3, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 1, -1, 0, 0, 0, 0))) # Calliphoridae vs. Carabidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 1, 0, -1, 0, 0, 0))) # Calliphoridae vs. Culicidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 1, 0, 0, -1, 0, 0))) # Calliphoridae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 1, 0, 0, 0, -1, 0))) # Calliphoridae vs. Formicidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 1, 0, 0, 0, 0, -1))) # Calliphoridae vs. Other Families

car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 1, -1, 0, 0, 0))) # Carabidae vs. Culicidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 1, 0, -1, 0, 0))) # Carabidae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 1, 0, 0, -1, 0))) # Carabidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 1, 0, 0, 0, -1))) # Carabidae vs. Other Families

car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 0, 1, -1, 0, 0))) # Culicidae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 0, 1, 0, -1, 0))) # Culicidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 0, 1, 0, 0, -1))) # Culicidae vs. Other Families

car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 0, 0, 1, -1, 0))) # Drosophilidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 0, 0, 1, 0, -1))) # Drosophilidae vs. Other Families
car::linearHypothesis(metareg.Family.lnRR, rbind(c(0, 0, 0, 0, 0, 1, -1))) # Formicidae vs. Other Families


################################################################################




################################################################################
# Sampling variance-covariance matrix SMDH
################################################################################

# subset
meta.final.SMDH <- meta.final.SA

# there are some clear outliers that we are going to exclude from the SMDH analyses 
meta.final.SMDH <- meta.final.SMDH[meta.final.SMDH$SMDH.vi<6,]
meta.final.SMDH <- meta.final.SMDH[meta.final.SMDH$SMDH>(-7),]


# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.SMDH <- matrix(0, nrow = nrow(meta.final.SMDH), 
                         ncol = nrow(meta.final.SMDH))

# names rows and columns for each obsID
rownames(VCV_ESVar.SMDH) <- meta.final.SMDH[, "obsID"]
colnames(VCV_ESVar.SMDH) <- meta.final.SMDH[, "obsID"]

# finds effect sizes that come from the same study
shared_coord <- which(meta.final.SMDH[, "studyID"] %in% 
                        meta.final.SMDH[duplicated(meta.final.SMDH[,"studyID"]), 
                                      "studyID"] == TRUE)

combinations <- do.call("rbind", tapply(shared_coord, 
                                        meta.final.SMDH[shared_coord,"studyID"], 
                                        function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations)[1]) {
  p1 <- combinations[i, 1]
  p2 <- combinations[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.SMDH[p1, "SMDH.vi"]) * sqrt(meta.final.SMDH[p2, "SMDH.vi"])
  VCV_ESVar.SMDH[p1, p2] <- p1_p2_cov
  VCV_ESVar.SMDH[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.SMDH) <- meta.final.SMDH[, "SMDH.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.SMDH, 'VCV_ESVar.SMDH.csv')


################################################################################
# SMDH
################################################################################

#Data funnel plot
par(mfrow = c(1, 2))
funnel(meta.final.SMDH$SMDH, meta.final.SMDH$SMDH.vi, yaxis="sei",
       xlab = "Effect size (SMDH)", digits = 2, las = 1)
funnel(meta.final.SMDH$SMDH, meta.final.SMDH$SMDH.vi, yaxis="seinv",
       xlab = "Effect size (SMDH)",  digits = 2, las = 1)


# MAIN MODEL = multilevel meta-analysis
model.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                     random = list(~ 1 | studyID,
                                   ~ 1 | comparisonID,
                                   ~ 1 | locationID,
                                   ~ 1 | obsID), 
                     method="REML", 
                     test="t", 
                     data=meta.final.SMDH)

print(model.SMDH, digits=2)
predict(model.SMDH, digits=3)

#model funnel plot
par(mfrow = c(1, 1))
funnel(model.SMDH)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model.SMDH <- i2_ml(model.SMDH)
round(I2.model.SMDH,2)


#########################
# method (recategorized) SMDH
#########################

#to test if the method influences the effect size
metareg.method.recat.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                              mods = ~ method.recat, 
                              random = list(~ 1 | studyID,
                                            ~ 1 | comparisonID,
                                            ~ 1 | locationID,
                                            ~ 1 | obsID),
                              method="REML", 
                              test="t", 
                              data=meta.final.SMDH)

print(metareg.method.recat.SMDH, digits=3)

###calculate marginal R2 with r2_ml
R2.method <- r2_ml(metareg.method.recat.SMDH)
round(R2.method*100,2) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.method.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                     mods = ~ method.recat - 1, 
                                     random = list(~ 1 | studyID,
                                                   ~ 1 | comparisonID,
                                                   ~ 1 | locationID,
                                                   ~ 1 | obsID),
                                     method="REML", 
                                     test="t", 
                                     data=meta.final.SMDH)

print(metareg.method.SMDH.no.int, digits=3)


tiff("figures/supplements/S01_Methods_SMDH.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.method.SMDH.no.int, mod = "method.recat", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.39, 0.085),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7,7),breaks = c(seq(-7,7,1))) +
  annotate(geom="text", x=3.43, y=-5, label=paste0("italic(R)^{2} == ", round(R2.method[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.41, y=-3.4, label="%",color="black", parse = FALSE, size = 5)

dev.off()

###compare the remaining factor levels
car::linearHypothesis(metareg.method.recat.SMDH, rbind(c(0, 1, -1))) # City Comparison vs. Urban-Rural


#################
# continent SMDH
#################

#to test if the continent influences the effect size
metareg.continent.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                 mods = ~ continent, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.SMDH)

print(metareg.continent.SMDH, digits=3)

###calculate marginal R2 with r2_ml
R2.continent <- r2_ml(metareg.continent.SMDH)
round(R2.continent*100,2) # in %


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                        mods = ~ continent - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.SMDH)

print(metareg.continent.SMDH.no.int, digits=3)


tiff("figures/supplements/S02_Continent_SMDH.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.SMDH.no.int, mod = "continent", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.46, 0.077),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7,7),breaks = c(seq(-7,7,1))) +
  annotate(geom="text", x=6.35, y=-6, label=paste0("italic(R)^{2} == ", round(R2.continent[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=6.32, y=-4.6, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 1, -1, 0, 0, 0))) # North America vs. South America
car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 1, 0, -1, 0, 0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 1, 0, 0, -1, 0))) # North America vs. Oceania
car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 1, 0, 0, 0, -1))) # North America vs. Africa

car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 0, 1, -1, 0, 0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 0, 1, 0, -1, 0))) # South America vs. Oceania
car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 0, 1, 0, 0, -1))) # South America vs. Africa

car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 0, 0, 1, -1, 0))) # Asia vs. Oceania
car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 0, 0, 1, 0, -1))) # Asia vs. Africa
car::linearHypothesis(metareg.continent.SMDH, rbind(c(0, 0, 0, 0, 1, -1))) # Oceania vs. Africa


#################################
# continent SMDH (recategorized)
#################################

#to test if the continent influences the effect size
metareg.continent.2.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                 mods = ~ continent.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.SMDH)

print(metareg.continent.2.SMDH, digits=3)

###calculate marginal R2 with r2_ml
R2.continent.2 <- r2_ml(metareg.continent.2.SMDH)
round(R2.continent.2*100,2) # in %


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.2.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                        mods = ~ continent.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.SMDH)

print(metareg.continent.2.SMDH.no.int, digits=3)


tiff("figures/supplements/S02_Continent_SMDH_Recat.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.2.SMDH.no.int, mod = "continent.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.46, 0.077),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7,7),breaks = c(seq(-7,7,1))) +
  annotate(geom="text", x=5.35, y=-6, label=paste0("italic(R)^{2} == ", round(R2.continent.2[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=5.32, y=-4.6, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.continent.2.SMDH, rbind(c(0,1,-1,0,0))) # North America vs. South America
car::linearHypothesis(metareg.continent.2.SMDH, rbind(c(0,1,0,-1,0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.2.SMDH, rbind(c(0,1,0,0,-1))) # North America vs. Others
car::linearHypothesis(metareg.continent.2.SMDH, rbind(c(0,0,1,-1,0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.2.SMDH, rbind(c(0,0,1,0,-1))) # South America vs. Others
car::linearHypothesis(metareg.continent.2.SMDH, rbind(c(0,0,0,1,-1))) # Asia vs. Others


#################
# scale SMDH
#################

#to test if the scale influences the effect size
metareg.scale.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                             mods = ~ scale, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method="REML", 
                             test="t", 
                             data=meta.final.SMDH)

print(metareg.scale.SMDH, digits=3)

###calculate marginal R2 with r2_ml
R2.scale <- r2_ml(metareg.scale.SMDH)
round(R2.scale*100,2) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.scale.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                    mods = ~ scale - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method="REML", 
                                    test="t", 
                                    data=meta.final.SMDH)

print(metareg.scale.SMDH.no.int, digits=3)


tiff("figures/supplements/S03_Scale_SMDH.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.scale.SMDH.no.int, mod = "scale", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.43, 0.084),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7,7),breaks = c(seq(-7,7,1))) +
  annotate(geom="text", x=3.45, y=-6, label=paste0("italic(R)^{2} == ", round(R2.scale[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.43, y=-4.6, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.scale.SMDH, rbind(c(0,1,-1))) # Local vs. Regional


#################
# diversity SMDH
#################

#to test if the diversity index influences the effect size
metareg.diversity.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                 mods = ~ diversity, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.SMDH)

print(metareg.diversity.SMDH, digits=3)

###calculate marginal R2 with r2_ml
R2.diversity <- r2_ml(metareg.diversity.SMDH)
round(R2.diversity*100,2) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.diversity.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                        mods = ~ diversity - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.SMDH)

print(metareg.diversity.SMDH.no.int, digits=3)


tiff("figures/supplements/S04_Diversity_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.diversity.SMDH.no.int, mod = "diversity", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.36, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7,7),breaks = c(seq(-7,7,1))) +
  annotate(geom="text", x=4.44, y=-5.6, label=paste0("italic(R)^{2} == ", round(R2.diversity[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=4.41, y=-4.1, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.diversity.SMDH, rbind(c(0, 1, -1, 0))) # Taxonomic diversity: others vs. Functional diversity
car::linearHypothesis(metareg.diversity.SMDH, rbind(c(0, 1, 0, -1))) # Taxonomic diversity: others vs. Abundance
car::linearHypothesis(metareg.diversity.SMDH, rbind(c(0, 0, 1, -1))) # Functional diversity vs. Abundance


#################
# Class SMDH
#################

#to test if the Class influences the effect size
metareg.Class.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                             mods = ~ Class, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method="REML", 
                             test="t", 
                             data=meta.final.SMDH)

print(metareg.Class.SMDH, digits=3)

###calculate marginal R2 with r2_ml
R2.Class <- r2_ml(metareg.Class.SMDH)
round(R2.Class*100,2) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                    mods = ~ Class - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method="REML", 
                                    test="t", 
                                    data=meta.final.SMDH)

print(metareg.Class.SMDH.no.int, digits=3)


tiff("figures/supplements/S05_Class_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.SMDH.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.43, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7,7),breaks = c(seq(-7,7,1))) +
  annotate(geom="text", x=5.40, y=-6, label=paste0("italic(R)^{2} == ", round(R2.Class[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=5.36, y=-4.7, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.Class.SMDH, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.SMDH, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.SMDH, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.SMDH, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.SMDH, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.SMDH, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


#################
# Order
#################

# To test if the Order influences the effect size
metareg.Order.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                             mods = ~ Order.2, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method = "REML", 
                             test = "t", 
                             data = meta.final.SMDH)

print(metareg.Order.SMDH, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.SMDH <- r2_ml(metareg.Order.SMDH)
round(R2.Order.SMDH*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                    mods = ~ Order.2 - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method = "REML", 
                                    test = "t", 
                                    data = meta.final.SMDH)

print(metareg.Order.SMDH.no.int, digits=3)


tiff("figures/supplements/S06_Order_Insecta_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.SMDH.no.int, mod = "Order.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7, 7), breaks = c(seq(-7, 7, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 12.7, y = -6, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.SMDH[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 12.62, y = -4.4, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.SMDH, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.SMDH, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.SMDH, rbind(c(0, 0, 0, 1, -1))) #  vs. 


#################
# Order (EPT)
#################

# To test if the Order influences the effect size
metareg.Order.EPT.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                 mods = ~ Order.3, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.SMDH)

print(metareg.Order.EPT.SMDH, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.EPT.SMDH <- r2_ml(metareg.Order.EPT.SMDH)
round(R2.Order.EPT.SMDH*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.EPT.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                        mods = ~ Order.3 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.SMDH)

print(metareg.Order.EPT.SMDH.no.int, digits=3)


tiff("figures/supplements/S06_Order_Insecta_EPT_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.EPT.SMDH.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7, 7), breaks = c(seq(-7, 7, 1))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 9.60, y = -6, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.EPT.SMDH[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 9.52, y = -4.4, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels 
# Hemiptera and Orthoptera not considered as n<10
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 1, -1, 0, 0, 0, 0, 0, 0))) # Diptera vs. EPT
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 1, 0, 0, -1, 0, 0, 0, 0))) # Diptera vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 1, 0, 0, 0, -1, 0, 0, 0))) # Diptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 1, 0, 0, 0, 0, -1, 0, 0))) # Diptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 1, 0, 0, 0, 0, 0, 0, -1))) # Diptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 1, 0, -1, 0, 0, 0, 0))) # EPT vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 1, 0, 0, -1, 0, 0, 0))) # EPT vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 1, 0, 0, 0, -1, 0, 0))) # EPT vs. Odonata
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 1, 0, 0, 0, 0, 0, -1))) # EPT vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 0, 0, 1, -1, 0, 0, 0))) # Hymenoptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 0, 0, 1, 0, -1, 0, 0))) # Hymenoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 0, 0, 0, 0, 0, 0, -1))) # Hymenoptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 0, 0, 0, 1, -1, 0, 0))) # Lepidoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 0, 0, 0, 1, 0, 0, -1))) # Lepidoptera vs. Non - Insect Orders
car::linearHypothesis(metareg.Order.EPT.SMDH, rbind(c(0, 0, 0, 0, 0, 0, 1, 0, -1))) # Odonata vs. Non - Insect Orders



#################
# Family
#################

# To test if the Family influences the effect size
metareg.Family.SMDH <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                              mods = ~ Family.2, 
                              random = list(~ 1 | studyID,
                                            ~ 1 | comparisonID,
                                            ~ 1 | locationID,
                                            ~ 1 | obsID),
                              method = "REML", 
                              test = "t", 
                              data = meta.final.SMDH)

print(metareg.Family.SMDH, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.SMDH <- r2_ml(metareg.Family.SMDH)
round(R2.Family.SMDH*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.SMDH.no.int <- rma.mv(SMDH, VCV_ESVar.SMDH, 
                                     mods = ~ Family.2 - 1, 
                                     random = list(~ 1 | studyID,
                                                   ~ 1 | comparisonID,
                                                   ~ 1 | locationID,
                                                   ~ 1 | obsID),
                                     method = "REML", 
                                     test = "t", 
                                     data = meta.final.SMDH)

print(metareg.Family.SMDH.no.int, digits=3)


tiff("figures/supplements/S07_Family_SMDH.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.SMDH.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.SMDH,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-7, 7), breaks = c(seq(-7, 7, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -6, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.SMDH[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -4.6, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 1, -1, 0, 0, 0, 0))) # Calliphoridae vs. Carabidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 1, 0, -1, 0, 0, 0))) # Calliphoridae vs. Culicidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 1, 0, 0, -1, 0, 0))) # Calliphoridae vs. Drosophilidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 1, 0, 0, 0, -1, 0))) # Calliphoridae vs. Formicidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 1, 0, 0, 0, 0, -1))) # Calliphoridae vs. Other Families

car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 1, -1, 0, 0, 0))) # Carabidae vs. Culicidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 1, 0, -1, 0, 0))) # Carabidae vs. Drosophilidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 1, 0, 0, -1, 0))) # Carabidae vs. Formicidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 1, 0, 0, 0, -1))) # Carabidae vs. Other Families

car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 0, 1, -1, 0, 0))) # Culicidae vs. Drosophilidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 0, 1, 0, -1, 0))) # Culicidae vs. Formicidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 0, 1, 0, 0, -1))) # Culicidae vs. Other Families

car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 0, 0, 1, -1, 0))) # Drosophilidae vs. Formicidae
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 0, 0, 1, 0, -1))) # Drosophilidae vs. Other Families
car::linearHypothesis(metareg.Family.SMDH, rbind(c(0, 0, 0, 0, 0, 1, -1))) # Formicidae vs. Other Families

