################################################################################
# Authors: 
# Alfredo Sanchez-Tojar (with support from Endika Blanco)

# Script first created in Nov 2018

################################################################################
# Description of script and Instructions
################################################################################

# This script is for a meta-analysis on the effect of urbanization on 
# biodiversity.

################################################################################
# Packages needed
################################################################################

# Clear memory
rm(list=ls())

###install.packages("pacman")
# devtools::install_github("itchyshin/orchard_plot", subdir = "orchaRd", 
#                          force = TRUE, build_vignettes = TRUE)
# devtools::install_github("daniel1noble/orchaRd", force = TRUE)
pacman::p_load(devtools, tidyverse, metafor, patchwork, R.rsp, orchaRd, emmeans,
               ape, phytools, report, car) #dplyr, ggplot2


################################################################################
# Using other effect sizes: lnCVR AND lnVR for extra sensitivity analyses
################################################################################

# importing the dataset for these tests and later on adjusting all variables
# as done for the main dataset above
meta.final.SA <- read.table("meta_final_reduced_sensitivity_analyses.csv",
                            header=T, sep=",")


# Modifying variables type
meta.final.SA$studyID <- as.factor(meta.final.SA$studyID)
meta.final.SA$es_type <- as.factor(meta.final.SA$es_type)


# Creating a new variable to categorize effects as biserial correlations, 
# Pearson's correlation coefficients or effects from inferential statistics
meta.final.SA$es_type_2 <- as.factor(ifelse(meta.final.SA$es_type %in% 
                                              c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                            "biserial_correlation",
                                            ifelse(meta.final.SA$es_type %in% 
                                                     c("pearsons", "spearmans"),
                                                   "correlation_coefficient",
                                                   "inferential_statistic")))

# METHOD
# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                                 mutate(method= 
                                          factor(method, 
                                                 levels=c("Urban Gradient",
                                                          "City Comparison",
                                                          "Urban-Rural",
                                                          "Temporal Urban Gradient"))))


# Generating a new method that accounts for the fact that for some of the data
# originally reported as gradients we later on had to extract only the extremes
# (i.e. most urbanized vs least urbanized), normally from figures, to be able to
# calculate biserial correlations. In these cases, these estimates are going to
# now be categorized as "Urban-Rural" as the original continuous nature of the
# measurement was then changed
meta.final.SA$method.recat <- ifelse(as.character(meta.final.SA$method) %in% 
                                       c("Urban Gradient") &
                                       as.character(meta.final.SA$es_type) %in% 
                                       c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                     "Urban-Rural", 
                                     as.character(meta.final.SA$method))

# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                                 mutate(method.recat= 
                                          factor(method.recat, 
                                                 levels=c("Urban Gradient",
                                                          "City Comparison",
                                                          "Urban-Rural",
                                                          "Temporal Urban Gradient"))))


# CONTINENT
# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                                 mutate(continent=
                                          factor(continent, 
                                                 levels=c("Europe",
                                                          "North America",
                                                          "South America",
                                                          "Asia",
                                                          "Oceania",
                                                          "Africa"))))


# since sample sizes were to small for the original idea, we have recoded the 
# factor so that the sample sizes are decent and still biologically meaningful
meta.final.SA$continent.2 <- as.factor(ifelse(meta.final.SA$continent=="Africa" | 
                                                meta.final.SA$continent=="Oceania", 
                                              "Others", as.character(meta.final.SA$continent)))

table(meta.final.SA$continent.2)

# We reorder the levels so that the reference level (intercept) is Europe
meta.final.SA <- as.data.frame(meta.final.SA %>%
                                 mutate(continent.2=
                                          factor(continent.2, 
                                                 levels=c("Europe",
                                                          "North America",
                                                          "South America",
                                                          "Asia",
                                                          "Others"))))


# SCALE
# We reorder the levels so that the reference level (intercept) is City. The 
# order of goes from smaller to larger scale
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                                 mutate(scale= 
                                          factor(scale, 
                                                 levels=c("City",
                                                          "Local",
                                                          "Regional"))))


# DIVERSITY
# We reorder the levels so that the reference level (intercept) is Richness, but
# first we recode the level names to make them more informative and standardized
meta.final.SA$diversity <- dplyr::recode(meta.final.SA$diversity, 
                                         "Other taxonomic diversity measure"= 
                                           "Taxonomic diversity: others", #to keep consistency with the other analyses, also shorter names are better for the plots and tables
                                         "Richness"="Taxonomic diversity: richness")

meta.final.SA <- as.data.frame(meta.final.SA %>% 
                                 mutate(diversity= 
                                          factor(diversity, 
                                                 levels=c("Taxonomic diversity: richness",
                                                          "Taxonomic diversity: others",
                                                          "Functional diversity",
                                                          "Abundance"))))


# Class
# Customizing the order of the factor levels. We reorder the levels so that the 
# reference level (intercept) is Insecta
meta.final.SA <- as.data.frame(meta.final.SA %>% 
                                 mutate(Class = factor(Class, 
                                                       levels=c("Insecta",
                                                                "Arachnida",
                                                                "Crustacea",
                                                                "Myriapoda",
                                                                "Entognatha"))))


# ORDER
table(meta.final.SA$Order)

#Subset for Insect Orders (Orders of the rest of Classes too small)
meta.final.SA$Order.2 <- ifelse(as.character(meta.final.SA$Order) %in% 
                                  c("Araneae", "Decapoda", "Diplostraca",
                                    "Harpacticoida", "Isopoda", "Ixodida",
                                    "Opiliones", "Spirostreptida",
                                    "Diplostraca", "Trombidiformes"),
                                "Non-Insect Orders", 
                                as.character(meta.final.SA$Order))

meta.final.SA$Order.2 <- factor(meta.final.SA$Order.2)
table(meta.final.SA$Order.2)


#Subset for Insect Orders, after unifying EPT orders into EPT.
meta.final.SA$Order.3 <- ifelse(as.character(meta.final.SA$Order.2) %in% 
                                  c("Ephemeroptera","Plecoptera","Trichoptera"),
                                "EPT", 
                                as.character(meta.final.SA$Order.2))

# We reorder the levels
meta.final.SA <- as.data.frame(meta.final.SA %>%
                              mutate(Order.3=
                                       factor(Order.3, 
                                              levels=c("Coleoptera",
                                                       "Diptera",
                                                       "EPT",
                                                       "Hemiptera",
                                                       "Hymenoptera",
                                                       "Lepidoptera",
                                                       "Odonata",
                                                       "Orthoptera",
                                                       "Non-Insect Orders"))))

meta.final.SA$Order.3 <- factor(meta.final.SA$Order.3)
table(meta.final.SA$Order.3)


# FAMILY
table(meta.final.SA$Family)

#Joining "Apidae" to "Apoidea" superfamily
meta.final.SA$Family.2 <- factor(meta.final.SA$Family)
meta.final.SA$Family.2 <- ifelse(as.character(meta.final.SA$Family.2) %in% 
                                   c("Apidae"), "Apoidea", 
                                 as.character(meta.final.SA$Family.2))

#Subset for Insect Families with enough data (10<)
meta.final.SA$Family.2 <- ifelse(as.character(meta.final.SA$Family.2) %in% 
                                   c("Anisoptera", "bat-flies", "Chironomidae",
                                     "Chloropidae", "Coccinellidae", "Cynipidae",
                                     "Geometridae", "Hydrachnidia", "Psychodidae",
                                     "Sarcophagidae", "Scarabaeidae", "Silphidae",
                                     "Sphecidae", "Staphylinidae", "Syrphidae",
                                     "Tachinidae", "Tenebrionidae", "Thomisidae",
                                     "Vespidae", "Zygoptera"),
                                 "Other Families", 
                                 as.character(meta.final.SA$Family.2))

meta.final.SA$Family.2 <- factor(meta.final.SA$Family.2)
table(meta.final.SA$Family.2)


################################################################################
# Sampling variance-covariance matrix lnCRV
################################################################################

# subset
meta.final.lnCVR <- meta.final.SA

# there is a clear outliers that we are going to exclude from the lnCVR 
# analyses. 
meta.final.lnCVR <- meta.final.lnCVR[meta.final.lnCVR$lnCVR<5 & 
                                     meta.final.lnCVR$lnCVR>-5 & 
                                 !(is.na(meta.final.lnCVR$lnCVR.vi)),]


# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnCVR <- matrix(0, nrow = nrow(meta.final.lnCVR), 
                          ncol = nrow(meta.final.lnCVR))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnCVR) <- meta.final.lnCVR[, "obsID"]
colnames(VCV_ESVar.lnCVR) <- meta.final.lnCVR[, "obsID"]

# finds effect sizes that come from the same study
shared_coord <- which(meta.final.lnCVR[, "studyID"] %in% 
                        meta.final.lnCVR[duplicated(meta.final.lnCVR[,"studyID"]), 
                                      "studyID"] == TRUE)

combinations <- do.call("rbind", tapply(shared_coord, 
                                        meta.final.lnCVR[shared_coord,"studyID"], 
                                        function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations)[1]) {
  p1 <- combinations[i, 1]
  p2 <- combinations[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnCVR[p1, "lnCVR.vi"]) * sqrt(meta.final.lnCVR[p2, "lnCVR.vi"])
  VCV_ESVar.lnCVR[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnCVR[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnCVR) <- meta.final.lnCVR[, "lnCVR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnCVR, 'VCV_ESVar.lnCVR.csv')


################################################################################
# lnCVR
################################################################################

#Data funnel plot
par(mfrow = c(1, 2))
funnel(meta.final.lnCVR$lnCVR, meta.final.lnCVR$lnCVR.vi, yaxis="sei",
       xlab = "Effect size (lnCVR)", digits = 2, las = 1)
funnel(meta.final.lnCVR$lnCVR, meta.final.lnCVR$lnCVR.vi, yaxis="seinv",
       xlab = "Effect size (lnCVR)",  digits = 2, las = 1)


# MAIN MODEL = multilevel meta-analysis
model.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                      random = list(~ 1 | studyID,
                                    ~ 1 | comparisonID,
                                    ~ 1 | locationID,
                                    ~ 1 | obsID), 
                      method="REML", 
                      test="t", 
                      data=meta.final.lnCVR)

print(model.lnCVR, digits=2)
predict(model.lnCVR, digits=2)

#model funnel plot
par(mfrow = c(1, 1))
funnel(model.lnCVR)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model.lnCVR <- i2_ml(model.lnCVR)
round(I2.model.lnCVR,1)


#########################
# method (recategorized) lnCVR
#########################

#to test if the method influences the effect size
metareg.method.recat.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                               mods = ~ method.recat, 
                               random = list(~ 1 | studyID,
                                             ~ 1 | comparisonID,
                                             ~ 1 | locationID,
                                             ~ 1 | obsID),
                               method="REML", 
                               test="t", 
                               data=meta.final.lnCVR)

print(metareg.method.recat.lnCVR, digits=2)

###calculate marginal R2 with r2_ml
R2.method <- r2_ml(metareg.method.recat.lnCVR)
round(R2.method*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.method.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                      mods = ~ method.recat - 1, 
                                      random = list(~ 1 | studyID,
                                                    ~ 1 | comparisonID,
                                                    ~ 1 | locationID,
                                                    ~ 1 | obsID),
                                      method="REML", 
                                      test="t", 
                                      data=meta.final.lnCVR)

print(metareg.method.lnCVR.no.int, digits=2)


tiff("figures/supplements/S01_Methods_lnCVR.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.method.lnCVR.no.int, mod = "method.recat", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.39, 0.085),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5,3.5),breaks = c(seq(-3.5,3.5,0.5))) +
  annotate(geom="text", x=3.43, y=-2.5, label=paste0("italic(R)^{2} == ", round(R2.method[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.40, y=-1.7, label="%",color="black", parse = FALSE, size = 5)

dev.off()

###compare the remaining factor levels
car::linearHypothesis(metareg.method.recat.lnCVR, rbind(c(0, 1, -1))) # City Comparison vs. Urban-Rural


#################
# continent lnCVR
#################

#to test if the continent influences the effect size
metareg.continent.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                  mods = ~ continent, 
                                  random = list(~ 1 | studyID,
                                                ~ 1 | comparisonID,
                                                ~ 1 | locationID,
                                                ~ 1 | obsID),
                                  method="REML", 
                                  test="t", 
                                  data=meta.final.lnCVR)

print(metareg.continent.lnCVR, digits=2)

###calculate marginal R2 with r2_ml
R2.continent <- r2_ml(metareg.continent.lnCVR)
round(R2.continent*100,1) # in %


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                         mods = ~ continent - 1, 
                                         random = list(~ 1 | studyID,
                                                       ~ 1 | comparisonID,
                                                       ~ 1 | locationID,
                                                       ~ 1 | obsID),
                                         method="REML", 
                                         test="t", 
                                         data=meta.final.lnCVR)

print(metareg.continent.lnCVR.no.int, digits=2)


tiff("figures/supplements/S02_Continent_lnCVR.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.lnCVR.no.int, mod = "continent", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.46, 0.077),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5,3.5),breaks = c(seq(-3.5,3.5,0.5))) +
  annotate(geom="text", x=6.35, y=-2.5, label=paste0("italic(R)^{2} == ", round(R2.continent[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=6.32, y=-1.8, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 1, -1, 0, 0, 0))) # North America vs. South America
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 1, 0, -1, 0, 0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 1, 0, 0, -1, 0))) # North America vs. Oceania
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 1, 0, 0, 0, -1))) # North America vs. Africa
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 0, 1, -1, 0, 0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 0, 1, 0, -1, 0))) # South America vs. Oceania
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 0, 1, 0, 0, -1))) # South America vs. Africa
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 0, 0, 1, -1, 0))) # Asia vs. Oceania
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 0, 0, 1, 0, -1))) # Asia vs. Africa
car::linearHypothesis(metareg.continent.lnCVR, rbind(c(0, 0, 0, 0, 1, -1))) # Oceania vs. Africa


##################################
# continent lnCVR (recategorized)
##################################

#to test if the continent influences the effect size
metareg.continent.2.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                  mods = ~ continent.2, 
                                  random = list(~ 1 | studyID,
                                                ~ 1 | comparisonID,
                                                ~ 1 | locationID,
                                                ~ 1 | obsID),
                                  method="REML", 
                                  test="t", 
                                  data=meta.final.lnCVR)

print(metareg.continent.2.lnCVR, digits=2)

###calculate marginal R2 with r2_ml
R2.continent.2 <- r2_ml(metareg.continent.2.lnCVR)
round(R2.continent.2*100,1) # in %


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.2.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                         mods = ~ continent.2 - 1, 
                                         random = list(~ 1 | studyID,
                                                       ~ 1 | comparisonID,
                                                       ~ 1 | locationID,
                                                       ~ 1 | obsID),
                                         method="REML", 
                                         test="t", 
                                         data=meta.final.lnCVR)

print(metareg.continent.2.lnCVR.no.int, digits=2)


tiff("figures/supplements/S02_Continent_lnCVR_Recat.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.2.lnCVR.no.int, mod = "continent.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.46, 0.077),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5,3.5),breaks = c(seq(-3.5,3.5,0.5))) +
  annotate(geom="text", x=5.35, y=-2.5, label=paste0("italic(R)^{2} == ", round(R2.continent.2[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=5.32, y=-1.8, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.continent.2.lnCVR, rbind(c(0,1,-1,0,0))) # North America vs. South America
car::linearHypothesis(metareg.continent.2.lnCVR, rbind(c(0,1,0,-1,0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.2.lnCVR, rbind(c(0,1,0,0,-1))) # North America vs. Others
car::linearHypothesis(metareg.continent.2.lnCVR, rbind(c(0,0,1,-1,0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.2.lnCVR, rbind(c(0,0,1,0,-1))) # South America vs. Others
car::linearHypothesis(metareg.continent.2.lnCVR, rbind(c(0,0,0,1,-1))) # Asia vs. Others


#################
# scale lnCVR
#################

#to test if the scale influences the effect size
metareg.scale.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                              mods = ~ scale, 
                              random = list(~ 1 | studyID,
                                            ~ 1 | comparisonID,
                                            ~ 1 | locationID,
                                            ~ 1 | obsID),
                              method="REML", 
                              test="t", 
                              data=meta.final.lnCVR)

print(metareg.scale.lnCVR, digits=2)

###calculate marginal R2 with r2_ml
R2.scale <- r2_ml(metareg.scale.lnCVR)
round(R2.scale*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.scale.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                     mods = ~ scale - 1, 
                                     random = list(~ 1 | studyID,
                                                   ~ 1 | comparisonID,
                                                   ~ 1 | locationID,
                                                   ~ 1 | obsID),
                                     method="REML", 
                                     test="t", 
                                     data=meta.final.lnCVR)

print(metareg.scale.lnCVR.no.int, digits=2)


tiff("figures/supplements/S03_Scale_lnCVR.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.scale.lnCVR.no.int, mod = "scale", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.43, 0.084),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5,3.5),breaks = c(seq(-3.5,3.5,0.5))) +
  annotate(geom="text", x=3.45, y=-2.5, label=paste0("italic(R)^{2} == ", round(R2.scale[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.43, y=-1.8, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.scale.lnCVR, rbind(c(0,1,-1))) # Local vs. Regional


#################
# diversity lnCVR
#################

#to test if the diversity index influences the effect size
metareg.diversity.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                  mods = ~ diversity, 
                                  random = list(~ 1 | studyID,
                                                ~ 1 | comparisonID,
                                                ~ 1 | locationID,
                                                ~ 1 | obsID),
                                  method="REML", 
                                  test="t", 
                                  data=meta.final.lnCVR)

print(metareg.diversity.lnCVR, digits=2)

###calculate marginal R2 with r2_ml
R2.diversity <- r2_ml(metareg.diversity.lnCVR)
round(R2.diversity*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.diversity.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                         mods = ~ diversity - 1, 
                                         random = list(~ 1 | studyID,
                                                       ~ 1 | comparisonID,
                                                       ~ 1 | locationID,
                                                       ~ 1 | obsID),
                                         method="REML", 
                                         test="t", 
                                         data=meta.final.lnCVR)

print(metareg.diversity.lnCVR.no.int, digits=2)


tiff("figures/supplements/S04_Diversity_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.diversity.lnCVR.no.int, mod = "diversity", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.36, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5,3.5),breaks = c(seq(-3.5,3.5,0.5))) +
  annotate(geom="text", x=4.40, y=-2.5, label=paste0("italic(R)^{2} == ", round(R2.diversity[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=4.37, y=-1.7, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.diversity.lnCVR, rbind(c(0, 1, -1, 0))) # Taxonomic diversity: others vs. Functional diversity
car::linearHypothesis(metareg.diversity.lnCVR, rbind(c(0, 1, 0, -1))) # Taxonomic diversity: others vs. Abundance
car::linearHypothesis(metareg.diversity.lnCVR, rbind(c(0, 0, 1, -1))) # Functional diversity vs. Abundance


#################
# Class lnCVR
#################

#to test if the Class influences the effect size
metareg.Class.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                  mods = ~ Class, 
                                  random = list(~ 1 | studyID,
                                                ~ 1 | comparisonID,
                                                ~ 1 | locationID,
                                                ~ 1 | obsID),
                                  method="REML", 
                                  test="t", 
                                  data=meta.final.lnCVR)

print(metareg.Class.lnCVR, digits=2)

###calculate marginal R2 with r2_ml
R2.Class <- r2_ml(metareg.Class.lnCVR)
round(R2.Class*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                     mods = ~ Class - 1, 
                                     random = list(~ 1 | studyID,
                                                   ~ 1 | comparisonID,
                                                   ~ 1 | locationID,
                                                   ~ 1 | obsID),
                                     method="REML", 
                                     test="t", 
                                     data=meta.final.lnCVR)

print(metareg.Class.lnCVR.no.int, digits=2)


tiff("figures/supplements/S05_Class_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnCVR.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.43, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5,3.5),breaks = c(seq(-3.5,3.5,0.5))) +
  annotate(geom="text", x=5.40, y=-2.5, label=paste0("italic(R)^{2} == ", round(R2.Class[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=5.36, y=-1.8, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnCVR, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnCVR, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnCVR, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnCVR, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnCVR, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnCVR, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


#################
# Order
#################

# To test if the Order influences the effect size
metareg.Order.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                             mods = ~ Order.2, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method = "REML", 
                             test = "t", 
                             data = meta.final.lnCVR)

print(metareg.Order.lnCVR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnCVR <- r2_ml(metareg.Order.lnCVR)
round(R2.Order.lnCVR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                    mods = ~ Order.2 - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method = "REML", 
                                    test = "t", 
                                    data = meta.final.lnCVR)

print(metareg.Order.lnCVR.no.int, digits=3)


tiff("figures/supplements/S06_Order_Insecta_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnCVR.no.int, mod = "Order.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5, 3.5), breaks = c(seq(-3.5, 3.5, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 12.7, y = -2.7, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnCVR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 12.62, y = -1.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnCVR, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnCVR, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnCVR, rbind(c(0, 0, 0, 1, -1))) #  vs. 


#################
# Order (EPT)
#################

# To test if the Order influences the effect size
metareg.Order.EPT.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                 mods = ~ Order.3, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.lnCVR)

print(metareg.Order.EPT.lnCVR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.EPT.lnCVR <- r2_ml(metareg.Order.EPT.lnCVR)
round(R2.Order.EPT.lnCVR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.EPT.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                        mods = ~ Order.3 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.lnCVR)

print(metareg.Order.EPT.lnCVR.no.int, digits=3)


tiff("figures/supplements/S06_Order_Insecta_EPT_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.EPT.lnCVR.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5, 3.5), breaks = c(seq(-3.5, 3.5, 0.5))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 9.60, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.EPT.lnCVR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 9.52, y = -1.6, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 1, -1, 0, 0, 0, 0, 0, 0))) # Diptera vs. EPT
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 1, 0, 0, -1, 0, 0, 0, 0))) # Diptera vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 1, 0, 0, 0, -1, 0, 0, 0))) # Diptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 1, 0, 0, 0, 0, -1, 0, 0))) # Diptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 1, 0, 0, 0, 0, 0, 0, -1))) # Diptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 1, 0, -1, 0, 0, 0, 0))) # EPT vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 1, 0, 0, -1, 0, 0, 0))) # EPT vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 1, 0, 0, 0, -1, 0, 0))) # EPT vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 1, 0, 0, 0, 0, 0, -1))) # EPT vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 0, 0, 1, -1, 0, 0, 0))) # Hymenoptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 0, 0, 1, 0, -1, 0, 0))) # Hymenoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 0, 0, 0, 0, 0, 0, -1))) # Hymenoptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 0, 0, 0, 1, -1, 0, 0))) # Lepidoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 0, 0, 0, 1, 0, 0, -1))) # Lepidoptera vs. Non - Insect Orders
car::linearHypothesis(metareg.Order.EPT.lnCVR, rbind(c(0, 0, 0, 0, 0, 0, 1, 0, -1))) # Odonata vs. Non - Insect Orders



#################
# Family
#################

# To test if the Family influences the effect size
metareg.Family.lnCVR <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                              mods = ~ Family.2, 
                              random = list(~ 1 | studyID,
                                            ~ 1 | comparisonID,
                                            ~ 1 | locationID,
                                            ~ 1 | obsID),
                              method = "REML", 
                              test = "t", 
                              data = meta.final.lnCVR)

print(metareg.Family.lnCVR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnCVR <- r2_ml(metareg.Family.lnCVR)
round(R2.Family.lnCVR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnCVR.no.int <- rma.mv(lnCVR, VCV_ESVar.lnCVR, 
                                     mods = ~ Family.2 - 1, 
                                     random = list(~ 1 | studyID,
                                                   ~ 1 | comparisonID,
                                                   ~ 1 | locationID,
                                                   ~ 1 | obsID),
                                     method = "REML", 
                                     test = "t", 
                                     data = meta.final.lnCVR)

print(metareg.Family.lnCVR.no.int, digits=3)


tiff("figures/supplements/S07_Family_lnCVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnCVR.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnCVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-3.5, 3.5), breaks = c(seq(-3.5, 3.5, 0.5))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -2.5, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnCVR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -1.7, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 1, -1, 0, 0, 0, 0))) # Calliphoridae vs. Carabidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 1, 0, -1, 0, 0, 0))) # Calliphoridae vs. Culicidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 1, 0, 0, -1, 0, 0))) # Calliphoridae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 1, 0, 0, 0, -1, 0))) # Calliphoridae vs. Formicidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 1, 0, 0, 0, 0, -1))) # Calliphoridae vs. Other Families

car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 1, -1, 0, 0, 0))) # Carabidae vs. Culicidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 1, 0, -1, 0, 0))) # Carabidae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 1, 0, 0, -1, 0))) # Carabidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 1, 0, 0, 0, -1))) # Carabidae vs. Other Families

car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 0, 1, -1, 0, 0))) # Culicidae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 0, 1, 0, -1, 0))) # Culicidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 0, 1, 0, 0, -1))) # Culicidae vs. Other Families

car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 0, 0, 1, -1, 0))) # Drosophilidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 0, 0, 1, 0, -1))) # Drosophilidae vs. Other Families
car::linearHypothesis(metareg.Family.lnCVR, rbind(c(0, 0, 0, 0, 0, 1, -1))) # Formicidae vs. Other Families


################################################################################




################################################################################
# Sampling variance-covariance matrix lnVR
################################################################################

# subset
meta.final.lnVR <- meta.final.SA

# there is a clear outliers that we are going to exclude from the lnVR 
# analyses (lnVR.vi: 1977.39), which is the same as for the lnRR. 
meta.final.lnVR <- meta.final.lnVR[meta.final.lnVR$lnVR<5 & 
                                   meta.final.lnVR$lnVR>-5 & 
                                 !(is.na(meta.final.lnVR$lnVR.vi)),]

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.lnVR <- matrix(0, nrow = nrow(meta.final.lnVR), 
                         ncol = nrow(meta.final.lnVR))

# names rows and columns for each obsID
rownames(VCV_ESVar.lnVR) <- meta.final.lnVR[, "obsID"]
colnames(VCV_ESVar.lnVR) <- meta.final.lnVR[, "obsID"]

# finds effect sizes that come from the same study
shared_coord <- which(meta.final.lnVR[, "studyID"] %in% 
                        meta.final.lnVR[duplicated(meta.final.lnVR[,"studyID"]), 
                                      "studyID"] == TRUE)

combinations <- do.call("rbind", tapply(shared_coord, 
                                        meta.final.lnVR[shared_coord,"studyID"], 
                                        function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations)[1]) {
  p1 <- combinations[i, 1]
  p2 <- combinations[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.lnVR[p1, "lnVR.vi"]) * sqrt(meta.final.lnVR[p2, "lnVR.vi"])
  VCV_ESVar.lnVR[p1, p2] <- p1_p2_cov
  VCV_ESVar.lnVR[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.lnVR) <- meta.final.lnVR[, "lnVR.vi"]

# In case you want to visually double check the matrix outside of R
# write.csv(VCV_ESVar.lnVR, 'VCV_ESVar.lnVR.csv')


################################################################################
# lnVR
################################################################################

#Data funnel plot
par(mfrow = c(1, 2))
funnel(meta.final.lnVR$lnVR, meta.final.lnVR$lnVR.vi, yaxis="sei",
       xlab = "Effect size (lnVR)", digits = 2, las = 1)
funnel(meta.final.lnVR$lnVR, meta.final.lnVR$lnVR.vi, yaxis="seinv",
       xlab = "Effect size (lnVR)",  digits = 2, las = 1)


# MAIN MODEL = multilevel meta-analysis
model.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                     random = list(~ 1 | studyID,
                                   ~ 1 | comparisonID,
                                   ~ 1 | locationID,
                                   ~ 1 | obsID), 
                     method="REML", 
                     test="t", 
                     data=meta.final.lnVR)

print(model.lnVR, digits=2)
predict(model.lnVR, digits=2)

#model funnel plot
par(mfrow = c(1, 1))
funnel(model.lnVR)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model.lnVR <- i2_ml(model.lnVR)
round(I2.model.lnVR,1)


#########################
# method (recategorized) lnVR
#########################

#to test if the method influences the effect size
metareg.method.recat.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                              mods = ~ method.recat, 
                              random = list(~ 1 | studyID,
                                            ~ 1 | comparisonID,
                                            ~ 1 | locationID,
                                            ~ 1 | obsID),
                              method="REML", 
                              test="t", 
                              data=meta.final.lnVR)

print(metareg.method.recat.lnVR, digits=2)

###calculate marginal R2 with r2_ml
R2.method <- r2_ml(metareg.method.recat.lnVR)
round(R2.method*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.method.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                     mods = ~ method.recat - 1, 
                                     random = list(~ 1 | studyID,
                                                   ~ 1 | comparisonID,
                                                   ~ 1 | locationID,
                                                   ~ 1 | obsID),
                                     method="REML", 
                                     test="t", 
                                     data=meta.final.lnVR)

print(metareg.method.lnVR.no.int, digits=2)


tiff("figures/supplements/S01_Methods_lnVR.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.method.lnVR.no.int, mod = "method.recat", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.39, 0.085),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5,5),breaks = c(seq(-5,5,1))) +
  annotate(geom="text", x=3.43, y=-4, label=paste0("italic(R)^{2} == ", round(R2.method[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.41, y=-2.9, label="%",color="black", parse = FALSE, size = 5)

dev.off()

###compare the remaining factor levels
car::linearHypothesis(metareg.method.recat.lnVR, rbind(c(0, 1, -1))) # City Comparison vs. Urban-Rural


#################
# continent lnVR
#################

#to test if the continent influences the effect size
metareg.continent.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                 mods = ~ continent, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.lnVR)

print(metareg.continent.lnVR, digits=2)

###calculate marginal R2 with r2_ml
R2.continent <- r2_ml(metareg.continent.lnVR)
round(R2.continent*100,1) # in %


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                        mods = ~ continent - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.lnVR)

print(metareg.continent.lnVR.no.int, digits=2)


tiff("figures/supplements/S02_Continent_lnVR.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.lnVR.no.int, mod = "continent", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.46, 0.077),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5,5),breaks = c(seq(-5,5,1))) +
  annotate(geom="text", x=6.35, y=-4, label=paste0("italic(R)^{2} == ", round(R2.continent[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=6.32, y=-2.9, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 1, -1, 0, 0, 0))) # North America vs. South America
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 1, 0, -1, 0, 0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 1, 0, 0, -1, 0))) # North America vs. Oceania
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 1, 0, 0, 0, -1))) # North America vs. Africa
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 0, 1, -1, 0, 0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 0, 1, 0, -1, 0))) # South America vs. Oceania
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 0, 1, 0, 0, -1))) # South America vs. Africa
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 0, 0, 1, -1, 0))) # Asia vs. Oceania
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 0, 0, 1, 0, -1))) # Asia vs. Africa
car::linearHypothesis(metareg.continent.lnVR, rbind(c(0, 0, 0, 0, 1, -1))) # Oceania vs. Africa


#################################
# continent lnVR (recategorized)
#################################

#to test if the continent influences the effect size
metareg.continent.2.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                 mods = ~ continent.2, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.lnVR)

print(metareg.continent.2.lnVR, digits=2)

###calculate marginal R2 with r2_ml
R2.continent.2 <- r2_ml(metareg.continent.2.lnVR)
round(R2.continent.2*100,1) # in %


# Plotting the results
# removing the intercept for easy plotting
metareg.continent.2.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                        mods = ~ continent.2 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.lnVR)

print(metareg.continent.2.lnVR.no.int, digits=2)


tiff("figures/supplements/S02_Continent_lnVR_Recat.tiff",
     height=13.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.continent.2.lnVR.no.int, mod = "continent.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.46, 0.077),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5,5),breaks = c(seq(-5,5,1))) +
  annotate(geom="text", x=5.35, y=-4, label=paste0("italic(R)^{2} == ", round(R2.continent.2[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=5.32, y=-2.9, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.continent.2.lnVR, rbind(c(0,1,-1,0,0))) # North America vs. South America
car::linearHypothesis(metareg.continent.2.lnVR, rbind(c(0,1,0,-1,0))) # North America vs. Asia
car::linearHypothesis(metareg.continent.2.lnVR, rbind(c(0,1,0,0,-1))) # North America vs. Others
car::linearHypothesis(metareg.continent.2.lnVR, rbind(c(0,0,1,-1,0))) # South America vs. Asia
car::linearHypothesis(metareg.continent.2.lnVR, rbind(c(0,0,1,0,-1))) # South America vs. Others
car::linearHypothesis(metareg.continent.2.lnVR, rbind(c(0,0,0,1,-1))) # Asia vs. Others



#################
# scale lnVR
#################

#to test if the scale influences the effect size
metareg.scale.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                             mods = ~ scale, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method="REML", 
                             test="t", 
                             data=meta.final.lnVR)

print(metareg.scale.lnVR, digits=2)

###calculate marginal R2 with r2_ml
R2.scale <- r2_ml(metareg.scale.lnVR)
round(R2.scale*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.scale.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                    mods = ~ scale - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method="REML", 
                                    test="t", 
                                    data=meta.final.lnVR)

print(metareg.scale.lnVR.no.int, digits=2)


tiff("figures/supplements/S03_Scale_lnVR.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.scale.lnVR.no.int, mod = "scale", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.43, 0.084),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5,5),breaks = c(seq(-5,5,1))) +
  annotate(geom="text", x=3.45, y=-4, label=paste0("italic(R)^{2} == ", round(R2.scale[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.43, y=-3, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.scale.lnVR, rbind(c(0,1,-1))) # Local vs. Regional


#################
# diversity lnVR
#################

#to test if the diversity index influences the effect size
metareg.diversity.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                 mods = ~ diversity, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method="REML", 
                                 test="t", 
                                 data=meta.final.lnVR)

print(metareg.diversity.lnVR, digits=2)

###calculate marginal R2 with r2_ml
R2.diversity <- r2_ml(metareg.diversity.lnVR)
round(R2.diversity*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.diversity.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                        mods = ~ diversity - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method="REML", 
                                        test="t", 
                                        data=meta.final.lnVR)

print(metareg.diversity.lnVR.no.int, digits=2)


tiff("figures/supplements/S04_Diversity_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.diversity.lnVR.no.int, mod = "diversity", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.36, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5,5),breaks = c(seq(-5,5,1))) +
  annotate(geom="text", x=4.44, y=-4, label=paste0("italic(R)^{2} == ", round(R2.diversity[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=4.40, y=-2.9, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.diversity.lnVR, rbind(c(0, 1, -1, 0))) # Taxonomic diversity: others vs. Functional diversity
car::linearHypothesis(metareg.diversity.lnVR, rbind(c(0, 1, 0, -1))) # Taxonomic diversity: others vs. Abundance
car::linearHypothesis(metareg.diversity.lnVR, rbind(c(0, 0, 1, -1))) # Functional diversity vs. Abundance


#################
# Class lnVR
#################

#to test if the Class influences the effect size
metareg.Class.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                             mods = ~ Class, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method="REML", 
                             test="t", 
                             data=meta.final.lnVR)

print(metareg.Class.lnVR, digits=2)

###calculate marginal R2 with r2_ml
R2.Class <- r2_ml(metareg.Class.lnVR)
round(R2.Class*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.Class.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                    mods = ~ Class - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method="REML", 
                                    test="t", 
                                    data=meta.final.lnVR)

print(metareg.Class.lnVR.no.int, digits=2)


tiff("figures/supplements/S05_Class_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Class.lnVR.no.int, mod = "Class", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.43, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5,5),breaks = c(seq(-5,5,1))) +
  annotate(geom="text", x=5.40, y=-4, label=paste0("italic(R)^{2} == ", round(R2.Class[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=5.36, y=-3, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.Class.lnVR, rbind(c(0, 1, -1, 0, 0))) # Arachnida vs Crustacea
car::linearHypothesis(metareg.Class.lnVR, rbind(c(0, 1, 0, -1, 0))) # Arachnida vs. Myriapoda
car::linearHypothesis(metareg.Class.lnVR, rbind(c(0, 1, 0, 0, -1))) # Arachnida vs. Entognatha
car::linearHypothesis(metareg.Class.lnVR, rbind(c(0, 0, 1, -1, 0))) # Crustacea vs. Myriapoda
car::linearHypothesis(metareg.Class.lnVR, rbind(c(0, 0, 1, 0, -1))) # Crustacea vs. Entognatha
car::linearHypothesis(metareg.Class.lnVR, rbind(c(0, 0, 0, 1, -1))) # Myriapoda vs. Entognatha


#################
# Order
#################

# To test if the Order influences the effect size
metareg.Order.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                             mods = ~ Order.2, 
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method = "REML", 
                             test = "t", 
                             data = meta.final.lnVR)

print(metareg.Order.lnVR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.lnVR <- r2_ml(metareg.Order.lnVR)
round(R2.Order.lnVR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                    mods = ~ Order.2 - 1, 
                                    random = list(~ 1 | studyID,
                                                  ~ 1 | comparisonID,
                                                  ~ 1 | locationID,
                                                  ~ 1 | obsID),
                                    method = "REML", 
                                    test = "t", 
                                    data = meta.final.lnVR)

print(metareg.Order.lnVR.no.int, digits=3)


tiff("figures/supplements/S06_Order_Insecta_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.lnVR.no.int, mod = "Order.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5, 5), breaks = c(seq(-5, 5, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 12.7, y = -4, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.lnVR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 12.62, y = -2.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.lnVR, rbind(c(0, 1, -1, 0, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR, rbind(c(0, 1, 0, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR, rbind(c(0, 1, 0, 0, -1))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR, rbind(c(0, 0, 1, -1, 0))) #  vs. 
car::linearHypothesis(metareg.Order.lnVR, rbind(c(0, 0, 1, 0, -1))) #  vs.
car::linearHypothesis(metareg.Order.lnVR, rbind(c(0, 0, 0, 1, -1))) #  vs. 


#################
# Order (EPT)
#################

# To test if the Order influences the effect size
metareg.Order.EPT.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                 mods = ~ Order.3, 
                                 random = list(~ 1 | studyID,
                                               ~ 1 | comparisonID,
                                               ~ 1 | locationID,
                                               ~ 1 | obsID),
                                 method = "REML", 
                                 test = "t", 
                                 data = meta.final.lnVR)

print(metareg.Order.EPT.lnVR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Order.EPT.lnVR <- r2_ml(metareg.Order.EPT.lnVR)
round(R2.Order.EPT.lnVR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Order.EPT.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                        mods = ~ Order.3 - 1, 
                                        random = list(~ 1 | studyID,
                                                      ~ 1 | comparisonID,
                                                      ~ 1 | locationID,
                                                      ~ 1 | obsID),
                                        method = "REML", 
                                        test = "t", 
                                        data = meta.final.lnVR)

print(metareg.Order.EPT.lnVR.no.int, digits=3)


tiff("figures/supplements/S06_Order_Insecta_EPT_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Order.EPT.lnVR.no.int, mod = "Order.3", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5, 5), breaks = c(seq(-5, 5, 1))) +
  scale_x_discrete(expand = c(0.12,0.12)) +
  annotate(geom = "text", x = 9.60, y = -4, 
           label = paste0("italic(R)^{2} == ", round(R2.Order.EPT.lnVR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 9.52, y = -2.8, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 1, -1, 0, 0, 0, 0, 0, 0))) # Diptera vs. EPT
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 1, 0, 0, -1, 0, 0, 0, 0))) # Diptera vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 1, 0, 0, 0, -1, 0, 0, 0))) # Diptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 1, 0, 0, 0, 0, -1, 0, 0))) # Diptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 1, 0, 0, 0, 0, 0, 0, -1))) # Diptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 1, 0, -1, 0, 0, 0, 0))) # EPT vs. Hymenoptera
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 1, 0, 0, -1, 0, 0, 0))) # EPT vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 1, 0, 0, 0, -1, 0, 0))) # EPT vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 1, 0, 0, 0, 0, 0, -1))) # EPT vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 0, 0, 1, -1, 0, 0, 0))) # Hymenoptera vs. Lepidoptera
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 0, 0, 1, 0, -1, 0, 0))) # Hymenoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 0, 0, 0, 0, 0, 0, -1))) # Hymenoptera vs. Non - Insect Orders

car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 0, 0, 0, 1, -1, 0, 0))) # Lepidoptera vs. Odonata
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 0, 0, 0, 1, 0, 0, -1))) # Lepidoptera vs. Non - Insect Orders
car::linearHypothesis(metareg.Order.EPT.lnVR, rbind(c(0, 0, 0, 0, 0, 0, 1, 0, -1))) # Odonata vs. Non - Insect Orders


#################
# Family
#################

# To test if the Family influences the effect size
metareg.Family.lnVR <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                              mods = ~ Family.2, 
                              random = list(~ 1 | studyID,
                                            ~ 1 | comparisonID,
                                            ~ 1 | locationID,
                                            ~ 1 | obsID),
                              method = "REML", 
                              test = "t", 
                              data = meta.final.lnVR)

print(metareg.Family.lnVR, digits=2)

# Calculate marginal R2 with r2_ml
R2.Family.lnVR <- r2_ml(metareg.Family.lnVR)
round(R2.Family.lnVR*100, 1)

# Plotting the results
# removing the intercept for easy plotting
metareg.Family.lnVR.no.int <- rma.mv(lnVR, VCV_ESVar.lnVR, 
                                     mods = ~ Family.2 - 1, 
                                     random = list(~ 1 | studyID,
                                                   ~ 1 | comparisonID,
                                                   ~ 1 | locationID,
                                                   ~ 1 | obsID),
                                     method = "REML", 
                                     test = "t", 
                                     data = meta.final.lnVR)

print(metareg.Family.lnVR.no.int, digits=3)


tiff("figures/supplements/S07_Family_lnVR.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.Family.lnVR.no.int, mod = "Family.2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final.lnVR,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position = c(0.43, 0.097),
        legend.justification = c(0, 1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction = "horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-5, 5), breaks = c(seq(-5, 5, 1))) +
  scale_x_discrete(expand = c(0.1,0.1)) +
  annotate(geom = "text", x = 7.40, y = -4, 
           label = paste0("italic(R)^{2} == ", round(R2.Family.lnVR[1]*100, 1)),
           color = "black", parse = TRUE, size = 5) +
  annotate(geom = "text", x = 7.35, y = -3, label = "%",color = "black", 
           parse = FALSE, size = 5)

dev.off()


# Compare the remaining factor levels
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 1, -1, 0, 0, 0, 0))) # Calliphoridae vs. Carabidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 1, 0, -1, 0, 0, 0))) # Calliphoridae vs. Culicidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 1, 0, 0, -1, 0, 0))) # Calliphoridae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 1, 0, 0, 0, -1, 0))) # Calliphoridae vs. Formicidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 1, 0, 0, 0, 0, -1))) # Calliphoridae vs. Other Families

car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 1, -1, 0, 0, 0))) # Carabidae vs. Culicidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 1, 0, -1, 0, 0))) # Carabidae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 1, 0, 0, -1, 0))) # Carabidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 1, 0, 0, 0, -1))) # Carabidae vs. Other Families

car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 0, 1, -1, 0, 0))) # Culicidae vs. Drosophilidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 0, 1, 0, -1, 0))) # Culicidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 0, 1, 0, 0, -1))) # Culicidae vs. Other Families

car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 0, 0, 1, -1, 0))) # Drosophilidae vs. Formicidae
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 0, 0, 1, 0, -1))) # Drosophilidae vs. Other Families
car::linearHypothesis(metareg.Family.lnVR, rbind(c(0, 0, 0, 0, 0, 1, -1))) # Formicidae vs. Other Families


################################################################################


# citing packages used
cite_packages()
citation("report")

# # exporting list of effect sizes that stand out from the plots for having rather large and positive r
# write.csv(meta.final[meta.final$r>0.3,],"potential_outlier_effect_sizes-to_check.csv",row.names=F)

