################################################################################
# Authors: 
# Alfredo Sanchez-Tojar (with support from Endika Blanco)

# Script first created in Nov 2018

################################################################################
# Description of script and Instructions
################################################################################

# This script is for a meta-analysis on the effect of urbanization on 
# biodiversity.

################################################################################
# Packages needed
################################################################################

# Clear memory
rm(list=ls())

###install.packages("pacman")
# devtools::install_github("itchyshin/orchard_plot", subdir = "orchaRd", 
#                          force = TRUE, build_vignettes = TRUE)
# devtools::install_github("daniel1noble/orchaRd", force = TRUE)
pacman::p_load(devtools, tidyverse, metafor, patchwork, R.rsp, orchaRd, emmeans,
               ape, phytools, report, car) #dplyr, ggplot2


################################################################################
# Importing the data (from script 'data_preparation_urban.R')
################################################################################

meta.final <- read.table("meta_final_reduced.csv", header=T, sep=",")

# Modifying variables type
meta.final$studyID <- as.factor(meta.final$studyID)
meta.final$es_type <- as.factor(meta.final$es_type)


# Creating a new variable to categorize effects as biserial correlations, 
# Pearson's correlation coefficients or effects from inferential statistics
meta.final$es_type_2 <- as.factor(ifelse(meta.final$es_type %in% 
                                           c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                         "biserial_correlation",
                                         ifelse(meta.final$es_type %in% 
                                                  c("pearsons", "spearmans"),
                                                "correlation_coefficient",
                                                "inferential_statistic")))

# METHOD
# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final <- as.data.frame(meta.final %>% 
                              mutate(method= 
                                       factor(method, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# Generating a new method that accounts for the fact that for some of the data
# originally reported as gradients we later on had to extract only the extremes
# (i.e. most urbanized vs least urbanized), normally from figures, to be able to
# calculate biserial correlations. In these cases, these estimates are going to
# now be categorized as "Urban-Rural" as the original continuous nature of the
# measurement was then changed
meta.final$method.recat <- ifelse(as.character(meta.final$method) %in% 
                                    c("Urban Gradient") &
                                    as.character(meta.final$es_type) %in% 
                                    c("tgfu", "tgri", "tgsh", "tgsi", "tgab"),
                                  "Urban-Rural", 
                                  as.character(meta.final$method))

# We reorder the levels so that the reference level (intercept) is Urban Gradient
meta.final <- as.data.frame(meta.final %>% 
                              mutate(method.recat= 
                                       factor(method.recat, 
                                              levels=c("Urban Gradient",
                                                       "City Comparison",
                                                       "Urban-Rural",
                                                       "Temporal Urban Gradient"))))


# CONTINENT
# We reorder the levels so that the reference level (intercept) is Europe
meta.final <- as.data.frame(meta.final %>%
                              mutate(continent=
                                       factor(continent, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Oceania",
                                                       "Africa"))))


# since sample sizes were to small for the original idea, we have recoded the 
# factor so that the sample sizes are decent and still biologically meaningful
meta.final$continent.2 <- as.factor(ifelse(meta.final$continent=="Africa" | 
                                             meta.final$continent=="Oceania", 
                                           "Others", as.character(meta.final$continent)))

table(meta.final$continent.2)

# We reorder the levels so that the reference level (intercept) is Europe
meta.final <- as.data.frame(meta.final %>%
                              mutate(continent.2=
                                       factor(continent.2, 
                                              levels=c("Europe",
                                                       "North America",
                                                       "South America",
                                                       "Asia",
                                                       "Others"))))


# SCALE
# We reorder the levels so that the reference level (intercept) is City. The 
# order of goes from smaller to larger scale
meta.final <- as.data.frame(meta.final %>% 
                              mutate(scale= 
                                       factor(scale, 
                                              levels=c("City",
                                                       "Local",
                                                       "Regional"))))


# DIVERSITY
# We reorder the levels so that the reference level (intercept) is Richness, but
# first we recode the level names to make them more informative and standardized
meta.final$diversity <- dplyr::recode(meta.final$diversity, 
                                      "Other taxonomic diversity measure"= 
                                        "Taxonomic diversity: others", #to keep consistency with the other analyses, also shorter names are better for the plots and tables
                                      "Richness"="Taxonomic diversity: richness")

meta.final <- as.data.frame(meta.final %>% 
                              mutate(diversity= 
                                       factor(diversity, 
                                              levels=c("Taxonomic diversity: richness",
                                                       "Taxonomic diversity: others",
                                                       "Functional diversity",
                                                       "Abundance"))))


# CLASS
# Customizing the order of the factor levels. We reorder the levels so that the 
# reference level (intercept) is Insecta
meta.final <- as.data.frame(meta.final %>% 
                              mutate(Class = factor(Class, 
                                                    levels=c("Insecta",
                                                             "Arachnida",
                                                             "Crustacea",
                                                             "Myriapoda",
                                                             "Entognatha"))))


# ORDER
table(meta.final$Order)

#Subset for Insect Orders (Orders of the rest of Classes too small)
meta.final$Order.2 <- ifelse(as.character(meta.final$Order) %in% 
                               c("Araneae", "Decapoda", "Diplostraca",
                                 "Harpacticoida", "Isopoda", "Ixodida",
                                 "Opiliones", "Spirostreptida",
                                 "Diplostraca", "Trombidiformes"),
                             "Non-Insect Orders", 
                             as.character(meta.final$Order))

meta.final$Order.2 <- factor(meta.final$Order.2)
table(meta.final$Order.2)


#Subset for Insect Orders, after unifying EPT orders into EPT.
meta.final$Order.3 <- ifelse(as.character(meta.final$Order.2) %in% 
                               c("Ephemeroptera","Plecoptera","Trichoptera"),
                             "EPT", 
                             as.character(meta.final$Order.2))

# We reorder the levels
meta.final <- as.data.frame(meta.final %>%
                              mutate(Order.3=
                                       factor(Order.3, 
                                              levels=c("Coleoptera",
                                                       "Diptera",
                                                       "EPT",
                                                       "Hemiptera",
                                                       "Hymenoptera",
                                                       "Lepidoptera",
                                                       "Odonata",
                                                       "Orthoptera",
                                                       "Non-Insect Orders"))))

meta.final$Order.3 <- factor(meta.final$Order.3)
table(meta.final$Order.3)


# FAMILY
table(meta.final$Family)

#Joining "Apidae" to "Apoidea" superfamily
meta.final$Family.2 <- factor(meta.final$Family)
meta.final$Family.2 <- ifelse(as.character(meta.final$Family.2) %in% 
                                c("Apidae"), "Apoidea", 
                              as.character(meta.final$Family.2))

#Subset for Insect Families with enough data (10<)
meta.final$Family.2 <- ifelse(as.character(meta.final$Family.2) %in% 
                                c("Anisoptera", "bat-flies", "Chironomidae",
                                  "Chloropidae", "Coccinellidae", "Cynipidae",
                                  "Geometridae", "Hydrachnidia", "Psychodidae",
                                  "Sarcophagidae", "Scarabaeidae", "Silphidae",
                                  "Sphecidae", "Staphylinidae", "Syrphidae",
                                  "Tachinidae", "Tenebrionidae", "Thomisidae",
                                  "Vespidae", "Zygoptera"),
                              "Other Families", 
                              as.character(meta.final$Family.2))

meta.final$Family.2 <- factor(meta.final$Family.2)
table(meta.final$Family.2)


################################################################################
# Sampling variance-covariance matrix
################################################################################

# We specified sampling variance as variance-covariance matrix, with the 
# sampling variance for each effect size on the diagonal, and the covariance 
# between these measures as off-diagonal elements. The conservative model 
# assumed a 0.5 correlation between the effect size sample variances with the 
# same studyID. For a similar approach, see O'Dea et al., 2019 
# (https://doi.org/10.1111/faf.12394)or Kim et al. 2022 
# (https://doi.org/10.1111/1365-2656.13554), from which this code is taken from.

### Creating a var-covar matrix assuming a 0.5 correlation between effect sizes 
# from the same studyID covariance = (0.5 * sqrt(vi.1) * sqrt(vi.2))

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar <- matrix(0, nrow = nrow(meta.final), ncol = nrow(meta.final))

# names rows and columns for each obsID
rownames(VCV_ESVar) <- meta.final[, "obsID"]
colnames(VCV_ESVar) <- meta.final[, "obsID"]

# finds effect sizes that come from the same study
shared_coord <- which(meta.final[, "studyID"] %in% 
                        meta.final[duplicated(meta.final[, "studyID"]), 
                                   "studyID"] == TRUE)

combinations <- do.call("rbind", tapply(shared_coord, 
                                        meta.final[shared_coord, "studyID"], 
                                        function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations)[1]) {
  p1 <- combinations[i, 1]
  p2 <- combinations[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final[p1, "Vr"]) * sqrt(meta.final[p2, "Vr"])
  VCV_ESVar[p1, p2] <- p1_p2_cov
  VCV_ESVar[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar) <- meta.final[, "Vr"]

# In case you want to visually double check the matrix outside of R
#write.csv(VCV_ESVar, 'VCV_ESVar.csv')


############################################################################
# PUBLICATION BIAS
############################################################################

####################################
# Small-study bias
####################################

# We follow the general guidelines of Nakagawa et al. 2022, MEE (but be aware of 
# the published corrigendum!). Instead of calculating effective sample size as 
# (Nr + Nu)/(Nr * Nu), which we could only do for part of the dataset (e.g. not 
# for the correlations), we will simply use the the inverse of the sample size
# and its sqrt. As a sensitivity test, we will use n/4 rather than simply n, but 
# results are expected to be very similar (not the slope though!).

meta.final$inv_esz <-  1/meta.final$Nt
meta.final$inv_esz.4 <-  1/(meta.final$Nt/4)
meta.final$sqrt_inv_esz  <-  with(meta.final, sqrt(inv_esz))
meta.final$sqrt_inv_esz.4 <-  with(meta.final, sqrt(inv_esz.4))


# publication bias: small-study bias
publication_bias <- rma.mv(r, VCV_ESVar,
                           mods = ~ 1 + sqrt_inv_esz,
                           random = list(~ 1 | studyID,
                                         ~ 1 | comparisonID,
                                         ~ 1 | locationID,
                                         ~ 1 | obsID),
                           method = "REML",
                           test = "t", 
                           data = meta.final)


# if the intercept B0 is statistically significant, Stanley & Doucouliagos 
# (2012, 2014) have shown that β_0 provides an adjusted estimate that is 
# downwardly biased. 
print(publication_bias, digits=2)

# Calculate marginal R2 with r2_ml
R2.publication_bias <- r2_ml(publication_bias)
round(R2.publication_bias*100, 1)


# Figure small-study bias
###########################

tiff("figures/Small-study_bias.tiff",
     height=10.5, width=10.5,
     units='cm', compression="lzw", res=800)

bubble_plot(publication_bias, mod = "sqrt_inv_esz", 
            xlab = "Square root of inverse of sample size", ylab = "Effect size (r)",
            group = "studyID",
            data = meta.final, legend.pos = "none") +
  theme(axis.text.x = element_text(size = 10, colour = "black"),
        axis.text.y = element_text(size = 10, colour = "black"),
        axis.title.x = element_text(size = 10, colour = "black"),
        plot.title = element_text(size = 10, colour = "black"))

dev.off()


# Sensitivity analysis of small-study bias using n/4 instead of n
publication_bias.4 <- rma.mv(r, VCV_ESVar,
                             mods = ~ 1 + sqrt_inv_esz.4,
                             random = list(~ 1 | studyID,
                                           ~ 1 | comparisonID,
                                           ~ 1 | locationID,
                                           ~ 1 | obsID),
                             method = "REML",
                             test = "t", 
                             data = meta.final)

print(publication_bias.4, digits=2) #very similar results, same conclusions.

# Calculate marginal R2 with r2_ml
R2.publication_bias.4 <- r2_ml(publication_bias.4)
round(R2.publication_bias.4*100, 1)


####################################
# Time-lag bias or decline effects
####################################

# Mean-centring year before including it in the model
meta.final$year.c <- as.vector(scale(meta.final$year, scale = F))

time_lag_bias <- rma.mv(r, VCV_ESVar,
                        mods = ~ 1 + year.c,
                        random = list(~ 1 | studyID,
                                      ~ 1 | comparisonID,
                                      ~ 1 | locationID,
                                      ~ 1 | obsID),
                        method = "REML",
                        test = "t", 
                        data = meta.final)

print(time_lag_bias, digits=2)

# Calculate marginal R2 with r2_ml
R2.time_lag_bias <- r2_ml(time_lag_bias)
round(R2.time_lag_bias*100, 1)


# Figure time-lag bias
###########################
timelag.plotting <- predict(time_lag_bias)

newdat <- data.frame(year = meta.final$year,
                     fit = timelag.plotting$pred,
                     upper = timelag.plotting$ci.ub,
                     lower = timelag.plotting$ci.lb,
                     stringsAsFactors = FALSE)

newdat <- newdat[order(newdat$year),]

tiff("figures/supplements/S10_Time-lag_bias.tiff",
     height=10.5, width=10.5,
     units='cm', compression="lzw", res=800)

xaxis <- meta.final$year
yaxis <- meta.final$r
cex.study <- meta.final$Nt/250

op <- par(mar = c(4.5, 4.5, 1, 1)) #bottom, left, top, and right. 

plot(xaxis, yaxis,
     type = "n",
     ylab = "",
     xlab = "",
     xaxt = "n",
     yaxt = "n",
     ylim = c(-1.5, 1.5),
     xlim = c(1996, 2022))

abline(a = 0, b = 0, lwd = 1, lty = 1)

axis(1, at = seq(1996, 2022, 6), cex.axis = 0.8, tck = -0.02)

axis(2, at = round(seq(-1.5, 1.5, 0.5), 1), 
     cex.axis = 0.8, las = 2, tck = -0.02)

title(xlab = "Year of publication", 
      ylab = "Effect size (r)",
      line = 2.75, cex.lab = 1.2)

lines(newdat$year, newdat$fit, lwd = 2.75, col = "black") 

polygon(c(newdat$year,rev(newdat$year)),
        c(newdat$lower,rev(newdat$upper)),
        border = NA, col = rgb(0, 0, 0, 0.25))

points(jitter(xaxis,2), yaxis,
       bg = rgb(0, 0, 0, 0.3),
       pch = 21,
       cex = cex.study)

text(x = 2004, y = 1.4, 
     labels = paste0("R2 = ", round(R2.time_lag_bias[1]*100, 1), " %"))

cex.legend <- c(4/200, 100/200, 500/200)

legend(1982, 1.5,
       c("N =   4",
         "N = 100",
         "N = 500"),
       pt.bg = rgb(0, 0, 0, 0.75),
       pt.cex = cex.legend,
       pch = 21,
       inset = c(0, 0),
       y.intersp = 1.2, x.intersp = 1)

dev.off()


###################################################
# All-in bias: multi-moderator model
###################################################

# This model includes all our moderators in the same model to test if evidence 
# for publication bias still exists after accounting for all the heterogeneity 
# explained by our moderators, and the model even provides an adjusted overall 
# effect size (the intercept, although interpret it carefully!). At the same 
# time, with this model, we can provide an estimate of how much heterogeneity we
# were able to explain with all our moderators combined.

# Publication and time-lag bias together with all moderators
all_in_bias <- rma.mv(r, VCV_ESVar,
                      mods = ~ 1 + inv_esz + year.c + #using inv_esz instead of sqrt_inv_esz to better estimate adjusted effect size (Nakagawa et al. 2022, MEE)
                        method + continent + scale 
                      + diversity + Class + Order.3 + Family.2,
                      random = list(~ 1 | studyID,
                                    ~ 1 | comparisonID,
                                    ~ 1 | locationID,
                                    ~ 1 | obsID),
                      method = "REML",
                      test = "t",
                      data = meta.final)

print(all_in_bias, digits=2)

# Calculate marginal R2 with r2_ml
R2.all_in_bias <- r2_ml(all_in_bias)
round(R2.all_in_bias*100, 1)

# The results of the all-in multi-moderator model confirm that there is
# evidence for funnel plot asymmetry: the slope of inv_esz is large and
# statistically significant. That is, there is small-study bias, even after we 
# have accounted for the heterogeneity explained by all the moderators we 
# considered in our study. Another take on message from this all-in model is 
# that we could actually explain a decent percentage of heterogeneity (relative 
# to most meta-analyses), since the R2marginal of our all-in model is 15.7%, 
# although keep in mind that about 10.9% was explained by the small-study effect
# alone. The adjusted for publication bias effect is r = -0.37 [-0.56,-0.18], 
# showing that despite of the evidence for small-study effects found, the effect 
# of urbanization on biodiversity is still negative across all contexts (except, 
# perhaps, when city comparisons are used as methodology). Keep in mind, though,
# that the intercept in this model correspond to the effect for the reference 
# levels of all the factorial moderators, and it assumes a hypothetical scenario
# where sampling variance is 0. Plus, since we mean-centred year, the intercept
# gives an estimate using mean year of publication, i.e. ~2012, as reference.
# To make it perhaps more easily understandable, we can fit a multi-moderator
# model that only contains inv_esz and year.c, and interpret the intercept of 
# this model as the overall effect sizes adjusted for publication bias, which
# we will report in our manuscript to show that, even when publication bias is
# accounted for, the effect of urbanization on biodiversity remains. Here are
# the results:

# Publication and time-lag bias together with all moderators
all_in_bias.adjusted.effect.size <- rma.mv(r, VCV_ESVar,
                                           mods = ~ 1 + inv_esz + year.c, #using inv_esz instead of sqrt_inv_esz to better estimate adjusted effect size (Nakagawa et al. 2022, MEE)
                                           random = list(~ 1 | studyID,
                                                         ~ 1 | comparisonID,
                                                         ~ 1 | locationID,
                                                         ~ 1 | obsID),
                                           method = "REML",
                                           test = "t",
                                           data = meta.final)

print(all_in_bias.adjusted.effect.size, digits=2)

# The adjusted overall effect size is -0.35 [-0.45,-0.25] compared to the 
# unadjusted overall effect size from the intercept-only model (meta.model),
# which was -0.51 [-0.58, -0.43]. As it can be observed, there is a relatively
# large reduction in the negative effect of urbanization on biodiversity once
# we account for publication bias. Nonetheless, the effect is still there and is
# rather important.


################################################################################
# SENSITIVITY ANALYSES
################################################################################

################################################################################
# Do different types of effect sizes lead to different results?
################################################################################

#to test if the effect size type influences the effect size
metareg.es_type_2 <- rma.mv(r, VCV_ESVar, 
                            mods = ~ es_type_2, 
                            random = list(~ 1 | studyID,
                                          ~ 1 | comparisonID,
                                          ~ 1 | locationID,
                                          ~ 1 | obsID),
                            method="REML", 
                            test="t", 
                            data=meta.final)

print(metareg.es_type_2, digits=2)

# calculate marginal R2 with r2_ml
R2.es_type_2 <- r2_ml(metareg.es_type_2)
round(R2.es_type_2*100,1) # in %

# Plotting the results
# removing the intercept for easy plotting
metareg.es_type_2.no.int <- rma.mv(r, VCV_ESVar, 
                                   mods = ~ es_type_2 - 1, 
                                   random = list(~ 1 | studyID,
                                                 ~ 1 | comparisonID,
                                                 ~ 1 | locationID,
                                                 ~ 1 | obsID),
                                   method="REML", 
                                   test="t", 
                                   data=meta.final)

print(metareg.es_type_2.no.int, digits=2)


tiff("figures/09_Effect_size_type_results.tiff",
     height=10.5, width=16,
     units='cm', compression="lzw", res=800)

orchard_plot(metareg.es_type_2.no.int, mod = "es_type_2", 
             xlab = "Effect size (r)", 
             group = "studyID",
             data = meta.final,
             cb = TRUE,
             alpha = 0.5, angle = 45) +
  theme(legend.position= c(0.42, 0.097),
        legend.justification = c(0,1.1),
        legend.key.size = unit(1, "mm")) +
  theme(legend.direction="horizontal",
        legend.title = element_text(size = 6),
        legend.text = element_text(size = 8)) +
  scale_y_continuous(limits = c(-1.75,1.5),breaks = c(seq(-1.5,1.5,0.5))) +
  annotate(geom="text", x=3.43, y=-1.54, label=paste0("italic(R)^{2} == ", round(R2.es_type_2[1]*100, 1)),
           color="black", parse = TRUE, size = 5) +
  annotate(geom="text", x=3.42, y=-1.20, label="%",color="black", parse = FALSE, size = 5)

dev.off()


###compare the remaining factor levels
car::linearHypothesis(metareg.es_type_2, rbind(c(0,1,-1))) # correlation coefficient vs inferential statistic


################################################################################
# Using correlation coefficients only
################################################################################

meta.final.r.only <- meta.final[meta.final$es_type_2=="correlation_coefficient",]

################################################################################
# Sampling variance-covariance matrix
################################################################################

# more details above

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.r <- matrix(0, nrow = nrow(meta.final.r.only), 
                      ncol = nrow(meta.final.r.only))

# names rows and columns for each obsID
rownames(VCV_ESVar.r) <- meta.final.r.only[, "obsID"]
colnames(VCV_ESVar.r) <- meta.final.r.only[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.r <- which(meta.final.r.only[, "studyID"] %in% 
                          meta.final.r.only[duplicated(meta.final.r.only[,"studyID"]), 
                                            "studyID"] == TRUE)

combinations.r <- do.call("rbind", tapply(shared_coord.r, 
                                          meta.final.r.only[shared_coord.r,"studyID"], 
                                          function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.r)[1]) {
  p1 <- combinations.r[i, 1]
  p2 <- combinations.r[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.r.only[p1, "Vr"]) * 
    sqrt(meta.final.r.only[p2, "Vr"])
  VCV_ESVar.r[p1, p2] <- p1_p2_cov
  VCV_ESVar.r[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.r) <- meta.final.r.only[, "Vr"]


#Data funnel plot
par(mfrow = c(1, 2))
funnel(meta.final.r.only$r, meta.final.r.only$Vr, yaxis="sei",
       xlab = "Effect size (r)", digits = 2, las = 1) 
funnel(meta.final.r.only$r, meta.final.r.only$Vr, yaxis="seinv",
       xlab = "Effect size (r)",  digits = 2, las = 1) 


# MAIN MODEL = multilevel meta-analysis
model.r.only <- rma.mv(r, VCV_ESVar.r, 
                       random = list(~ 1 | studyID,
                                     ~ 1 | comparisonID,
                                     ~ 1 | locationID,
                                     ~ 1 | obsID), 
                       method="REML", 
                       test="t", 
                       data=meta.final.r.only)

print(model.r.only, digits=2)
predict(model.r.only, digits=2)

#model funnel plot
par(mfrow = c(1, 1))
funnel(model.r.only)

# we can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be considered outliers
resid<-rstandard(model.r.only)
plot(1:nrow(meta.final.r.only),resid$z,type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model.r.only <- i2_ml(model.r.only)
round(I2.model.r.only,1)

# # Plot for the meta-analytic mean
# # xlab should be Effect size (r)
# tiff("10_Meta-analytic_mean_r_only.tiff",
#      height=10.5, width=10.5,
#      units='cm', compression="lzw", res=800)
# 
# orchard_plot(model.r.only, mod = "Int", xlab = "Effect size (r)",transfm = "none") + 
#   annotate(geom = "text", x = -1.1, y = 1.5, label = paste0("italic(I)^{2} == ", round(I2.model.r.only[1] * 100, 1)), 
#            color = "black", parse = TRUE, size = 5) + 
#   annotate(geom = "text", x = -0.65, y = 1.49, label = "%", color = "black", parse = FALSE, size = 5) +
#   scale_x_continuous(limits = c(-1.5,1.5),breaks = c(seq(-1.5,1.5,0.5))) +
#   theme(legend.direction="horizontal",
#         legend.title = element_text(size = 8),
#         legend.text = element_text(size = 10),
#         axis.text.y = element_blank(),
#         axis.ticks = element_blank())
# 
# dev.off()

# exploring moderators: table
table(meta.final.r.only$method)
table(meta.final.r.only$taxa)
table(meta.final.r.only$continent)
table(meta.final.r.only$scale)
table(meta.final.r.only$diversity)


################################################################################
# Using biserial correlation coefficients only
################################################################################

meta.final.bsr.only <- meta.final[meta.final$es_type_2=="biserial_correlation",]

################################################################################
# Sampling variance-covariance matrix
################################################################################

# more details above

# creates a matrix (called 'VCV_ESVar') with the dimensions 
# n(effect_sizes) x n(effect_sizes)
VCV_ESVar.bsr <- matrix(0, nrow = nrow(meta.final.bsr.only), 
                        ncol = nrow(meta.final.bsr.only))

# names rows and columns for each obsID
rownames(VCV_ESVar.bsr) <- meta.final.bsr.only[, "obsID"]
colnames(VCV_ESVar.bsr) <- meta.final.bsr.only[, "obsID"]

# finds effect sizes that come from the same study
shared_coord.bsr <- which(meta.final.bsr.only[, "studyID"] %in% 
                            meta.final.bsr.only[duplicated(meta.final.bsr.only[,"studyID"]), 
                                                "studyID"] == TRUE)

combinations.bsr <- do.call("rbind", tapply(shared_coord.bsr, 
                                            meta.final.bsr.only[shared_coord.bsr,"studyID"], 
                                            function(x) t(utils::combn(x, 2))))

# calculates the covariance between effect sizes and enters them in each 
# combination of coordinates
for (i in 1:dim(combinations.bsr)[1]) {
  p1 <- combinations.bsr[i, 1]
  p2 <- combinations.bsr[i, 2]
  p1_p2_cov <- 0.5 * sqrt(meta.final.bsr.only[p1, "Vr"]) * 
    sqrt(meta.final.bsr.only[p2, "Vr"])
  VCV_ESVar.bsr[p1, p2] <- p1_p2_cov
  VCV_ESVar.bsr[p2, p1] <- p1_p2_cov
} 

# enters previously calculated effect size sampling variances into diagonals 
diag(VCV_ESVar.bsr) <- meta.final.bsr.only[, "Vr"]

#Data funnel plot
par(mfrow = c(1, 2))
funnel(meta.final.bsr.only$r, meta.final.bsr.only$Vr, yaxis="sei",
       xlab = "Effect size (r)", digits = 2, las = 1) 
funnel(meta.final.bsr.only$r, meta.final.bsr.only$Vr, yaxis="seinv",
       xlab = "Effect size (r)",  digits = 2, las = 1) 


# MAIN MODEL = multilevel meta-analysis
model.bsr.only <- rma.mv(r, VCV_ESVar.bsr, 
                         random = list(~ 1 | studyID,
                                       ~ 1 | comparisonID,
                                       ~ 1 | locationID,
                                       ~ 1 | obsID), 
                         method="REML", test="t", data=meta.final.bsr.only)

print(model.bsr.only, digits=2)
predict(model.bsr.only, digits=2)

#model funnel plot
par(mfrow = c(1, 1))
funnel(model.bsr.only)

# we can look for potential outliers based on the residuals of the model
# any points below -2 or above 2 could be considered outliers
resid<-rstandard(model.bsr.only)
plot(1:nrow(meta.final.bsr.only),resid$z,type="b")
abline(h = 2)
abline(h = -2)

# Estimating heterogeneity as I2 (Nakagawa and Santos 2012) 
I2.model.bsr.only <- i2_ml(model.bsr.only)
round(I2.model.bsr.only,1)


# # Plot for the meta-analytic mean
# # xlab should be Effect size (r)
# tiff("11_Meta-analytic_mean_bsr_only.tiff",
#      height=10.5, width=10.5,
#      units='cm', compression="lzw", res=800)
# 
# orchard_plot(model.bsr.only, mod = "Int", xlab = "Effect size (r)",transfm = "none") + 
#   annotate(geom = "text", x = -1.1, y = 1.5, label = paste0("italic(I)^{2} == ", round(I2.model.bsr.only[1] * 100, 1)), 
#            color = "black", parse = TRUE, size = 5) + 
#   annotate(geom = "text", x = -0.65, y = 1.49, label = "%", color = "black", parse = FALSE, size = 5) +
#   scale_x_continuous(limits = c(-1.9,1.5),breaks = c(seq(-1.5,1.5,0.5))) +
#   theme(legend.direction="horizontal",
#         legend.title = element_text(size = 8),
#         legend.text = element_text(size = 10),
#         axis.text.y = element_blank(),
#         axis.ticks = element_blank())
# 
# dev.off()

