##############################################################
# Author: Endika Blanco

# Script for map figure for a meta-analysis 
# on the effect of urbanization on biodiversity.
##############################################################

# Clear memory
rm(list=ls())

# Install and load packages
#install.packages(c("ggplot2", "dplyr", "scatterpie","memisc, "assertthat"))
#install.packages(c("sqldf", "magrittr", "reshape2", "oz", "rgdal", "maptools"))
library(readxl)
library(ggplot2)
library(dplyr)
library(scatterpie)

library(memisc)
library(assertthat)
library(sqldf)
library(magrittr)
library(reshape2)
library(oz)
library(rgdal)
library(maptools)


##############################################################
# DATA PREPARATION
##############################################################

# Import database
meta.final <- read.table("meta_final_reduced.csv", header=T, sep=",")

#Subset for Insect Orders (Orders of the rest of orders are too small)
meta.final$Order.2 <- ifelse(as.character(meta.final$Order) %in% 
                               c("Araneae", "Decapoda", "Diplostraca",
                                 "Harpacticoida", "Isopoda", "Ixodida",
                                 "Opiliones", "Spirostreptida",
                                 "Diplostraca", "Trombidiformes"),
                             "Non-Insect Orders", 
                             as.character(meta.final$Order))

#Subset for Insect Orders, after unifying EPT orders into EPT.
meta.final$Order.3 <- ifelse(as.character(meta.final$Order.2) %in% 
                               c("Ephemeroptera","Plecoptera","Trichoptera"),
                             "EPT", 
                             as.character(meta.final$Order.2))

meta.final$Order.3 <- factor(meta.final$Order.3)

#Removing "Non-Insect Orders" group.
meta.final$Order.4 <- droplevels(meta.final$Order.3, exclude = "Non-Insect Orders",)
mape <- meta.final[complete.cases(meta.final$Order.4), ] 
table(mape$Order.4)

# Export to delete NAs manually as code "complete.cases" not working
#write.csv(mape[,c("obsID", "studyID", "comparisonID", "locationID",
#                        "authors", "title", "year", "Order.4")],
#          file= "mape.csv", row.names=FALSE)

# Change pie text size
#update_geom_defaults("text", list(size = 4.2))

# create bar plot data
mape2 <- mape %>%
  dplyr::mutate(Order.4 = factor(Order.4)) %>%
  group_by(Order.4) %>%
  dplyr::summarise(Frequency = n()) %>%
  dplyr::mutate(Percent = round(Frequency/sum(Frequency)*100, 1))

# create an individual pie (not used in map script)
mape2$Label  <- round(((mape2$Frequency/sum(mape2$Frequency))*100),2)
mape2 <- mape2 %>%
  mutate(end = 2 * pi * cumsum(Label)/sum(Label),
         start = lag(end, default = 0),
         middle = 0.5 * (start + end),
         hjust = ifelse(middle > pi, 1, 0),
         vjust = ifelse(middle < pi/2 | middle > 3 * pi/2, 0, 1))


ggplot(mape2) + 
  ggforce::geom_arc_bar(aes(x0 = 0, y0 = 0, r0 = 0, r = 1,
                            start = start, end = end, fill = Order.4)) +
  geom_text(aes(x = 1.05 * sin(middle), y = 1.05 * cos(middle), label = Label,
                hjust = hjust, vjust = vjust, fontface = "bold")) +
  coord_fixed() +
  labs(x = NULL, y = NULL, fill = NULL, 
       title = "ESTUDIED ORDERS IN EUROPE") +
  guides(fill = guide_legend(reverse = TRUE)) +
  scale_fill_manual(values = c("indianred4", "gray80", "darkblue", "gray30", "orange")) +
  theme_classic() +
  theme(axis.line = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        plot.title = element_text(hjust = 0.5, color = "#666666"))


##############################################################
# EUROPE
##############################################################

#subset for Europe data
mape.euro <- mape[mape$continent=="Europe",]

# create bar plot data
mape.euro <- mape.euro %>%
  dplyr::mutate(Order.4 = factor(Order.4)) %>%
  group_by(Order.4) %>%
  dplyr::summarise(Frequency = n()) %>%
  dplyr::mutate(Percent = round(Frequency/sum(Frequency)*100, 1))

# create an individual pie (not used in map script)
mape.euro$Label  <- round(((mape.euro$Frequency/sum(mape.euro$Frequency))*100),2)
mape.euro <- mape.euro %>%
  mutate(end = 2 * pi * cumsum(Label)/sum(Label),
         start = lag(end, default = 0),
         middle = 0.5 * (start + end),
         hjust = ifelse(middle > pi, 1, 0),
         vjust = ifelse(middle < pi/2 | middle > 3 * pi/2, 0, 1))


ggplot(mape.euro) + 
  ggforce::geom_arc_bar(aes(x0 = 0, y0 = 0, r0 = 0, r = 1,
                            start = start, end = end, fill = Order.4)) +
  geom_text(aes(x = 1.05 * sin(middle), y = 1.05 * cos(middle), label = Label,
                hjust = hjust, vjust = vjust, fontface = "bold")) +
  coord_fixed() +
  labs(x = NULL, y = NULL, fill = NULL, 
       title = "ESTUDIED ORDERS IN EUROPE") +
  guides(fill = guide_legend(reverse = TRUE)) +
  scale_fill_manual(values = c("indianred4", "gray80", "darkblue", "gray30", "orange")) +
  theme_classic() +
  theme(axis.line = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        plot.title = element_text(hjust = 0.5, color = "#666666"))


##############################################################
# NORTH AMERICA
##############################################################

#subset for North America data
mape.north <- mape[mape$continent=="North America",]

# create bar plot data
mape.north <- mape.north %>%
  dplyr::mutate(Order.4 = factor(Order.4)) %>%
  group_by(Order.4) %>%
  dplyr::summarise(Frequency = n()) %>%
  dplyr::mutate(Percent = round(Frequency/sum(Frequency)*100, 1))

# create an individual pie (not used in map script)
mape.north$Label  <- round(((mape.north$Frequency/sum(mape.north$Frequency))*100),2)
mape.north <- mape.north %>%
  mutate(end = 2 * pi * cumsum(Label)/sum(Label),
         start = lag(end, default = 0),
         middle = 0.5 * (start + end),
         hjust = ifelse(middle > pi, 1, 0),
         vjust = ifelse(middle < pi/2 | middle > 3 * pi/2, 0, 1))


ggplot(mape.north) + 
  ggforce::geom_arc_bar(aes(x0 = 0, y0 = 0, r0 = 0, r = 1,
                            start = start, end = end, fill = Order.4)) +
  geom_text(aes(x = 1.05 * sin(middle), y = 1.05 * cos(middle), label = Label,
                hjust = hjust, vjust = vjust, fontface = "bold")) +
  coord_fixed() +
  labs(x = NULL, y = NULL, fill = NULL, 
       title = "ESTUDIED ORDERS IN NA") +
  guides(fill = guide_legend(reverse = TRUE)) +
  scale_fill_manual(values = c("indianred4", "gray80", "darkblue", "gray30", "orange")) +
  theme_classic() +
  theme(axis.line = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        plot.title = element_text(hjust = 0.5, color = "#666666"))


##############################################################
# SOUTH AMERICA
##############################################################

#subset for South America data
mape.south <- mape[mape$continent=="South America",]

# create bar plot data
mape.south <- mape.south %>%
  dplyr::mutate(Order.4 = factor(Order.4)) %>%
  group_by(Order.4) %>%
  dplyr::summarise(Frequency = n()) %>%
  dplyr::mutate(Percent = round(Frequency/sum(Frequency)*100, 1))

# create an individual pie (not used in map script)
mape.south$Label  <- round(((mape.south$Frequency/sum(mape.south$Frequency))*100),2)
mape.south <- mape.south %>%
  mutate(end = 2 * pi * cumsum(Label)/sum(Label),
         start = lag(end, default = 0),
         middle = 0.5 * (start + end),
         hjust = ifelse(middle > pi, 1, 0),
         vjust = ifelse(middle < pi/2 | middle > 3 * pi/2, 0, 1))


ggplot(mape.south) + 
  ggforce::geom_arc_bar(aes(x0 = 0, y0 = 0, r0 = 0, r = 1,
                            start = start, end = end, fill = Order.4)) +
  geom_text(aes(x = 1.05 * sin(middle), y = 1.05 * cos(middle), label = Label,
                hjust = hjust, vjust = vjust, fontface = "bold")) +
  coord_fixed() +
  labs(x = NULL, y = NULL, fill = NULL, 
       title = "ESTUDIED ORDERS IN SA") +
  guides(fill = guide_legend(reverse = TRUE)) +
  scale_fill_manual(values = c("indianred4", "gray80", "darkblue", "gray30", "orange")) +
  theme_classic() +
  theme(axis.line = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        plot.title = element_text(hjust = 0.5, color = "#666666"))


##############################################################
# ASIA
##############################################################

#subset for Asia data
mape.asia <- mape[mape$continent=="Asia",]

# create bar plot data
mape.asia <- mape.asia %>%
  dplyr::mutate(Order.4 = factor(Order.4)) %>%
  group_by(Order.4) %>%
  dplyr::summarise(Frequency = n()) %>%
  dplyr::mutate(Percent = round(Frequency/sum(Frequency)*100, 1))

# create an individual pie (not used in map script)
mape.asia$Label  <- round(((mape.asia$Frequency/sum(mape.asia$Frequency))*100),2)
mape.asia <- mape.asia %>%
  mutate(end = 2 * pi * cumsum(Label)/sum(Label),
         start = lag(end, default = 0),
         middle = 0.5 * (start + end),
         hjust = ifelse(middle > pi, 1, 0),
         vjust = ifelse(middle < pi/2 | middle > 3 * pi/2, 0, 1))


ggplot(mape.asia) + 
  ggforce::geom_arc_bar(aes(x0 = 0, y0 = 0, r0 = 0, r = 1,
                            start = start, end = end, fill = Order.4)) +
  geom_text(aes(x = 1.05 * sin(middle), y = 1.05 * cos(middle), label = Label,
                hjust = hjust, vjust = vjust, fontface = "bold")) +
  coord_fixed() +
  labs(x = NULL, y = NULL, fill = NULL, 
       title = "ESTUDIED ORDERS IN ASIA") +
  guides(fill = guide_legend(reverse = TRUE)) +
  scale_fill_manual(values = c("indianred4", "gray80", "darkblue", "gray30", "orange")) +
  theme_classic() +
  theme(axis.line = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        plot.title = element_text(hjust = 0.5, color = "#666666"))


##############################################################
# OCEANIA
##############################################################

#subset for Oceania data
mape.ocean <- mape[mape$continent=="Oceania",]

# create bar plot data
mape.ocean <- mape.ocean %>%
  dplyr::mutate(Order.4 = factor(Order.4)) %>%
  group_by(Order.4) %>%
  dplyr::summarise(Frequency = n()) %>%
  dplyr::mutate(Percent = round(Frequency/sum(Frequency)*100, 1))

# create an individual pie (not used in map script)
mape.ocean$Label  <- round(((mape.ocean$Frequency/sum(mape.ocean$Frequency))*100),2)
mape.ocean <- mape.ocean %>%
  mutate(end = 2 * pi * cumsum(Label)/sum(Label),
         start = lag(end, default = 0),
         middle = 0.5 * (start + end),
         hjust = ifelse(middle > pi, 1, 0),
         vjust = ifelse(middle < pi/2 | middle > 3 * pi/2, 0, 1))


ggplot(mape.ocean) + 
  ggforce::geom_arc_bar(aes(x0 = 0, y0 = 0, r0 = 0, r = 1,
                            start = start, end = end, fill = Order.4)) +
  geom_text(aes(x = 1.05 * sin(middle), y = 1.05 * cos(middle), label = Label,
                hjust = hjust, vjust = vjust, fontface = "bold")) +
  coord_fixed() +
  labs(x = NULL, y = NULL, fill = NULL, 
       title = "ESTUDIED ORDERS IN OCEANIA") +
  guides(fill = guide_legend(reverse = TRUE)) +
  scale_fill_manual(values = c("indianred4", "gray80", "darkblue", "gray30", "orange")) +
  theme_classic() +
  theme(axis.line = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        plot.title = element_text(hjust = 0.5, color = "#666666"))


##############################################################
# AFRICA
##############################################################

#subset for Africa data
mape.afri <- mape[mape$continent=="Africa",]

# create bar plot data
mape.afri <- mape.afri %>%
  dplyr::mutate(Order.4 = factor(Order.4)) %>%
  group_by(Order.4) %>%
  dplyr::summarise(Frequency = n()) %>%
  dplyr::mutate(Percent = round(Frequency/sum(Frequency)*100, 1))

# create an individual pie (not used in map script)
mape.afri$Label  <- round(((mape.afri$Frequency/sum(mape.afri$Frequency))*100),2)
mape.afri <- mape.afri %>%
  mutate(end = 2 * pi * cumsum(Label)/sum(Label),
         start = lag(end, default = 0),
         middle = 0.5 * (start + end),
         hjust = ifelse(middle > pi, 1, 0),
         vjust = ifelse(middle < pi/2 | middle > 3 * pi/2, 0, 1))


ggplot(mape.afri) + 
  ggforce::geom_arc_bar(aes(x0 = 0, y0 = 0, r0 = 0, r = 1,
                            start = start, end = end, fill = Order.4)) +
  geom_text(aes(x = 1.05 * sin(middle), y = 1.05 * cos(middle), label = Label,
                hjust = hjust, vjust = vjust, fontface = "bold")) +
  coord_fixed() +
  labs(x = NULL, y = NULL, fill = NULL, 
       title = "ESTUDIED ORDERS IN AFRICA") +
  guides(fill = guide_legend(reverse = TRUE)) +
  scale_fill_manual(values = c("indianred4", "gray80", "darkblue", "gray30", "orange")) +
  theme_classic() +
  theme(axis.line = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        plot.title = element_text(hjust = 0.5, color = "#666666"))


##############################################################
# SCATTERPIE PLOT
##############################################################

# PREPARE DATA

# Creating new variables for map coordinates (script used, but used in a new
# database that includes Order.4, lat, long and Percent of each order) 
#mapdata2$lat <- recode_factor(mape$continent, "Europe" = "50", "North America" = "50",
#                          "South America" = "-10", "Asia" = "50",
#                          "Oceania" = "-25", "Africa" = "20")
#mapdata2$long <- recode_factor(mape$continent, "Europe" = "15", "North America" = "-100",
#                          "South America" = "-60", "Asia" = "100",
#                          "Oceania" = "140", "Africa" = "15")
#mapdata2$lat <- as.numeric(mape$lat)
#mapdata2$long <- as.numeric(mape$long)


# Import database
cont <- as.data.frame(read_excel("mapdata2.xlsx"))

# Preparing worldmap
set.seed(123)
long <- rnorm(50, sd=100)
lat <- rnorm(50, sd=50)
d <- data.frame(long=long, lat=lat)
d <- with(d, d[abs(long) < 150 & abs(lat) < 70,])
n <- nrow(d)
d$region <- factor(1:n)
d$A <- abs(rnorm(n, sd=1))
d$B <- abs(rnorm(n, sd=2))
d$C <- abs(rnorm(n, sd=3))
d$D <- abs(rnorm(n, sd=4))
d[1, 4:7] <- d[1, 4:7] * 3
head(d)

tiff("figures/Map_order.tiff",
     height=12, width=16,
     units='cm', compression="lzw", res=800)

# plot
world <- map_data('world')
p <- ggplot(world, aes(long, lat)) +
  geom_map(map=world, aes(map_id=region), fill=NA, color="black") +
  coord_quickmap()

maped <- p +
  geom_scatterpie(data=cont, aes(x = long, y = lat, r=15, group= "Order.4"),
                  cols= c("Coleoptera", "Diptera", "EPT", "Hemiptera",
                          "Hymenoptera", "Lepidoptera", "Odonata", "Orthoptera")) +
  theme(legend.position = c(0.10, 0.35))

plot(maped)
dev.off()



# If a color change is needed for pies
#maped + scale_fill_manual(values = c("indianred4", "gray80", "darkblue", "gray30", "orange"))


